* ------------------------------------------------------------------------------------
* Load data
set more off
if Mortg==1 {
	use UpdatedDebtDistr_M.dta, clear
}
if Mortg==0 {
	use UpdatedDebtDistr_C.dta, clear
}
* ------------------------------------------------------------------------------------


* ------------------------------------------------------------------------------------
* Collapse and reshape for final data
collapse (sum) celldebt, by(age sa0100 currentdate)
compress
rename celldebt debt_
encode sa0100, gen(sa0100_num)
gen temp_id = age*100+sa0100_num
reshape wide debt_ , i(temp_id) j(currentdate)
keep debt_* age sa0100
compress
* ------------------------------------------------------------------------------------


* Choose measure of debt
qui sca relbase = 1 /* if=1, then everything scaled by base year, otherwise distr. sums up to 1 each year*/

* Generate aggregate debt per period/country
do BaseYearsAssetsLiabilities.do
qui local datevec "20133 20132 20131 20124 20123 20122 20121 20114 20113 20112 20111 20104 20103 20102 20101 20094 20093 20092 20091 20084 20083 20082 20081"
qui levelsof sa0100, local(countryvec)
foreach it of local datevec {
	di " `it' "
	bysort sa0100: egen aggdebt_`it'=sum(debt_`it')
}

* Generate variable with aggregate debt for baseyear
gen aggdebt_base = .
qui local datevec "20133 20132 20131 20124 20123 20122 20121 20114 20113 20112 20111 20104 20103 20102 20101 20094 20093 20092 20091 20084 20083 20082 20081"
qui levelsof sa0100, local(countryvec)
foreach ii of local countryvec {
	di " `ii' "
	local it = stSmplAsstNum_`ii'
	di " `it' "
	replace aggdebt_base = aggdebt_`it' if sa0100=="`ii'"
}

* Scale everything by aggregate debt of base year 
qui local datevec "20133 20132 20131 20124 20123 20122 20121 20114 20113 20112 20111 20104 20103 20102 20101 20094 20093 20092 20091 20084 20083 20082 20081"
foreach it of local datevec {
	di " `it' "
	gen double reldebt_`it' = debt_`it'/aggdebt_`it'*100
	if relbase==1 {
		replace reldebt_`it' = debt_`it'/aggdebt_base*100
	}
}
sort sa0100 age
compress
drop if age>80

* Generate age group
*gen agegrp=.
*replace agegrp=34 if age<=34
*replace agegrp=44 if age>=35 & age<=44
*replace agegrp=54 if age>=45 & age<=54
*replace agegrp=64 if age>=55 & age<=64
*replace agegrp=65 if age>=65
*drop if agegrp==.

* Greece * * * * * * OK OK OK OK OK * * * * * * *
twoway (line reldebt_20081 age if sa0100=="GR", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20093 age if sa0100=="GR", lcolor(blue*1.2) lpattern(longdash lwidth(medthick))) (line reldebt_20132 age if sa0100=="GR", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2010Q2)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) { 
	graph export "$graphPath\NewDistr_Mortg_GR.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_GR.pdf", replace
}


* Portugal 
twoway (line reldebt_20081 age if sa0100=="PT", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20102 age if sa0100=="PT", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="PT", lcolor(blue*0.3 lwidth(medthick))),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2010Q2)" 3 " 2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_PT.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_PT.pdf", replace
}

	
* Spain 
twoway (line reldebt_20081 age if sa0100=="ES", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20091 age if sa0100=="ES", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="ES", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2009Q1)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_ES.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_ES.pdf", replace
}


* Austria  
twoway (line reldebt_20081 age if sa0100=="AT", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20111 age if sa0100=="AT", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="AT", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2011Q1)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_AT.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_AT.pdf", replace
}


* Slovakia 
twoway (line reldebt_20081 age if sa0100=="SK", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20103 age if sa0100=="SK", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="SK", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2010Q3)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_SK.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_SK.pdf", replace
}


* Slovenia 
twoway (line reldebt_20081 age if sa0100=="SI", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20104 age if sa0100=="SI", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="SI", lcolor(blue*0.3 lwidth(medthick))),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2010Q4)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_SI.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_SI.pdf", replace
}


* Belgium 
twoway (line reldebt_20081 age if sa0100=="BE", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20103 age if sa0100=="BE", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="BE", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2010Q3)" 3 " 013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_BE.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_BE.pdf", replace
}

* Italy 
twoway (line reldebt_20081 age if sa0100=="IT", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20104 age if sa0100=="IT", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="IT", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2010Q4)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_IT.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_IT.pdf", replace
}


* Netherlands 
twoway (line reldebt_20081 age if sa0100=="NL", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20094 age if sa0100=="NL", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="NL", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2009Q4)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_NL.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_NL.pdf", replace
}


* Germany 
twoway (line reldebt_20081 age if sa0100=="DE", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20111 age if sa0100=="DE", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="DE", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2011Q1)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_DE.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_DE.pdf", replace
}

* Cyprus 
twoway (line reldebt_20081 age if sa0100=="CY", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20103 age if sa0100=="CY", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="CY", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2010Q3)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_CY.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_CY.pdf", replace
}


* Finland
twoway (line reldebt_20081 age if sa0100=="FI", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20093 age if sa0100=="FI", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="FI", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2009Q3)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_FI.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_FI.pdf", replace
}


* France 
twoway (line reldebt_20081 age if sa0100=="FR", lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20094 age if sa0100=="FR", lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age if sa0100=="FR", lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "Original (2009Q4)" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1)) xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_FR.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_FR.pdf", replace
}

* ------------------------------------------------------------------------------------
* Euro Area aggregate
collapse (sum) aggdebt_* debt_*, by(age)
* ------------------------------------------------------------------------------------

* Scale everything by aggregate debt of artificial/arbitrary baseyear
qui local datevec "20133 20132 20131 20124 20123 20122 20121 20114 20113 20112 20111 20104 20103 20102 20101 20094 20093 20092 20091 20084 20083 20082 20081"
foreach it of local datevec {
	gen double reldebt_`it' = debt_`it'/ debt_`it'*100 
	if relbase==1 {
		replace reldebt_`it' = debt_`it'/aggdebt_20102*100
	}
}

twoway (line reldebt_20081 age, lcolor(blue*5) lpattern(shortdash) lwidth(medthick)) (line reldebt_20111 age, lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line reldebt_20132 age, lcolor(blue*0.3) lwidth(medthick)),  ytitle(in %) xtitle(Age) legend(order(1 "2008Q1" 2 "2011Q1" 3 "2013Q2"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1))  xlabel(20(10)80) xscale(range(20 80))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\NewDistr_Mortg_EA.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\NewDistr_Cons_EA.pdf", replace
}

