use "D_compl.dta", clear
set more off
*keep if im0100==1
*keep if sa0100=="AT"
drop if dhageh1<18


* --------------------------------------
* Compute cutoffs for age
*collapse (sum) dl1000 [pweight=hw0010], by(dhageh1)
*egen totdebt = sum(dl1000)
*gen debtshare= dl1000/totdebt
*sort dhageh1
*gen cumdebtshare=debtshare if _n==1
*replace cumdebtshare=cumdebtshare[_n-1]+debtshare if _n>1
*tab dhageh1, su(cumdebtshare)
*line cumdebtshare dhageh1  
* --------------------------------------

* --------------------------------------
do GenGrouping.do
* --------------------------------------

* --------------------------------------
clonevar avgintrpaym=intrpaym 
clonevar avgrepaym=repaym
clonevar avgdebt=debt
* --------------------------------------

*gen primeage=(dhageh1>30 & dhageh1<=40)
*drop if dhageh1>70
*drop if dhageh1<20
*collapse (sum) debt repaym [pweight=hw0010], by(primeage)
*gen debtlength=1/( repaym / debt)
*tab primeage, su(debtlength)
*asdf

* ---------------------------------------------------------------------------------------------------------
drop if sa0100=="FI"
keep hw0010 dhageh1 hasdebt debt intrpaym repaym incgrp wealthgrp ctrygrp
drop if dhageh1>75
drop if dhageh1<20
collapse (sum) debt hasdebt intrpaym repaym [pweight=hw0010], by(dhageh1 incgrp wealthgrp ctrygrp)
rename dhageh1 age
fillin age incgrp wealthgrp ctrygrp
drop _fillin 
* ---------------------------------------------------------------------------------------------------------



* ---------------------------------------------------------------------------------------------------------
* Generate new debt directly
sort incgrp wealthgrp ctrygrp age
by incgrp wealthgrp ctrygrp: gen newdebt=debt-(debt[_n-1]+intrpaym[_n] - repaym[_n]) if _n>1
by incgrp wealthgrp ctrygrp: replace newdebt=debt if _n==1

* Generate counterfactual asset holdings
by incgrp wealthgrp ctrygrp: gen debt_counterf = (debt[_n-1]+intrpaym[_n] - repaym[_n]) if _n>1
by incgrp wealthgrp ctrygrp: replace debt_counterf=debt if _n==1


* ---------------------------------------------------------------------------------------------------------
* Generate repayment ratio
gen repaym_ratio=repaym/debt
gen intr_ratio=intrpaym/debt

* Generate variables
gen debt_smooth = .
gen debt_smooth_poly = .

gen debt_counterf_smooth = .
gen debt_counterf_smooth_poly = .

gen newdebt_smooth = .
gen newdebt_smooth_poly = .

gen repaym_smooth = .
gen repaym_smooth_poly = .

gen repaym_ratio_smooth = .
gen repaym_ratio_smooth_poly = .

gen intrpaym_smooth = .
gen intrpaym_smooth_poly = .
 
gen intr_ratio_smooth = .
gen intr_ratio_smooth_poly = .

*gen reprat=repaym/debt
*graph bar (mean) reprat, over(age)
*graph bar (mean) debt, over(age)

* ---------------------------------------------------------------------------------------------------------
* country group
*local ctrylist = "Cont Med"
levelsof ctrygrp, local(ctrylist) 
foreach ii of local ctrylist {
	* income group
	qui levelsof incgrp, local(incgrp_list) 
	foreach ij of local incgrp_list {
		* wealth group
		qui levelsof wealthgrp, local(wealth_list)
		foreach ik of local incgrp_list {
			disp "`ii'" "`ij'" "`ik'"
			* Debt: LOWESS
			lowess debt age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) nograph  adjust
			replace debt_smooth=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Debt: POLYNOMIAL
			lpoly debt age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace debt_smooth_poly=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Debt Counterfactual: LOWESS
			lowess debt_counterf age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) nograph  adjust
			replace debt_counterf_smooth=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Debt Counterfactual: POLYNOMIAL
			lpoly debt_counterf age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace debt_counterf_smooth_poly=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* New Debt: LOWESS
			lowess newdebt age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) nograph  adjust
			replace newdebt_smooth=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var

			* New Debt: POLYNOMIAL
			lpoly newdebt age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace newdebt_smooth_poly=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
					
			* Repayments: LOWESS
			lowess repaym age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) nograph  adjust
			replace repaym_smooth=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Repayments: POLYNOMIAL
			lpoly repaym age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace repaym_smooth_poly=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Repayment Ratio: LOWESS
			lowess repaym_ratio age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph  adjust
			replace repaym_ratio_smooth_poly=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Repayment Ratio: POLYNOMIAL
			lpoly repaym_ratio age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace repaym_ratio_smooth=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Interest payments: LOWESS
			lowess intrpaym age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) nograph  adjust
			replace intrpaym_smooth=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Interest payments: POLYNOMIAL
			lpoly intrpaym age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace intrpaym_smooth_poly=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			
			* Interest payment ratio (approx.=interest rate): LOWESS
			lowess intr_ratio age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) nograph  adjust
			replace intr_ratio_smooth=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var	
			
			* Interest payment ratio (approx.=interest rate): POLYNOMIAL
			lpoly intr_ratio age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace intr_ratio_smooth_poly=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var	
		}
	}
}
* ---------------------------------------------------------------------------------------------------------



* --------------------------------------------------------------------------
* Generate new debt using difference between debt and counterfactual debt
* LOWESS
sort incgrp wealthgrp ctrygrp age
by incgrp wealthgrp ctrygrp: gen newdebt_smooth2=debt_smooth-debt_counterf_smooth
by incgrp wealthgrp ctrygrp: replace newdebt_smooth2=debt_smooth if _n==1

* POLYNOMIAL
sort incgrp wealthgrp ctrygrp age
by incgrp wealthgrp ctrygrp: gen newdebt_smooth2_poly=debt_smooth_poly-debt_counterf_smooth_poly

* --------------------------------------------------------------------------
* Generate new debt using smoothed interest payments and repayments
sort incgrp wealthgrp ctrygrp age
* LOWESS
by incgrp wealthgrp ctrygrp:  gen newdebt_smooth3 = debt_smooth - ( debt_smooth[_n-1]+intrpaym_smooth[_n-1] - repaym_smooth[_n-1] ) if _n>1 
by incgrp wealthgrp ctrygrp:  replace newdebt_smooth3 = debt_smooth if _n==1
* POLYNOMIAL
by incgrp wealthgrp ctrygrp:  gen newdebt_smooth3_poly = debt_smooth_poly - ( debt_smooth_poly[_n-1]+intrpaym_smooth_poly[_n-1] - repaym_smooth_poly[_n-1] ) if _n>1 


* --------------------------------------------------------------------------
* Generate repayment ratio using smoothed repayments and debt
gen repaym_ratio2_smooth =repaym_smooth/debt_smooth
gen repaym_ratio2_smooth_poly = repaym_smooth_poly/debt_smooth_poly

* --------------------------------------------------------------------------
* Generate change in aggregate debt (only delta time)
sort incgrp wealthgrp ctrygrp age
* LOWESS
by incgrp wealthgrp ctrygrp: gen d_debt = debt_smooth-debt_smooth[_n-1]
* POLYNOMIAL
by incgrp wealthgrp ctrygrp: gen d_debt_poly = debt_smooth_poly-debt_smooth_poly[_n-1]

replace newdebt_smooth2_poly = 0 if newdebt_smooth2_poly<0
replace newdebt_smooth3_poly = 0 if newdebt_smooth3_poly<0

gen newdebt_smooth2_poly_sm=.
gen newdebt_smooth3_poly_sm=.

* Smoothing of new debt from the two smooth profiles
* country group
levelsof ctrygrp, local(ctrylist)
foreach ii of local ctrylist {
	* income group
	qui levelsof incgrp, local(incgrp_list) 
	foreach ij of local incgrp_list {
		* wealth group
		qui levelsof wealthgrp, local(wealth_list)
		foreach ik of local incgrp_list {
			disp "`ii'" "`ij'" "`ik'"
			* Version 2
			lpoly newdebt_smooth2_poly age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace newdebt_smooth2_poly_sm=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
			* Version 3
			lpoly newdebt_smooth3_poly age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace newdebt_smooth3_poly_sm=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
		}
	}
}


drop if age>maxage

* --------------------------------
* New debt: comparison of methods
* --------------------------------
*graph bar (sum) newdebt, over(age) by(ctrygrp)			/* "raw" data only*/ 
*graph bar (sum) newdebt_smooth, over(age) by(ctrygrp)
*graph bar (sum) newdebt_~h_poly, over(age) by(ctrygrp)
*graph bar (sum) newdebt_smooth2, over(age) by(ctrygrp)

*graph bar (sum) newdebt_~2_poly, over(age) by(ctrygrp)      /* 1) OK ex ES*/              
*graph bar (sum) newdebt_smooth3, over(age) by(ctrygrp)    	/* 2) OK ex 20 year*/            
*graph bar (sum) newdebt_~3_poly, over(age) by(ctrygrp)    	/* 3) OK ex peak in ES*/             
*graph bar (sum) newde~2_poly_sm, over(age) by(ctrygrp)    	/* 4) OK ex peak in ES*/   
*graph bar (sum) newde~3_poly_sm, over(age) by(ctrygrp)      /* 5) OK */             
               
*graph bar (sum) newdebt_smooth2_poly newdebt_smooth3_poly, over(age) by(ctrygrp)
*graph bar (sum) newdebt_smooth2_poly_sm newdebt_smooth3_poly_sm, over(age) by(ctrygrp)  


* --------------------------------
* Repayment ratios: comparison of methods
* --------------------------------

*graph bar (mean) repaym, over(age) by(ctrygrp) 
*graph bar (mean) repaym_smooth, over(age) by(ctrygrp)
*graph bar (mean) repaym_smooth~y, over(age) by(ctrygrp)                   
	
*graph bar (mean) repaym_ratio, over(age) by(ctrygrp) 
*graph bar (mean) repaym_ratio_~h, over(age) by(ctrygrp) 
*graph bar (mean) repaym_ratio_~y, over(age) by(ctrygrp)     
*graph bar (mean) repaym_ratio2~h, over(age) by(ctrygrp) 	   
                
*graph bar (min) repaym_ratio2_smooth_poly, over(age) by(ctrygrp)
*graph bar (max) repaym_ratio2_smooth_poly, over(age) by(ctrygrp)
*graph bar (median) repaym_ratio2_smooth_poly, over(age) by(ctrygrp)
*graph bar (mean) repaym_ratio2_smooth_poly, over(age) by(ctrygrp)


* Get rid of "holes" & "jumps"
gen double repaym_ratio2_smooth_poly_sm = .
replace    repaym_ratio2_smooth_poly =. if repaym_ratio2_smooth_poly>0.9 | repaym_ratio2_smooth_poly<=0

levelsof ctrygrp, local(ctrylist)
foreach ii of local ctrylist {
	* income group
	qui levelsof incgrp, local(incgrp_list) 
	foreach ij of local incgrp_list {
		* wealth group
		qui levelsof wealthgrp, local(wealth_list)
		foreach ik of local incgrp_list {
			disp "`ii'" "`ij'" "`ik'"
			lpoly repaym_ratio2_smooth_poly age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace repaym_ratio2_smooth_poly_sm=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
		}
	}
}

*graph bar (min) repaym_ratio2_smooth_poly repaym_ratio2_smooth_poly_sm, over(age) by(ctrygrp)
*graph bar (max) repaym_ratio2_smooth_poly repaym_ratio2_smooth_poly_sm, over(age) by(ctrygrp)
*graph bar (median) repaym_ratio2_smooth_poly repaym_ratio2_smooth_poly_sm, over(age) by(ctrygrp)
*graph bar (mean) repaym_ratio2_smooth_poly repaym_ratio2_smooth_poly_sm, over(age) by(ctrygrp)


* --------------------------------
* Interest payments: comparison of methods
* --------------------------------

*graph bar (mean) intrpaym, over(age) by(ctrygrp)
*graph bar (mean) intr_ratio, over(age) by(ctrygrp)
*graph bar (mean) intrpaym_smooth, over(age) by(ctrygrp)
*graph bar (mean) intrpaym_smoo~y, over(age) by(ctrygrp)
*graph bar (mean) intr_ratio_sm~h, over(age) by(ctrygrp)

* Get rid of "holes" & "jumps"
gen double intr_ratio_smooth_poly_sm = .
replace    intr_ratio_smooth_poly =. if intr_ratio_smooth_poly>0.1 | repaym_ratio2_smooth_poly<=0

levelsof ctrygrp, local(ctrylist)
foreach ii of local ctrylist {
	* income group
	qui levelsof incgrp, local(incgrp_list) 
	foreach ij of local incgrp_list {
		* wealth group
		qui levelsof wealthgrp, local(wealth_list)
		foreach ik of local incgrp_list {
			disp "`ii'" "`ij'" "`ik'"
			lpoly intr_ratio_smooth_poly age if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik'), generate(temp_smooth_var) at(age) nograph
			replace intr_ratio_smooth_poly_sm=temp_smooth_var if (ctrygrp=="`ii'" & incgrp==`ij' & wealthgrp==`ik')
			drop temp_smooth_var
		}
	}
}

*graph bar (mean) intr_ratio_smooth_poly_sm, over(age) by(ctrygrp)
*graph bar (min) intr_ratio_smooth_poly_sm, over(age) by(ctrygrp)
*graph bar (max) intr_ratio_smooth_poly_sm, over(age) by(ctrygrp)
*graph bar (median) intr_ratio_smooth_poly_sm, over(age) by(ctrygrp)

* ---------------------------------------------------------------------------------------------------------
* Export graphs for paper
* ---------------------------------------------------------------------------------------------------------

* Total debt
egen totdebt=sum(debt_smooth_poly)
gen debt_smooth_poly_rel = debt_smooth_poly/totdebt*100
*qui graph bar (sum) debt_smooth_poly_rel, over(age, relabel(2" "3" "4" "5" "6" "7" "8" "9" "10" "12" "13" "14" "15" "16" "17" "18" "19" "20" "22" "23" "24" "25" "26" "27" "28" "29" "30" "32" "33" "34" "35" "36" "37" "38" "39" "40" "42" "43" "44" "45" "46" "47" "48" "49" "50" ") )/*
**/ over(incgrp, label(labsize(large)) gap(1000) relabel(1 "Low" 2 "Medium" 3 "High")) bar(1, fcolor(blue*1.2)) ytitle(in % of aggregate debt) graphregion(color(white)) ylabel(, labsize(large))
bysort age incgrp: egen temp = sum(debt_smooth_poly_rel)

twoway (line temp age if incgrp==0, lcolor(blue*5) lwidth(medthick)) (line temp age if incgrp==1, lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line temp age if incgrp==2, lcolor(blue*0.3) lwidth(medthick)),  ytitle(in % of aggregate debt, size(large)) xtitle(Age, size(large)) legend(order(1 "Low" 2 "Medium" 3 "High"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(0 0.5 1 1.5 2, labsize(large)) legend(rows(1) size(large)) xlabel(20(10)70) xscale(range(20 70)) yscale(range(0 2))
if (Mortg==1 & graphexp==1)  {
	graph export "$graphPath\CrossSectDebtDistr_M.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\CrossSectDebtDistr_C.pdf", replace           
}


* Total vs. Counterfactual
gen debt_smooth_poly_sc = debt_smooth_poly/(5*1000000000) 
gen debt_counterf_smooth_poly_sc = debt_counterf_smooth_poly/(5*1000000000) 
*qui graph bar (sum) debt_smooth_poly_sc debt_counterf_smooth_poly_sc if ctrygrp=="Cont", over(age, relabel(2" "3" "4" "5" "6" "7" "8" "9" "10" "12" "13" "14" "15" "16" "17" "18" "19" "20" "22" "23" "24" "25" "26" "27" "28" "29" "30" "32" "33" "34" "35" "36" "37" "38" "39" "40" "42" "43" "44" "45" "46" "47" "48" "49" "50" ")) /*
**/ over(incgrp, label(labsize(large)) gap(1500) relabel(1 "Low" 2 "Medium" 3 "High")) bar(1, fcolor(blue*0.3) lcolor(blue*0.3)) bar(2, fcolor(black) lcolor(black)) ytitle(in EUR bn) legend(on order(1 "Level" 2 "Counterfactual")) graphregion(color(white)) ylabel(, labsize(large)) 
drop temp*
bysort age: egen temp = sum(debt_smooth_poly_sc) 
bysort age: egen temp2 = sum(debt_counterf_smooth_poly_sc)
replace temp=temp*(5*1000000000)/totdebt*100 
replace temp2=temp2*(5*1000000000)/totdebt*100 

twoway (line temp age , lcolor(blue*5) lwidth(medthick)) (line temp2 age, lcolor(blue*1.2) lpattern(shortdash) lwidth(medthick)),  ytitle(in % of aggregate debt, size(large)) xtitle(Age, size(large)) legend(order(1 "Level" 2 "Counterfactual"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(0 1 2 3 4, labsize(large)) legend(rows(1) size(large)) xlabel(20(10)70) xscale(range(20 70)) yscale(range(0 4))
if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\CrossSectDebtDistrCounterf_M.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\CrossSectDebtDistrCounterf_C.pdf", replace
}


* -------------------------------------------------------
* Smoothing procedure
if (ForCharts==1 & Mortg == 1) {
	
	gen debt_raw_sc = debt/(5*1000000000)
	collapse (sum) debt_counterf_smooth_poly_sc debt_raw_sc, by(age incgrp)
	
	* Low income
	twoway (line debt_counterf_smooth_poly_sc age if incgrp==0, lcolor(blue*1.2) lpattern(shortdash)) (line debt_raw_sc age if incgrp==0, lcolor(black)), xtitle(Age) legend(on order(1 "Smoothed" 2 "Raw Data")) graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large))  
	graph export "$graphPath\SmoothRaw_M_low.pdf", replace
	* Medium income
	twoway (line debt_counterf_smooth_poly_sc age if incgrp==1, lcolor(blue*1.2) lpattern(shortdash)) (line debt_raw_sc age if incgrp==1, lcolor(black)), xtitle(Age) legend(on order(1 "Smoothed" 2 "Raw Data")) graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large))  
	graph export "$graphPath\SmoothRaw_M_medium.pdf", replace
	* High income
	twoway (line debt_counterf_smooth_poly_sc age if incgrp==2, lcolor(blue*1.2) lpattern(shortdash)) (line debt_raw_sc age if incgrp==2, lcolor(black)), xtitle(Age) legend(on order(1 "Smoothed" 2 "Raw Data")) graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large))  
	graph export "$graphPath\SmoothRaw_M_high.pdf", replace
	
	STOP

}
* -------------------------------------------------------



* ---------------------------------------------------------------------------------------------------------

* Keep only relevant variables
replace newdebt = newdebt_smooth3_poly_sm
replace intrpaym = intrpaym_smooth
replace repaym = repaym_smooth_poly
replace debt = debt_smooth_poly
replace repaym_ratio = repaym_ratio2_smooth_poly
replace intr_ratio = intr_ratio_smooth_poly_sm
keep age debt newdebt intrpaym repaym incgrp wealthgrp ctrygrp repaym_ratio intr_ratio
* ---------------------------------------------------------------------------------------------------------


* Some "quality checks"
replace repaym_ratio=0 if repaym_ratio<0    
replace intrpaym=0 if intrpaym<0   

* Some Graphs
* Repayment Ratios
*graph bar (mean) repaym_ratio*, over(age) by(incgrp)    over(ctrygrp)
*graph bar (mean) repaym_ratio*, over(age) by(wealthgrp) over(ctrygrp)
*graph bar (median) repaym_ratio*, over(age) by(incgrp)    over(ctrygrp)
*graph bar (median) repaym_ratio*, over(age) by(wealthgrp) over(ctrygrp)
* New Debt
*graph bar (mean) newdebt, over(age) by(incgrp)    over(ctrygrp)
*graph bar (mean) newdebt, over(age) by(wealthgrp) over(ctrygrp)
*graph bar (median) newdebt, over(age) by(incgrp)    over(ctrygrp)
*graph bar (median) newdebt, over(age) by(wealthgrp) over(ctrygrp)

*graph bar (mean) intr_ratio, over(age) by(incgrp)    over(ctrygrp)
*graph bar (mean) intr_ratio, over(age) by(wealthgrp) over(ctrygrp)
*graph bar (median) intr_ratio, over(age) by(incgrp)    over(ctrygrp)
*graph bar (median) intr_ratio, over(age) by(wealthgrp) over(ctrygrp)


* ---------------------------------------------------------------------------------------------------------
* Generate Distribution
* 1) control for HICP trend
sort ctrygrp age
if Mortg==1 {
	merge ctrygrp age using DebtScaleFactors_M.dta
}
if Mortg==0 {
	merge ctrygrp age using DebtScaleFactors_C.dta 
}
drop _merge

*clonevar newdebt_orig = newdebt
replace newdebt=newdebt/scaletrend
*graph bar (sum) newdebt*, over(age)

* Scale by total debt
replace newdebt=0 if newdebt<0
bysort ctrygrp: egen totnewdebt=sum(newdebt)
gen double relnewdebt=newdebt/totnewdebt
replace relnewdebt=0 if relnewdebt==.

keep age incgrp wealthgrp ctrygrp relnewdebt repaym_ratio intr_ratio
compress
* ---------------------------------------------------------------------------------------------------------


* ---------------------------------------------------------------------------------------------------------

* Add ages for 70+ to complete the data
local new = _N + 30
set obs `new'
gen ind=(age==.)
sort ind
by ind: gen t=_n
egen maxage=max(age)
replace age=maxage+t if age==.
drop maxage ind t
replace incgrp=1 if incgrp==.
replace wealthgrp=1 if wealthgrp==.
replace ctrygrp="Med" if ctrygrp==""
fillin age incgrp wealthgrp ctrygrp
drop _fillin

* Artificially keep the repayment rate of 65+ at 65+ level
sort incgrp wealthgrp ctrygrp age
replace relnewdebt=0 if age>=maxage
by incgrp wealthgrp ctrygrp: replace repaym_ratio=repaym_ratio[51] if age>maxage
by incgrp wealthgrp ctrygrp: replace intr_ratio=intr_ratio[51] if age>maxage

bysort ctrygrp: egen double temp_sum=sum(relnewdebt)
replace relnewdebt=relnewdebt/temp_sum
drop temp_sum

* Save data to file
compress
sort ctrygrp age incgrp wealthgrp

if Mortg==1 {
	saveold NewDebtDistr_M.dta, replace
}
if Mortg==0 {
	saveold NewDebtDistr_C.dta, replace
}


* ---------------------------------------------------------------------------------------------------------
* Export graphs for paper
* ---------------------------------------------------------------------------------------------------------

* Some data preparation
drop if age>maxage
clonevar repaym_ratio_mean= repaym_ratio
rename repaym_ratio repaym_ratio_med
collapse (mean) repaym_ratio_mean (median) repaym_ratio_med (sum) relnewdebt, by(age incgrp)


*qui graph bar (median) repaym_ratio_med, over(age, relabel(2" "3" "4" "5" "6" "7" "8" "9" "10" "12" "13" "14" "15" "16" "17" "18" "19" "20" "22" "23" "24" "25" "26" "27" "28" "29" "30" "32" "33" "34" "35" "36" "37" "38" "39" "40" "42" "43" "44" "45" "46" "47" "48" "49" "50" ")) /*
**/ over(incgrp, label(labsize(large)) gap(1200) relabel(1 "Low" 2 "Medium" 3 "High")) bar(1, fcolor(blue*1.2) lcolor(blue*1.2)) bar(2, fcolor(black) lcolor(black)) ytitle(Repayments / Outstanding Debt) graphregion(color(white)) ylabel(, labsize(large))
twoway (line repaym_ratio_med age if incgrp==0, lcolor(blue*5) lwidth(medthick)) (line repaym_ratio_med age if incgrp==1, lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line repaym_ratio_med age if incgrp==2, lcolor(blue*0.3) lwidth(medthick)),  ytitle(Repayments / Outstanding Debt, size(large)) xtitle(Age, size(large)) legend(order(1 "Low" 2 "Medium" 3 "High"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1) size(large)) xlabel(20(10)70) xscale(range(20 70))

if (Mortg==1  & graphexp==1) {
	graph export "$graphPath\RepaymRatMed_M.pdf", replace
}
if (Mortg==0  & graphexp==1) {
	graph export "$graphPath\RepaymRatMed_C.pdf", replace
}

*qui graph bar (mean) repaym_ratio, over(age, relabel(2" "3" "4" "5" "6" "7" "8" "9" "10" "12" "13" "14" "15" "16" "17" "18" "19" "20" "22" "23" "24" "25" "26" "27" "28" "29" "30" "32" "33" "34" "35" "36" "37" "38" "39" "40" "42" "43" "44" "45" "46" "47" "48" "49" "50" ")) /*
**/ over(incgrp, label(labsize(large)) gap(1200) relabel(1 "Low" 2 "Medium" 3 "High")) bar(1, fcolor(blue*1.2) lcolor(blue*1.2)) bar(2, fcolor(black) lcolor(black)) ytitle(Repayments / Outstanding Debt) graphregion(color(white)) ylabel(, labsize(large))
twoway (line repaym_ratio_mean age if incgrp==0, lcolor(blue*5) lwidth(medthick)) (line repaym_ratio_mean age if incgrp==1, lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line repaym_ratio_mean age if incgrp==2, lcolor(blue*0.3) lwidth(medthick)),  ytitle(Repayments / Outstanding Debt, size(large)) xtitle(Age, size(large)) legend(order(1 "Low" 2 "Medium" 3 "High"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1) size(large)) xlabel(20(10)70) xscale(range(20 70))

if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\RepaymRatMean_M.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\RepaymRatMean_C.pdf", replace
}


* ------------------------------------------------
* New debt distribution: by INCOME
replace relnewdebt = relnewdebt*100/6

twoway (line relnewdebt age if incgrp==0, lcolor(blue*5) lwidth(medthick)) (line relnewdebt age if incgrp==1, lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line relnewdebt age if incgrp==2, lcolor(blue*0.3) lwidth(medthick)),  ytitle(in % of aggregate new debt, size(large)) xtitle(Age, size(large)) legend(order(1 "Low" 2 "Medium" 3 "High"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1) size(large)) xlabel(20(10)70) xscale(range(20 70))

if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\RelNewDebt_M_incgrp.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\RelNewDebt_C_incgrp.pdf", replace
}


* ------------------------------------------------
* New debt distribution: by WEALTH
if Mortg==1 {
	use NewDebtDistr_M.dta, replace
}
if Mortg==0 {
	use NewDebtDistr_C.dta, replace
}
drop if age>maxage
collapse (sum) relnewdebt, by(age wealthgrp)
replace relnewdebt = relnewdebt*100/6

twoway (line relnewdebt age if wealthgrp==0, lcolor(blue*5) lwidth(medthick)) (line relnewdebt age if wealthgrp==1, lcolor(blue*1.2) lpattern(longdash) lwidth(medthick)) (line relnewdebt age if wealthgrp==2, lcolor(blue*0.3) lwidth(medthick)),  ytitle(in % of aggregate new debt, size(large)) xtitle(Age, size(large)) legend(order(1 "Low" 2 "Medium" 3 "High"))/*
*/ graphregion(color(white)) xlabel(, labsize(large))  ylabel(, labsize(large)) legend(rows(1) size(large)) xlabel(20(10)70) xscale(range(20 70))

if (Mortg==1 & graphexp==1) {
	graph export "$graphPath\RelNewDebt_M_wealthgrp.pdf", replace
}
if (Mortg==0 & graphexp==1) {
	graph export "$graphPath\RelNewDebt_C_wealthgrp.pdf", replace
}
