
* ------------------------------------------------------------------------------------
* This is a master file generating the updated debt distributions
set more off

global basePath "C:\Users\vogeled\Desktop\MonPol Heterogeneity\DebtDistributionUpdate"


global graphPath "$basePath\figures\graphs_debtsimul"  
cd "${basePath}"
do BaseYearsAssetsLiabilities.do
* ------------------------------------------------------------------------------------


* ------------------------------------------------------------------------------------
* Set Variables 
qui sca Mortg = 1		/* =1 computation for mortgages, otherwise consumer loans */
qui sca ForCharts = 0	/* =1 2 charts for paper/presentation - backfitting */
qui sca maxage = 70		/* maximum age to cut off new debt (age>maxage= 0 new debt)*/
qui sca graphexp = 0	/* =1 save graphs, otherwise graphs only shown*/
qui sca datadownl = 0	/* =1 new data donwnloaded, otherwise old data used*/	
* ------------------------------------------------------------------------------------


* ------------------------------------------------------------------------------------
* Data Preparation

* 1) Prepare HH debt data from Quaterl. Accounts
if datadownl==1 {
	do SDW_download_HH_Loans.do
}
do Prepare_Loans.do

* 2) Inflation rates for some adjustment of nominal values
if datadownl==1 {
	do SDW_download_HICP.do
}
do Prepare_HICP.do

* 3) Prepare MIR data
if datadownl==1 {
	do SDW_download_IntRates.do
}
do Prepare_IntRates.do

* 4) Generate new debt distribution
do Gen_NewDebtDistr.do

* 5) Prepare data for cell based distribution
do PrepareDataForCellBasedOnly.do

* 6) Merge interest rate and loan data
if Mortg==1 {
	use IntRates_M.dta, clear
	sort sa0100 date
	merge sa0100 date using Loans_M.dta
}
if Mortg==0 {
	use IntRates_C.dta, clear
	sort sa0100 date
	merge sa0100 date using Loans_C.dta
}
drop if _merge==1
drop _merge date
sort sa0100 currentdate
compress
if Mortg==1 {
	saveold LoanIntrData_M.dta, replace
}
if Mortg==0 {
	saveold LoanIntrData_C.dta, replace
}

* Manual adjustment for interest rate FI (N/A in HFCN)
gen temp=intr_var if (sa0100=="FI" & currentdate==stSmplAsstNum_FI)
egen temp2=mean(temp)
sca intr_FI = temp2
drop temp*
* ------------------------------------------------------------------------------------


* ------------------------------------------------------------------------------------
* 7) Update forward and backward
do UpdateDebtDistr.do
* ------------------------------------------------------------------------------------


* ------------------------------------------------------------------------------------
* 8) Charts
do Eval_Results_Graphs.do
* ------------------------------------------------------------------------------------
