* ------------------------------------------------------
* Step 1: Generate initial aggregates by cell 
set more off
use "D_compl.dta", clear
*keep if im0100==1
*keep if sa0100=="AT"

drop if dhageh1<20
do GenGrouping.do
collapse (sum) debt intrpaym repaym [aweight=hw0010], by(sa0100 dhageh1 incgrp wealthgrp)
fillin dhageh1 incgrp wealthgrp sa0100
do CtryGrouping.do
rename debt totcelldebt
rename intrpaym totcellintrpaym
rename repaym totcellrepaym
bysort sa0100: egen totaggdebt = sum(totcelldebt)
bysort sa0100: egen totaggintrpaym = sum(totcellintrpaym)
bysort sa0100: egen totaggrepaym = sum(totcellrepaym)
replace totcelldebt = 0 if totcelldebt==.
replace totcellintrpaym = 0 if totcellintrpaym==.
replace totcellrepaym = 0 if totcellrepaym==. 
drop _fillin
sort sa0100 dhageh1 incgrp wealthgrp
compress
* ------------------------------------------------------


* ------------------------------------------------------
* Step 1: Merge with distribution of new debt 
clonevar age=dhageh1
*do CtryGrouping.do
sort ctrygrp age incgrp wealthgrp 
if Mortg==1 { 
	merge ctrygrp age incgrp wealthgrp using NewDebtDistr_M.dta
}
if Mortg==0 { 
	merge ctrygrp age incgrp wealthgrp using NewDebtDistr_C.dta
}
drop _merge
compress
* Set values for agents w/o observations
replace relnewdebt=0 if age<20
replace intr_ratio=0 if age<20
replace repaym_ratio=0 if age<20
*drop if sa0100=="FI"
drop if sa0100==""
keep relnewdebt repaym_ratio intr_ratio age totaggrepaym totaggintrpaym totaggdebt totcellrepaym totcellintrpaym totcelldebt ctrygrp repaym wealthgrp incgrp sa0100

compress
* ------------------------------------------------------


* ------------------------------------------------------
* Step 2: Set initial values and assumptions about targets

* a) Index of debt aggregates (from flows)
*sort sa0100
*if Mortg==1 { 
*	merge sa0100 using DebtIndexFinal_M.dta
*}
*if Mortg==0 {
*	merge sa0100 using DebtIndexFinal_C.dta
*}
*drop _merge
*drop if age==.
*sca upperb = tmax
*global upperb = tmax


* b) Interest rates
gen double intr_t0 = totcellintrpaym/totcelldebt
replace intr_t0=.    if intr_t0<=0
replace intr_t0=.    if intr_t0>0.15
* Impute missing with avg. of non-missings
gen agegrp=.
replace agegrp=1 if age<30
replace agegrp=2 if age>=30 & age<55
replace agegrp=3 if age>=55
bysort sa0100 agegrp: egen temp=mean(intr_t0)
replace intr_t0=temp if intr_t0==.
drop temp agegrp

* Manual correction for FI: just arbitrary values for smoothing alg. to work
* Will be later replaced by MIR data
replace intr_t0 = uniform()/10 if sa0100=="FI"

*sort sa0100
*if Mortg==1 { 
	*merge sa0100 using IntrRateFinal_M.dta
*}
*if Mortg==0 { 
	*merge sa0100 using IntrRateFinal_C.dta
*}
*drop _merge
*drop if age==.


* Smooth data
do SmoothCrossSection.do
replace totcelldebt = totcelldebt_sm

* Another manual correctin for FI
replace intr_t0_sm = 9999999 if sa0100=="FI"
replace intr_ratio = intr_t0_sm


* ------------------------------------------------------
* Compare two distributions
*egen double temp=sum(totcelldebt)
*replace totcelldebt = totcelldebt/temp
*replace totcelldebt_sm = totcelldebt_sm/temp

*sort totcelldebt
*gen t=_n
*sort t
*gen double totcelldebt_cdf=totcelldebt if _n==1
*replace totcelldebt_cdf=totcelldebt_cdf[_n-1]+totcelldebt if _n>1
*save test_dist_temp.dta, replace
*line totcelldebt_cdf t
*drop totcelldebt_cdf t

*sort totcelldebt_sm
*gen t=_n
*sort t
*gen double totcelldebt_cdf_sm=totcelldebt_sm if _n==1
*replace totcelldebt_cdf_sm=totcelldebt_cdf_sm[_n-1]+totcelldebt_sm if _n>1
*line totcelldebt_cdf_sm t

*merge t using test_dist_temp.dta
*drop _merge
*sort t

*line totcelldebt_cdf totcelldebt_cdf_sm t, legend(order(1 "Raw Data" 2 "Smooth Distribution"))
* ------------------------------------------------------


* Set Initial Values: 
	* AGGREGATES

	* Debt Levels
	*gen double totaggdebt_t0 = 0
	*replace totaggdebt_t0 = totaggdebt if t0==0
	* Repayments
	*gen double totaggrepaym_t0 = 0
	*replace totaggrepaym_t0 = totaggrepaym if t0==0
	* Interest Payments
	*gen double totaggintrpaym_t0 = 0
	*replace totaggintrpaym_t0 = totaggintrpaym if t0==0

	* CELL AGGREGATES

	* Debt Levels
	*gen double totcelldebt_t0  = 0
	*replace totcelldebt_t0 = totcelldebt if t0==0
	* Repayments
	*gen double totcellrepaym_t0 = 0
	*replace totcellrepaym_t0 = totcellrepaym if t0==0
	* Interest Payments
	*gen double totcellintrpaym_t0 = 0
	*replace totcellintrpaym_t0 = totcellintrpaym if t0==0

* ------------------------------------------------------


* ------------------------------------------------------
collapse (mean) /* 
*/ repaym_ratio intr_ratio /* 
*/ totcelldebt totcellintrpaym totcellrepaym /*
*/ totaggdebt   totaggintrpaym   totaggrepaym   /*
*/ relnewdebt, /*
*/ by(sa0100 age incgrp wealthgrp)
* ------------------------------------------------------


* ------------------------------------------------------
* Generate aggregate initial debt for 20 year old guys
gen double age20inidebt = totcelldebt if age==20
* ------------------------------------------------------


* ------------------------------------------------------
* Save data
rename intr_ratio intr
rename totcelldebt celldebt
keep sa0100 incgrp wealthgrp age repaym intr celldebt relnewdebt age20inidebt

compress
if Mortg==1 { 
	saveold CellBasedData_M.dta, replace
	keep sa0100 incgrp wealthgrp age repaym_ratio relnewdebt
	saveold NewDebtDistr_M.dta, replace
}
if Mortg==0 { 
	saveold CellBasedData_C.dta, replace
	keep sa0100 incgrp wealthgrp age repaym_ratio relnewdebt
	saveold NewDebtDistr_C.dta, replace
}
* ------------------------------------------------------


