* -----------------------------------------------------------
* Load HICP data
use HICP_all.dta, clear
gsort - PERIOD_NAME
set more off


local new = _N + 80
set obs `new'

destring PERIOD_NAME, gen(date)
replace date=. if _n>1
replace date=date[_n-1]-1 if _n>1
egen temp=max(date)
gen diff = temp-date
drop if diff>100
drop temp diff
compress

tsset date
gsort -date
gen age = 35 if _n==1
replace age = age[_n-1]+1  if _n>1

local ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of local ctrylist {
	tssmooth ma infl_`ii' = VAL_`ii' , window(5 1 5)
	gen t=_n
	replace t=. if VAL_`ii'==.
	gsort -t
	gen temp = infl_`ii' if _n==1
	egen temp2=mean(temp)
	gsort -date
	replace infl_`ii'=temp2 if t==.
	drop t temp*
}

local new = _N + 15
set obs `new'

gsort -age
gen age2 = 34 if age==.
replace age2=age2[_n-1]-1 if age2[_n-1]!=.
replace age = age2 if age==.
drop age2
sort age

local ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of local ctrylist {

	* Adjust for duration of loans: Mortages
	if Mortg==1 {
		* Index based on borrowing at 35
		gen temp = infl_`ii' if age==35
		egen temp2=mean(temp)
		replace infl_`ii' = temp2 if infl_`ii'==.
		drop temp*
		gen ind_`ii'=1 if _n==1
		replace ind_`ii'=ind_`ii'[_n-1]/(1+infl_`ii'[_n-1]/100) if _n>1
	
		gen temp_L13 = ind_`ii'[_n-13]
		replace temp_L13 = 1 if temp_L13==.
		gen age_ind = (age>(35+13))
		sort age_ind age
		by age_ind: gen age_counter = _n
		gen temp_ind2 = (13-age_counter)/13*ind_`ii' + (age_counter)/13*temp_L13 
		replace temp_ind2 = temp_L13 if age_counter>13
		replace temp_ind2 = ind_`ii' if age_ind==0
		*line temp_ind2  ind_`ii' temp_L13 age if age<71
		
		replace ind_`ii' = temp_ind2
		*replace ind_`ii' = temp_L13
		drop temp_L13 age_ind temp_ind2 age_counter
	}
	* Adjust for duration of loans: Consumer loans
	if Mortg==0 {
		* Index based on borrowing at 35
		gen temp = infl_`ii' if age==35
		egen temp2=mean(temp)
		replace infl_`ii' = temp2 if infl_`ii'==.
		drop temp*
		gen ind_`ii'=1 if _n==1
	
		gen temp_L6 = ind_`ii'[_n-6]
		replace temp_L6 = 1 if temp_L6==.
		gen age_ind = (age>(35+13))
		sort age_ind age
		by age_ind: gen age_counter = _n
		gen temp_ind2 = (6-age_counter)/6*ind_`ii' + (age_counter)/6*temp_L6  
		replace temp_ind2 = temp_L6 if age_counter>6
		replace temp_ind2 = ind_`ii' if age_ind==0
		*line temp_ind2  ind_`ii' temp_L13 age if age<71
	
		replace ind_`ii' = temp_ind2
		*replace ind_`ii' = temp_L6
		drop temp_L6 age_ind temp_ind2 age_counter
		* NO CORRECTION FOR CONS.LOANS
		replace ind_`ii' = 1
	}
	
}
drop if age>80
keep ind_* age

reshape long ind_, i(age) j(sa0100, string)  
rename ind_ ind
sort sa0100 age
compress


if Mortg==1 {
	saveold HICP_M_temp.dta, replace
}
if Mortg==0 {
	saveold HICP_C_temp.dta, replace
}

* -----------------------------------------------------------


* -----------------------------------------------------------
* Country data for weighting
use F41F42.dta, clear
rename  ctryid sa0100
gen ind=( PERIOD_NAME=="2013Q3" | PERIOD_NAME=="2013Q2" | PERIOD_NAME=="2013Q1" |  PERIOD_NAME=="2012Q4")
drop if ind==0
keep  PERIOD_NAME bs_* sa0100

if Mortg==1 {
	gen val =  bs_F42 
}
if Mortg==0 {
	gen val =  bs_F41 
}
collapse (mean) val, by(sa0100)
sort sa0100
saveold HICP_weighting_temp.dta, replace

if Mortg==1 {
	use HICP_M_temp.dta, clear
	erase HICP_M_temp.dta
}
if Mortg==0 {
	use HICP_C_temp.dta, clear
	erase HICP_C_temp.dta
}

merge sa0100 using HICP_weighting_temp.dta
erase HICP_weighting_temp.dta
drop _merge
gen double weightedind=ind*val

do CtryGrouping.do
drop if ctrygrp == " "
collapse (sum) weightedind, by(ctrygrp age)
gen temp=weightedind if age==20 
bysort ctrygrp: egen temp2=mean(temp)
replace weightedind=weightedind/temp2
drop temp*
rename weightedind scaletrend
compress
sort ctrygrp age
drop if age>70


if Mortg==1 {
	saveold DebtScaleFactors_M.dta, replace
}
if Mortg==0 {
	saveold DebtScaleFactors_C.dta, replace
}
* -----------------------------------------------------------
