set more off
use F41F42.dta, clear
gen bs_F40 = bs_F42 + bs_F41
gen tr_F40 = tr_F42 + tr_F41
gen val_F40 = val_F41 + val_F42 
do BaseYearsAssetsLiabilities.do

rename ctryid sa0100

* Generate base year indicators
gen baseyear = 0
local ctrylist "ES FI GR FR NL PT BE CY SK IT LU MT SI AT DE"
foreach ii of local ctrylist {
	replace baseyear=1 if (PERIOD_NAME==stSmplAsst_`ii' & sa0100=="`ii'")
}
rename PERIOD_NAME date
drop if  sa0100=="EE" | sa0100=="IE"
compress


* ------------------------------------------------------
if ForCharts==1 {
* For charts
	do CtryGrouping.do
	drop sa0100
	rename ctrygrp sa0100
	collapse (sum) bs_F* tr_F* val_F*, by(sa0100 date)
	gen baseyear=1 if date=="2011Q1"
}
* ------------------------------------------------------


* Set baseyear + eliminate data if not needed
gen bs_F42_ns = bs_F42 if baseyear==1
gen bs_F41_ns = bs_F41 if baseyear==1
gen bs_F40_ns = bs_F40 if baseyear==1

* drop date before 2008
split date, parse(Q) gen(date)
destring date1, replace
destring date2, replace
gen currentdate=date1*10+date2
drop if currentdate<20074
gen date4=currentdate if baseyear==1
bysort sa0100: egen basedate=mean(date4)
drop date1 date4
rename date2 quarter

gen postbase = (currentdate>=basedate)	

* Generate stock from flows / index
local nacelist "F42 F41 F40"
foreach ii of local nacelist {

	* Variable with value for base year
	bysort sa0100: egen bs_`ii'_baseyear = max(bs_`ii'_ns)

	* Generate stocks from flows
	sort sa0100 postbase currentdate
	by sa0100 postbase: replace bs_`ii'_ns = bs_`ii'_ns[_n-1] + tr_`ii' if _n>1
	replace postbase=0 if baseyear==1
	gsort sa0100 postbase -currentdate
	by sa0100 postbase: replace bs_`ii'_ns = bs_`ii'_ns[_n-1] - tr_`ii'[_n-1] if _n>1 & postbase==0
	replace postbase=1 if baseyear==1
	
	* Smooth data
	gen bs_`ii'_ns_sm = .
	levelsof sa0100,local(ctrylist)
	foreach ij of local ctrylist {
		gen temp_data = bs_`ii'_ns if sa0100=="`ij'"
		lowess temp_data currentdate, generate(temp_smooth_var) nograph adjust
		replace bs_`ii'_ns_sm = temp_smooth_var if (sa0100=="`ij'")
		drop temp_smooth_var temp_data
	}
	* Variable with value for base year SMOOTHED
	gen temp = bs_`ii'_ns_sm if baseyear==1
	bysort sa0100: egen bs_`ii'_baseyear_sm = max(temp)
	drop temp
	
	* Generate Index
	gen ind_`ii'_sm = bs_`ii'_ns_sm/bs_`ii'_baseyear_sm
	gen ind_`ii' = bs_`ii'_ns/bs_`ii'_baseyear
 	
}

drop if currentdate<20081
keep date ind_* sa0100 basedate baseyear currentdate 
compress


* ------------------------------------------------------
* Set Base Variable
if Mortg==1 {
	gen debt_var = ind_F42_sm  /* mortg.  */
}
if Mortg==0 {
	gen debt_var = ind_F41_sm  /* consumption  */
}
* ------------------------------------------------------

gen temp1 = debt_var if currentdate==20081
bysort sa0100: egen min_ind=mean(temp1)
gen temp2 = debt_var if currentdate==20132
bysort sa0100: egen plot_ind  = mean(temp2)
gen plot_min_ratio = (plot_ind/min_ind-1)*100

graph hbar (mean) plot_min_ratio , over(sa0100) graphregion(color(white))  ytitle("percentage change 2013Q2-2008Q1", size(large))  bar(1, color(blue*1.2)) ylabel(, labsize(large)) 

tab sa0100, su(plot_min_ratio)

if (Mortg==1 & graphexp==1 & ForCharts==0) {
	graph export "$graphPath\Change_M_Debt.pdf", as(pdf) replace 
}
if (Mortg==0 & graphexp==1 & ForCharts==0) {
	graph export "$graphPath\Change_C_Debt.pdf", replace
}


if ForCharts==1 {
	keep currentdate debt_var sa0100
	rename debt_var debt_var_
	reshape wide debt_var_, i(currentdate) j(sa0100, string)
	local ctrylist = "Cont DE ES FR IT Med"
	
	twoway (line debt_var_Cont currentdate, lcolor(blue*1.2) lwidth(medthick) ) /*
	*/ (line debt_var_DE currentdate,  lcolor(blue*5)        lwidth(medthick) ) /*
	*/ (line debt_var_ES currentdate,  lcolor(blue*0.3)      lwidth(medthick) ) /*
	*/ (line debt_var_FR currentdate,  lcolor(blue*1.2)      lwidth(medthick) lpattern(shortdash)) /*
	*/ (line debt_var_IT currentdate,  lcolor(blue*5)        lwidth(medthick) lpattern(shortdash)) /*
	*/ (line debt_var_Med currentdate, lcolor(blue*0.3)      lwidth(medthick) lpattern(shortdash)) /*	
	*/,  ytitle("Debt Index (2011Q1=1)", size(large)) legend(rows(2) order(1 "Continental" 2 "DE" 3 "ES" 4 "FR" 5 "IT" 6 "Mediterranean")) xtitle("Date", size(large)) /*
	*/  graphregion(color(white)) ylabel(, labsize(large)) xlabel(, labsize(large)) xlabel(20081 "08Q1" 20091 "09Q1" 20101 "10Q1" 20111 "2011Q1" 20121 "12Q1" 20131 "13Q1")
	
	if (Mortg==1 & graphexp==1) {
		graph export "$graphPath\AggDebtInd_CtryGrp_M.pdf", as(pdf) replace 
	}
	if (Mortg==0 & graphexp==1) {
		graph export "$graphPath\AggDebtInd_CtryGrp_C.pdf", as(pdf) replace
	}
	STOP
}

compress
sort sa0100 date
rename debt_var debt_ind
drop ind_*
keep sa0100 currentdate debt_ind date
compress
sort sa0100 date

if Mortg==1 {
	saveold Loans_M.dta, replace
}
if Mortg==0 {
	saveold Loans_C.dta, replace
}

