* --------------------------------------------------
* This file uses SDW codes to download wage data
* --------------------------------------------------

* Clear Memory
capture log close
clear
set more off

* Set source
set more off
odbc query "sdw", user(pub) password(pub)


* --------------------------------------------------
* Import Country by Country Property Prices
* Step 1: download series
* Step 2: rename OBS_VAL to country specific value
* Step 3: sort by date (to merge) and save
* --------------------------------------------------

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {

	local nacelist ="F42 F41"
	foreach ij of local nacelist {
	* Closing Balance Sheet
	clear
	odbc load,/*
	*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'IEAQ.Q.`ii'.N.V.LE.`ij'.S1M.A1.S.2.N.N.Z',obs_value,null)) val_`ii'_`ij' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_IEAQ_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('IEAQ.Q.`ii'.N.V.LE.`ij'.S1M.A1.S.2.N.N.Z') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
	sort PERIOD_NAME
	compress
	save bs_`ii'_`ij'.dta, replace	
	
	* Transactions
	clear
	odbc load,/*
	*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'IEAQ.Q.`ii'.N.V.F.`ij'.S1M.A1.S.2.N.N.Z',obs_value,null)) val_`ii'_`ij' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_IEAQ_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('IEAQ.Q.`ii'.N.V.F.`ij'.S1M.A1.S.2.N.N.Z') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
	sort PERIOD_NAME
	compress
	save tr_`ii'_`ij'.dta, replace	
	
	* Other / Valuation
	clear
	odbc load,/*
	*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'IEAQ.Q.`ii'.N.V.LO.`ij'.S1M.A1.S.2.N.N.Z',obs_value,null)) val_`ii'_`ij' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_IEAQ_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('IEAQ.Q.`ii'.N.V.LO.`ij'.S1M.A1.S.2.N.N.Z') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
	sort PERIOD_NAME
	compress
	save val_`ii'_`ij'.dta, replace
	}
}
clear
* --------------------------------------------------


* --------------------------------------------------
* Merge Data INTO Country Files
global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {

	* Load Closing BS F42
	use bs_`ii'_F42.dta, clear
	rename VAL_`ii'_F42 bs_F42
	rm bs_`ii'_F42.dta
	* Merge Closing BS F41
	merge PERIOD_NAME using bs_`ii'_F41.dta
	drop _merge
	rename VAL_`ii'_F41 bs_F41
	rm bs_`ii'_F41.dta
	sort PERIOD_NAME	
	
	local bsitemlist ="F42 F41"
	foreach ij of local bsitemlist {
		* Merge Transactions
		merge PERIOD_NAME using tr_`ii'_`ij'.dta
		drop _merge
		rename VAL_`ii'_`ij' tr_`ij'
		rm tr_`ii'_`ij'.dta
		sort PERIOD_NAME
	
		* Merge Other / Valuation
		merge PERIOD_NAME using val_`ii'_`ij'.dta
		drop _merge
		rename VAL_`ii'_`ij' val_`ij'
		rm val_`ii'_`ij'.dta
		sort PERIOD_NAME						
	}

	gen ctryid = "`ii'"
	sort ctryid PERIOD_NAME
	save temp_`ii'.dta, replace
}
* --------------------------------------------------



* --------------------------------------------------
* Merge Country Files
use temp_AT.dta, clear
rm temp_AT.dta
global ctrylist = "NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
		append using temp_`ii'.dta
		rm temp_`ii'.dta
}
label variable bs_F41 "Short-term loans (consumption)"
label variable bs_F42 "Long-term loans (housing)"
compress
saveold F41F42.dta, replace
*clear
* --------------------------------------------------



