* --------------------------------------------------
* This file uses SDW codes to download HICP data
* --------------------------------------------------

* Clear Memory
capture log close
clear
set more off

* Set source
odbc query "sdw", user(pub) password(pub)


* --------------------------------------------------
* Import Country by Country Property Prices
* Step 1: download series
* Step 2: rename OBS_VAL to country specific value
* Step 3: sort by date (to merge) and save
* --------------------------------------------------


global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
	clear
	odbc load,/*
	*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ICP.A.`ii'.N.000000.4.AVR',obs_value,null)) val_`ii' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ICP_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('ICP.A.`ii'.N.000000.4.AVR') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
compress
save HICP_`ii'.dta, replace	
}
* --------------------------------------------------


* --------------------------------------------------
* Merge Data
use HICP_AT.dta, clear
global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
		merge PERIOD_NAME using HICP_`ii'.dta
		rm HICP_`ii'.dta
		drop _merge
		sort PERIOD_NAME
		display "`ii' matched"
}
* --------------------------------------------------


* --------------------------------------------------
* save intermediate restult
saveold HICP_all.dta, replace
* --------------------------------------------------


* --------------------------------------------------
* Pick only quarter-end values
gen date_test = monthly(PERIOD_NAME, "YM")
format date_test %tm

gen temp_y= yofd(dofm(date_test))
format temp_y %ty
gen temp_q= qofd(dofm(date_test))
format temp_q %tq

sort temp_q date_test
by temp_q: gen t=_n
keep if t==3

sort temp_y temp_q
list temp_y temp_q
drop t
by temp_y: gen t=_n
gen qind="Q1" if t==1
replace qind="Q2" if t==2
replace qind="Q3" if t==3
replace qind="Q4" if t==4

gen y_str = string(temp_y)

replace PERIOD_NAME = y_str + qind
* --------------------------------------------------


* --------------------------------------------------
* Rename Variables & Save
*rename PERIOD_NAME date
*reshape long VAL_, i(date) j(ctryid) string
*rename VAL_ HICP
*label variable HICP "End of quarter level of HICP"
*compress
*keep date ctryid HICP
*sort ctryid date
*saveold HICP_ALL.dta, replace
*clear
* --------------------------------------------------







