* ------------------------------------------------------------------------------------
* Forward looking part

* Loop over countries and time
do BaseYearsAssetsLiabilities.do

qui levelsof currentdate, local(datevec)
qui levelsof sa0100, local(countryvec)

foreach ii of local countryvec {

		foreach it of local datevec  {
		di " ----------------`it' ------------- "

		if `it'<stSmplAsstNum_`ii' {
			di " before start "
		}

		if `it'==stSmplAsstNum_`ii' {
			*di " in base year"
			if Mortg==1 {
				use CellBasedData_M.dta, clear
			}
			if Mortg==0 {
				use CellBasedData_C.dta, clear
			}
			keep if sa0100=="`ii'"
			
			* Manual adjustment for FI
			replace intr = intr_FI if sa0100=="FI"
			
			* Generate cell interest/repayments
			gen double cellintrpaym = celldebt*intr/4
			gen double cellrepaym = celldebt*repaym_ratio/4
			
			* Generate AGGREGATES
			egen double aggdebt = sum(celldebt)
			egen double aggintrpaym = sum(cellintrpaym)
			egen double aggrepaym = sum(cellrepaym)
			clonevar aggdebt_base = aggdebt
			keep sa0100 inc we age* cell* agg*
			gen currentdate=`it'
			gen basequarter = mod(currentdate,10)  /* set current quarter*/
			aorder
			sort sa0100 currentdate
			saveold Data_lastit.dta, replace
			sort sa0100 age inc we
			saveold Data_`ii'_`it'.dta, replace
		}

		if `it'>stSmplAsstNum_`ii' {
			di " ---------------------- "
			di " after base year "
			di " ---------------------- "

			* Use values from last period
			use Data_lastit.dta, clear

			* Generate aggregate debt of young guys (if age shifted)
			egen agg_age20inidebt = sum(age20inidebt)

			* Update year & genenerate index for age adjustment		
			replace currentdate=`it'	/* change date*/
			gen currentquarter = mod(currentdate,10)  /* set current quarter*/
			gen shift_ind = abs(currentquarter-basequarter)<0.01

			* Merge with interest rate and debt index data
			sort sa0100 currentdate		
			*merge sa0100 currentdate using IntrLoan_MatchTest.dta /* merge with aggregate debt index and interest rate */
			if Mortg==1 {
				merge sa0100 currentdate using LoanIntrData_M.dta /* merge with aggregate debt index and interest rate */
			}
			if Mortg==0 {
				merge sa0100 currentdate using LoanIntrData_C.dta /* merge with aggregate debt index and interest rate */
			}
			drop _merge
			
			* Merge with distribution of new debt
			sort sa0100 age inc we
			if Mortg==1 {
				merge sa0100 age inc we using NewDebtDistr_M.dta
			}
			if Mortg==0 {
				merge sa0100 age inc we using NewDebtDistr_C.dta
			}
			keep if sa0100=="`ii'"
			keep if _merge==3
			drop _merge

			* Update aggregates/cells
			gen double aggdebt_target = aggdebt_base*debt_ind
			gen double aggdebt_counterf = aggdebt + aggintrpaym - aggrepaym
			gen double aggdebt_NEW = aggdebt_target - aggdebt_counterf
			replace aggdebt_NEW = aggdebt_NEW - agg_age20inidebt*debt_ind if shift_ind==1 

			* CELL debt
			sort incgrp wealthgrp age
			gen double celldebt_NEW = aggdebt_NEW * relnewdebt
			gen double temp = celldebt + cellintrpaym - cellrepaym
			
			* Update according to change in age yes/no
			sort incgrp wealthgrp age
			replace celldebt = 0
			by incgrp wealthgrp: replace celldebt = temp[_n-1] if shift_ind==1	/* update age if jump of 4 quarter relative to base*/
			by incgrp wealthgrp: replace celldebt = temp       if shift_ind==0	/* loop "within" age if no full year*/

			* Debt of new young (age=20) cohort	
			replace celldebt = age20inidebt*debt_ind if age==20 & shift_ind==1 
			replace celldebt = celldebt + celldebt_NEW

			* CELL interest payments
			replace cellintrpaym = celldebt * intr_var/4
			* CELL repayments
			replace cellrepaym = celldebt * repaym_ratio/4
			replace cellrepaym = celldebt + cellintrpaym if age==99

			* AGGREGATE debt
			egen temp_aggdebt = sum(celldebt)
			replace aggdebt = temp_aggdebt
			egen temp_aggintrpaym = sum(cellintrpaym)
			replace aggintrpaym = temp_aggintrpaym
			egen temp_aggrepaym = sum(cellrepaym)
			replace aggrepaym = temp_aggrepaym
			drop temp_*
						
			* Save new data
			keep age age20inidebt aggdebt aggdebt_base aggintrpaym aggrepaym celldebt cellintrpaym cellrepaym currentdate incgrp sa0100 wealthgrp basequarter celldebt_NEW
			compress
			sort sa0100 age inc we
			saveold Data_`ii'_`it'.dta, replace
			drop celldebt_NEW
			saveold Data_lastit.dta, replace
		}
	}
	erase Data_lastit.dta
}
* ------------------------------------------------------------------------------------



* ------------------------------------------------------------------------------------
* Backward looking part
if Mortg==1 {
	use LoanIntrData_M.dta, clear  
}
if Mortg==0 {
	use LoanIntrData_C.dta, clear  
}
do BaseYearsAssetsLiabilities.do


qui local datevec "20111 20104 20103 20102 20101 20094 20093 20092 20091 20084 20083 20082 20081"
qui levelsof sa0100, local(countryvec)
foreach ii of local countryvec {

		foreach it of local datevec  {
		di " ----------------`it' ------------- "

		if `it'==stSmplAsstNum_`ii' {
			di " base year `ii' "
			if Mortg==1 {
				use CellBasedData_M.dta, clear
			}
			if Mortg==0 {
				use CellBasedData_C.dta, clear
			}
			keep if sa0100=="`ii'"
			
			* Manual adjustment for FI
			replace intr = intr_FI if sa0100=="FI"
			
			use Data_`ii'_`it'.dta, clear
			saveold Data_lastit.dta, replace
		}

		if `it'<stSmplAsstNum_`ii' {
			di "adjustment needed `ii'"
			
			* Use values from last period
			use Data_lastit.dta, clear
			
			* Generate aggregate debt of young guys (if age shifted)
			egen agg_age20inidebt = sum(age20inidebt)

			* Update year & genenerate index for age adjustment		
			replace currentdate=`it'	/* change date*/
			
			gen currentquarter = mod(currentdate,10)  /* set current quarter*/
			gen shift_ind=0
			if basequarter==1 & currentquarter==4 {
				replace shift_ind=1
			}
			if basequarter==2 & currentquarter==1 {
				replace shift_ind=1
			}
			if basequarter==3 & currentquarter==2 {
				replace shift_ind=1
			}
			if basequarter==4 & currentquarter==1 {
				replace shift_ind=1
			}
			
			* Merge with interest rate and debt index data
			sort sa0100 currentdate		
			if Mortg==1 {
				merge sa0100 currentdate using LoanIntrData_M.dta /* merge with aggregate debt index and interest rate */
				drop _merge
			}
			if Mortg==0 {
				merge sa0100 currentdate using LoanIntrData_C.dta /* merge with aggregate debt index and interest rate */
				drop _merge
			}
			
			* Merge with distribution of new debt
			sort sa0100 age inc we
			if Mortg==1 {
				merge sa0100 age inc we using NewDebtDistr_M.dta
			}
			if Mortg==0 {
				merge sa0100 age inc we using NewDebtDistr_C.dta
			}
			keep if sa0100=="`ii'"
			keep if _merge==3
			drop _merge
			
			
			
			* Update aggregate target
			gen double aggdebt_target = aggdebt_base*debt_ind
			
			sort sa0100 inc we age
			if shift_ind==1 {	
				by sa0100 inc we: gen double celldebt_temp = celldebt[_n+1]
				by sa0100 inc we: replace celldebt_temp = 0 if age==100
			}
			if shift_ind==0 {
				gen double celldebt_temp = celldebt
			}
			
			* Generate counterfactual cell debt for t-1
			gen double temp_1 = celldebt_temp / (1 + intr_var/4 - repaym_ratio/4)
			gen double temp_2 = relnewdebt / (1 + intr_var/4 - repaym_ratio/4)
			egen double sum_temp_1 = sum(temp_1)
			egen double sum_temp_2 = sum(temp_2)
			gen double aggdebt_NEW = (sum_temp_1 - aggdebt_target)/sum_temp_2
			
			* CELL debt
			gen double celldebt_NEW = aggdebt_NEW * relnewdebt
			gen double temp = (celldebt_temp - celldebt_NEW)/(1 + intr_var/4 - repaym_ratio/4)			
			
			* Correct negative values (potential also `while' loop needed -> for later)
				gen ind = (temp<0)
				* Set d{t+1}=d^N
				replace celldebt_NEW = celldebt_temp if ind==1
				* Determine how much more to give to others
				egen double temp_aggdebt_NEW = sum(celldebt_NEW) /* "new" aggregate with restricted agens*/
				gen diff_abs = aggdebt_NEW - temp_aggdebt_NEW /* "overhang" for redistribution*/
				bysort ind: egen temp_celldebt_NEW = sum(celldebt_NEW) /* generate sum per group (restricted or not restricted)*/
				gen diff_ratio = (1+diff_abs/temp_celldebt_NEW)
				* Compute scaling factor for non-constrained observations
				replace diff_ratio=1 if ind==1
				* Rescale others
				replace celldebt_NEW = celldebt_NEW*diff_ratio
				* New aggregation
				replace temp = (celldebt_temp - celldebt_NEW)/(1 + intr_var/4 - repaym_ratio/4)

			replace celldebt = temp
			
			* CELL interest payments
			replace cellintrpaym = celldebt * intr_var/4
			* CELL repayments
			replace cellrepaym = celldebt * repaym_ratio/4
			replace cellrepaym = celldebt + cellintrpaym if age==99

			* AGGREGATE debt
			egen temp_aggdebt = sum(celldebt)
			replace aggdebt = temp_aggdebt
			egen temp_aggintrpaym = sum(cellintrpaym)
			replace aggintrpaym = temp_aggintrpaym
			egen temp_aggrepaym = sum(cellrepaym)
			replace aggrepaym = temp_aggrepaym
			drop temp_*
			
			keep age age20inidebt aggdebt aggdebt_base aggintrpaym aggrepaym basequarter celldebt cellintrpaym cellrepaym currentdate incgrp sa0100 wealthgrp celldebt_NEW	
			
			compress
			sort sa0100 age inc we
			saveold Data_`ii'_`it'.dta, replace
			drop celldebt_NEW
			saveold Data_lastit.dta, replace	                 
		}
	}
}
erase Data_lastit.dta
* ------------------------------------------------------------------------------------


* ------------------------------------------------------------------------------------
* Merge data
if Mortg==1 {
	use LoanIntrData_M.dta, clear  
}
if Mortg==0 {
	use LoanIntrData_C.dta, clear  
}


levelsof sa0100, local(countryvec)
levelsof currentdate, local(datevec)
foreach ii of local countryvec {
	use	Data_`ii'_20081.dta, clear
	foreach it of local datevec {
		di " country `ii' and time `it' "
		qui drop if `it'==20081
		append using Data_`ii'_`it'.dta
		erase Data_`ii'_`it'.dta
	}
	compress
	saveold Data_`ii'.dta, replace
}


local countryvec "BE CY DE ES FI FR GR IT LU MT NL PT SI SK" /* w/o AT as first element of loop*/
use	Data_AT.dta, clear
erase Data_AT.dta
foreach ii of local countryvec {
	append using Data_`ii'.dta
	erase Data_`ii'.dta
}
drop age20inidebt
compress

if Mortg==1 {
	saveold UpdatedDebtDistr_M.dta, replace
}
if Mortg==0 {
	saveold UpdatedDebtDistr_C.dta, replace
}
* ------------------------------------------------------------------------------------
