
set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
*************************************************************************************;
set scheme ecbochre;
graph set window fontface "Gill Sans MT";
graph set window fontfacesans "Gill Sans MT";

capture log close;
cd "`stataPath'";
log using "`logPath'\DebtServiceRatio_Income.log", replace;

use "`dataPath'\D_compl_2013_extended_unempSimul.dta";

******* Generate additional (rougher) classification variables;
*************************************************************************************;
*gen pop=1;	* whole sample;
*gen pop=1;	* whole sample;
mvdecode _all, mv(-1=.a);	* -1 are missing values;
mvdecode _all, mv(-2=.b);	* -2 are missing values;

replace dmdhageh=25;
replace dmdhageh=35 if dhageh1b>=8&dhageh1b<10;
replace dmdhageh=45 if dhageh1b>=10&dhageh1b<12;
replace dmdhageh=55 if dhageh1b>=12&dhageh1b<14;
replace dmdhageh=65 if dhageh1b>=14&dhageh1b<16;
replace dmdhageh=75 if dhageh1b>=16;

replace dmdhhtype=dhhtype;
replace dmdhhtype=6 if dhhtype==7;
replace dmdhhtype=10 if dhhtype==11|dhhtype==12;

*** Redefine dmdhhtype so that stats in the table show up in the order I want;
replace dmdhhtype_j=0;
replace dmdhhtype_j=1 if dmdhhtype==9;
replace dmdhhtype_j=2 if dmdhhtype==51;
replace dmdhhtype_j=3 if dmdhhtype==52;
replace dmdhhtype_j=4 if dmdhhtype==10;
replace dmdhhtype_j=5 if dmdhhtype==6;

replace dmdheduh=dheduh1;
replace dmdheduh=0 if dheduh1==1|dheduh1==2;
replace dmdheduh=3 if dheduh1==4;
replace dmdheduh=5 if dheduh1==6;

replace dmdheduh_j=dheduh;
replace dmdheduh_j=1 if dmdheduh==0;
replace dmdheduh_j=2 if dmdheduh==3;
replace dmdheduh_j=3 if dmdheduh==5;

*** Redefine top ditop10 and dntop10 (create indicators of top 10/5/1 percent of income/wealth);
replace ditop10_j=0;
replace ditop10_j=1 if ditop10>=90;
replace ditop5_j=0;
replace ditop5_j=1 if ditop10>=95;
replace ditop1_j=0;
replace ditop1_j=1 if ditop10==99;

replace dntop10_j=0;
replace dntop10_j=1 if dntop10>=90;
replace dntop5_j=0;
replace dntop5_j=1 if dntop10>=95;
replace dntop1_j=0;
replace dntop1_j=1 if dntop10==99;

******* Draw graphs;
*************************************************************************************;
local allVars "dodstotalp";
local bdWidth=.2;

*replace dodstotalp =. if sa0100=="FI";

gen di2000_pctile = .; 
    forvalues i = 1(1)5 {;
	_pctile di2000 [aweight=hw0010] if im0100 == `i',n(5);
    replace di2000_pctile = 20 if im0100 == `i' & di2000 <= r(r1);
    replace di2000_pctile = 40 if im0100 == `i' & di2000 > r(r1) & di2000 <= r(r2);
    replace di2000_pctile = 60 if im0100 == `i' & di2000 > r(r2) & di2000 <= r(r3);
    replace di2000_pctile = 80 if im0100 == `i' & di2000 > r(r3) & di2000 <= r(r4);
	replace di2000_pctile = 100 if im0100 == `i' & di2000 > r(r4);

    replace di2000_pctile=di2000_pctile; 

};

sort di2000;

statsby dodstotal_mean=r(mean), by(di2000_pctile im0100)
	saving("`basePath'\stats\parti_mean_dodstotal_di2000_pctile.dta", replace): 
	summarize dodstotalp [aweight = hw0010], det;

foreach var of local allVars {;
forvalues i=20(20)100 {;

	gen `var'_ind_`i' = hw0010 if di2000_pctile==`i'&`var'~=.;
	egen `var'_tot_`i' = total(`var'_ind_`i');

	forvalues j=0(2)600 {;
		gen `var'_ind`j'_`i' = hw0010 if di2000_pctile==`i'&`var'>=(`j'/1000)&`var'~=.;
		egen `var'_tot`j'_`i' = total(`var'_ind`j'_`i');
		gen `var'_share`j'_`i' = `var'_tot`j'_`i'/`var'_tot_`i' ;
	};

	gen complcdf_`var'_`i'=`var'_share0_`i' if di2000_pctile==`i'&`var'>=0&`var'~=.;
	forvalues j=0(2)600 {;
		replace complcdf_`var'_`i'=`var'_share`j'_`i' if di2000_pctile==`i'&`var'>=(`j'/1000)&`var'~=.;
		drop `var'_ind`j'_`i' `var'_tot`j'_`i' `var'_share`j'_`i';
	};

};
};

gen dodaratio_plot=dodaratio;
replace dodaratio_plot =. if dodaratio>3;
gen dodstotal_plot=dodstotalp;
replace dodstotal_plot=. if dodstotalp>0.6;
gen dnnlaratio_plot=dnnlaratio;
replace dnnlaratio_plot=. if dnnlaratio<0|dnnlaratio>1;

drop if dodstotal_plot==.;

**** Debt Service-Income Ratio;
**********************************;
drop if dodstotalp<0;

twoway
	(line complcdf_dodstotalp_20 dodstotal_plot if di2000_pctile==20, sort)
	(line complcdf_dodstotalp_40 dodstotal_plot if di2000_pctile==40, sort)
	(line complcdf_dodstotalp_60 dodstotal_plot if di2000_pctile==60, sort)
	(line complcdf_dodstotalp_80 dodstotal_plot if di2000_pctile==80, sort)
	(line complcdf_dodstotalp_100 dodstotal_plot if di2000_pctile==100, sort
	 		xlabel(0 0.1 0.2 0.3 0.4 0.5 0.6) xline(0.2 0.3 0.4, lcolor(black) lpatter(dash))
	xtitle(`" "' "Debt Service-Income Ratio") ytitle("Fraction of Hhs with DS-I Ratio > Threshold" `" "') 
		legend(lab(1 "Q1") lab(2 "Q2") lab(3 "Q3") lab(4 "Q4") lab(5 "Q5") cols(5)));
graph save "`basePath'\graphs\_empCDF_dodstotalInc", asis replace;
graph export "`basePath'\graphs\_empCDF_dodstotalInc.wmf", replace;	


* Keep only each 10th observation to reduce the size of the graph;
keep if _n/10==round(_n/10);

twoway
	(line complcdf_dodstotalp_20 dodstotal_plot if di2000_pctile==20, sort)
	(line complcdf_dodstotalp_40 dodstotal_plot if di2000_pctile==40, sort)
	(line complcdf_dodstotalp_60 dodstotal_plot if di2000_pctile==60, sort)
	(line complcdf_dodstotalp_80 dodstotal_plot if di2000_pctile==80, sort)
	(line complcdf_dodstotalp_100 dodstotal_plot if di2000_pctile==100, sort
	 		xlabel(0 0.1 0.2 0.3 0.4 0.5 0.6) xline(0.2 0.3 0.4, lcolor(black) lpatter(dash))
	xtitle(`" "' "Debt Service-Income Ratio") ytitle("Fraction of Hhs with DS-I Ratio > Threshold" `" "') 
		legend(lab(1 "Q1") lab(2 "Q2") lab(3 "Q3") lab(4 "Q4") lab(5 "Q5") cols(5)));
graph save "`basePath'\graphs\_empCDF_dodstotalInc_crude", asis replace;
graph export "`basePath'\graphs\_empCDF_dodstotalInc_crude.wmf", replace;	


gen complcdf_dodstotalp_20_perc=100*complcdf_dodstotalp_20;
gen complcdf_dodstotalp_40_perc=100*complcdf_dodstotalp_40;
gen complcdf_dodstotalp_60_perc=100*complcdf_dodstotalp_60;
gen complcdf_dodstotalp_80_perc=100*complcdf_dodstotalp_80;
gen complcdf_dodstotalp_100_perc=100*complcdf_dodstotalp_100;
gen dodstotal_plot_perc=100*dodstotal_plot;

twoway
	(line complcdf_dodstotalp_20_perc dodstotal_plot_perc if di2000_pctile==20, sort)
	(line complcdf_dodstotalp_40_perc dodstotal_plot_perc if di2000_pctile==40, sort)
	(line complcdf_dodstotalp_60_perc dodstotal_plot_perc if di2000_pctile==60, sort)
	(line complcdf_dodstotalp_80_perc dodstotal_plot_perc if di2000_pctile==80, sort)
	(line complcdf_dodstotalp_100_perc dodstotal_plot_perc if di2000_pctile==100, sort
	 		xlabel(0 10 20 30 40 50 60) xline(20 30 40, lcolor(black) lpatter(dash))
	xtitle(`" "' "Debt Service-Income Ratio (%)") ytitle("Fraction of Hhs with DS-I Ratio > Threshold (%)" `" "') 
		legend(lab(1 "Q1") lab(2 "Q2") lab(3 "Q3") lab(4 "Q4") lab(5 "Q5") cols(5)));
graph save "`basePath'\graphs\_empCDF_dodstotalIncT_perc", asis replace;
graph export "`basePath'\graphs\_empCDF_dodstotalIncT_perc.wmf", replace;	
log close;
