
* draw asset prices

*cd "D:\akmaral\HFCS\HFCSupdate\MASTER\programs"
set more off 
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;
do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
global dataPath "`dataPath'";
adopath + "`stataPath'";
capture log close;
cd "`stataPath'";

use "`dataPath'\allMacroDataSmooth.dta";
global currentPeriod "2013Q2";
sca startOfRecession = "2008Q1";

global realIndex "1";  * show real growth rates [default: No/0];

**************************************************************************************;
* account for adjustments;
local allCountries "FR CY MT PT DE GR";
foreach cntry of local allCountries{;
	replace B2B3_`cntry' = HICP_`cntry';   * Gross operating surplus and mixed income;
};
local allCountries "AT CY LU MT PT SK BE";    
foreach cntry of local allCountries{;
	replace D41_`cntry' = HICP_`cntry';    * Interests;
};

local allCountries "AT IT CY LU MT PT SK BE DE";
foreach cntry of local allCountries{;
	replace D75_C_`cntry' = HICP_`cntry';  * miscellaneous current transfers;
};

local allCountries "LU MT SK";
foreach cntry of local allCountries{;
	replace BS_F6_`cntry' = HICP_`cntry';	* Insurance technical reserves;
};



**************************************************************************************;
sca startSmpl = quarterly(startOfRecession,"YQ")-159;

sca currentPeriod = "$currentPeriod";
sca endSmpl = quarterly(currentPeriod,"YQ")-159;

local ctrylist = "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
local allVariables "D75_C WagesPC D41";
	
foreach var of local allVariables {;
foreach cntry of local ctrylist {;	
	* Adjustment for missing D41D42 in Germany [VERY ROUGH!!!];	
	replace `var'_`cntry' = `var'_`cntry'[_n-1] if missing(`var'_`cntry');
};
};

local varlist = "RPP Stock ZCB USOE_D HICP BS_F6 WagesPC D75_C B2B3 D41 BS_F2M";
foreach ii of local ctrylist {;
foreach var of local varlist{;
	sca index_`var'_`ii' = 100*(`var'_`ii'[endSmpl]/`var'_`ii'[startSmpl] -1);

};
};
drop _all;

set obs 15;
gen numobs = _n;
gen countrynum = numobs;

gen Deposits = .;
gen HousePrices = .;
gen Shares = .;
gen Bonds = .;
gen UnqShares = .;
gen HICP = .;
gen Pension = .;

gen WagesPE = .;
gen Transfers = .;
gen GrossSurplus = .;
gen Interests = .;


gen Dummy1 =.;
gen Dummy2 =.;

gen countrylabel = "";
replace countrylabel = "Austria" if numobs==1;
replace countrylabel = "Belgium" if numobs==2;
replace countrylabel = "Cyprus" if numobs==3;
replace countrylabel = "Germany" if numobs==4;
replace countrylabel = "Spain" if numobs==5;
replace countrylabel = "Finland" if numobs==6;
replace countrylabel = "France" if numobs==7;
replace countrylabel = "Greece" if numobs==8;
replace countrylabel = "Italy" if numobs ==9;
replace countrylabel = "Luxembourg" if numobs ==10;
replace countrylabel = "Malta" if numobs==11;
replace countrylabel = "Netherlands" if numobs==12;
replace countrylabel = "Portugal" if numobs==13;
replace countrylabel = "Slovenia" if numobs==14;
replace countrylabel = "Slovakia" if numobs==15;

local counter=1;

foreach ii of local ctrylist {;	
	replace HousePrices=index_RPP_`ii' if numobs==`counter';
	replace Shares=index_Stock_`ii' if numobs==`counter';
	replace Bonds=index_ZCB_`ii' if numobs==`counter';
	replace UnqShares=index_USOE_D_`ii' if numobs==`counter';
	replace HICP=index_HICP_`ii' if numobs==`counter';
	replace Pension=index_BS_F6_`ii' if numobs==`counter';
	replace Deposits=index_BS_F2M_`ii'  if numobs==`counter';
	
	replace WagesPE=index_WagesPC_`ii' if numobs==`counter';
	replace Transfers=index_D75_C_`ii' if numobs==`counter';
	replace GrossSurplus=index_B2B3_`ii' if numobs==`counter';
	replace Interests=index_D41_`ii' if numobs==`counter';
	
	local counter = `counter'+ 1;
};

local allVariables "HousePrices Shares Bonds UnqShares HICP Pension WagesPE Transfers GrossSurplus Interests Deposits";

if "$realIndex"=="1" {;
	foreach var of local allVariables {;
		replace `var' = `var'-HICP;
	};
	};
	
label define countryLabelLong 1 "Austria" 2 "Belgium" 3 "Cyprus" 4 "Germany" 5 "Spain" 6 "Finland" 7 "France" 8 "Greece" 9 "Italy" 10 "Luxembourg" 11 "Malta" 12 "Netherlands" 13 "Portugal" 14 "Slovenia" 15 "Slovakia";
label values countrynum countryLabelLong;

sort HousePrices;
gen countryOrder = _n;
global nobs =_N;



forvalues cntry = 1/$nobs {;
	global countryName = countrylabel[`cntry'];
	label define countryLabelSorted `cntry' "$countryName", modify;
};
label values countryOrder countryLabelSorted;

graph hbar (asis) HousePrices Dummy1 Dummy2, over(countryOrder)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) bar(3, color(blue*0.3)) 
yscale(range(-100 50)) ylabel(-100 "-100" -50 "-50" 0 "0" 50 "50") ytitle("Growth Rate, 2008Q1-2013Q2, Percent")
legend(label(1 "House Prices") label(2 "Shares") label(3 "Bonds") cols(3))
graphregion(color(white));
graph export "`dataPath'\fAssetPrices1.pdf", replace;

graph hbar (asis) HousePrices Shares Dummy2, over(countryOrder)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) bar(3, color(blue*0.3)) 
yscale(range(-100 50)) ylabel(-100 "-100" -50 "-50" 0 "0" 50 "50") ytitle("Growth Rate, 2008Q1-2013Q2, Percent")
legend(label(1 "House Prices") label(2 "Shares") label(3 "Bonds") cols(3))
graphregion(color(white));
graph export "`dataPath'\fAssetPrices2.pdf", replace;


graph hbar (asis) HousePrices Shares Bonds, over(countryOrder)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) bar(3, color(blue*0.3)) 
yscale(range(-100 50)) ylabel(-100 "-100" -50 "-50" 0 "0" 50 "50") ytitle("Growth Rate, 2008Q1-2013Q2, Percent")
legend(label(1 "House Prices") label(2 "Shares") label(3 "Bonds") cols(3))
graphregion(color(white));
graph export "`dataPath'\fAssetPrices3s.pdf", replace;

graph hbar (asis) HousePrices Shares Bonds, over(countryOrder)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) bar(3, color(blue*0.3)) 
yscale(range(-120 50)) ylabel(-100 "-100" -50 "-50" 0 "0" 50 "50") ytitle("Percent")
legend(pos(7) ring(0) label(1 "House" "Prices") label(2 "Shares ") label(3 "Bonds") cols(1))
graphregion(color(white));
graph export "`dataPath'\fAssetPrices4.pdf", replace;


graph hbar (asis) HousePrices Shares Bonds UnqShares HICP, over(countryOrder)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) bar(3, color(blue*0.6)) bar(4, color(blue*0.3)) bar(5, color(blue*0.10))
yscale(range(-120 50)) ylabel(-100 "-100" -50 "-50" 0 "0" 50 "50") ytitle("Percent")
legend(pos(7) ring(0) label(1 "House" "Prices") label(2 "Shares") label(3 "Bonds")  label(4 "Unquoted" "Shares")  label(5 "HICP") cols(1))
graphregion(color(white));
graph export "`dataPath'\fAssetPrices_Big.pdf", replace;

graph hbar (asis) HousePrices Shares Bonds UnqShares HICP Pension Deposits, over(countryOrder)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) bar(3, color(blue*0.6)) bar(4, color(blue*0.3)) bar(5, color(blue*0.10)) bar(6, color(red)) bar(7, color(red*0.3))
yscale(range(-150 50)) ylabel(-100 "-100" -50 "-50" 0 "0" 50 "50") ytitle("Percent")
legend(pos(7) ring(0) label(1 "House" "Prices") label(2 "Shares") label(3 "Bonds") label(4 "Unquoted" "Shares") label(5 "HICP") label(6 "Pension") label(7 "Deposits") cols(1))
graphregion(color(white));
graph export "`dataPath'\fAssetPrices_Big.pdf", replace;

fdafda;
************************************************************;

graph hbar (asis) WagesPE Transfers GrossSurplus Interests, over(countryOrder)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) bar(3, color(blue*0.6)) bar(4, color(blue*0.3))
yscale(range(-120 50)) ylabel(-100 "-100" -50 "-50" 0 "0" 50 "50") ytitle("Percent")
legend(pos(11) ring(0) label(1 "Wages" "per Employee") label(2 "Transfers") label(3 "Gross" "Surplus") label(4 "Interests") cols(1))
graphregion(color(white));
graph export "`dataPath'\fIncomeComponents.pdf", replace;



* relabel(1 "Spain" 2"Greece" 3 "Netherlands" 4 "Cyprus" 5 "Slovakia" 6 "Slovenia" 7 "Italy" 8 "Malta" 9 "Portugal" 10 "France" 11 "Germany" 12 "Finland" 13 "Belgium" 14 "Luxembourg" 15 "Austria");
