* 26/06/2014
* draws GINIs of net wealth between 2008 and 2013 across countries
* you need ainequal.ado in your program folder




cd "U:\akmaral\HFCS\HFCSupdate\MASTER\programs"
*************************************************************************************;
#delimit;
clear; clear matrix; clear mata; program drop _all; discard;
set mem 3000m; set maxvar 30000; set matsize 155; set scheme s2color; set more off;
do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
global dataPath "`dataPath'";
adopath + "`stataPath'";
capture log close;
global eolString "_char(92) _char(92)";		* string denoting new line in LaTeX tables \\;


cd "`stataPath'";
log using "`logPath'\DoAllHFCS.log", replace;
cd "`dataPath'";
*************************************************************************************;
* 2008;
use "`dataPath'\D_compl_2008_0.dta";
keep  dn3001 hw0010 sa0100;
rename dn3001 networth;
rename hw0010 wgt;
rename sa0100 country;

local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
local allWealthVars "networth";

	
* Data transformations;
*************************************************************************************;
foreach var of local allWealthVars {;	
	foreach cntry of local allCountries {;	
		disp "Country: `cntry'";
		ainequal `var' [weight=wgt] if country=="`cntry'";
		mat tempMat = r(b);
		sca gini_`var'_`cntry' = tempMat[1,1];
	};

	disp "Country: All countries";
	ainequal `var' [weight=wgt];
	mat tempMat = r(b);
	sca gini_`var'_ALL = tempMat[1,1];
};

cd "`basePath'";
*************************************************************************************;
local allCountries "ALL AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
gen observation = _n;
gen gini_networth = .;
gen mpc_networth = .;
gen mpc_liquidAssets = .;
gen mpc_liquidAssets_bottomTop = .;
gen mpc_networth_bottomTop = .;
gen countryLabel = "L";
local counter = 1;

mat input mpcAll_networth =        (0.12\ 0.16\ 0.10\ 0.13\ 0.22\ 0.12\ 0.13\ 0.13\ 0.10\ 0.13\ 0.12\ 0.10\ 0.11\ 0.11\ 0.10\ 0.10);
mat input mpcAll_liquidAssets =    (0.26\ 0.24\ 0.27\ 0.25\ 0.26\ 0.38\ 0.28\ 0.30\ 0.35\ 0.31\ 0.23\ 0.18\ 0.19\ 0.32\ 0.29\ 0.23);
mat input mpcTop_networth =        (0.06\ 0.07\ 0.06\ 0.06\ 0.08\ 0.07\ 0.06\ 0.07\ 0.06\ 0.07\ 0.06\ 0.06\ 0.06\ 0.06\ 0.06\ 0.07);
mat input mpcBottom_networth =     (0.17\ 0.25\ 0.14\ 0.19\ 0.34\ 0.17\ 0.19\ 0.19\ 0.13\ 0.19\ 0.17\ 0.14\ 0.16\ 0.15\ 0.13\ 0.13);
mat input mpcTop_liquidAssets =    (0.14\ 0.14\ 0.14\ 0.14\ 0.14\ 0.18\ 0.15\ 0.15\ 0.17\ 0.16\ 0.14\ 0.13\ 0.13\ 0.16\ 0.15\ 0.14);
mat input mpcBottom_liquidAssets = (0.36\ 0.33\ 0.38\ 0.35\ 0.36\ 0.54\ 0.40\ 0.43\ 0.50\ 0.44\ 0.32\ 0.23\ 0.24\ 0.45\ 0.42\ 0.31);
mat input homeOwnership_all =      (60.1\ 47.7\ 69.6\ 76.7\ 44.2\ 82.7\ 67.8\ 55.3\ 72.4\ 68.7\ 67.1\ 77.7\ 57.1\ 71.5\ 81.8\ 89.9);

foreach cntry of local allCountries {;	
	replace gini_networth = gini_networth_`cntry' in `counter';
	replace mpc_networth = mpcAll_networth[`counter',1] in `counter';
	replace mpc_liquidAssets = mpcAll_liquidAssets[`counter',1] in `counter';
	replace mpc_networth_bottomTop = mpcBottom_networth[`counter',1]/mpcTop_networth[`counter',1] in `counter';
	replace mpc_liquidAssets_bottomTop = mpcBottom_liquidAssets[`counter',1]/mpcTop_liquidAssets[`counter',1] in `counter';
	replace countryLabel = "`cntry'" in `counter';
	local counter = `counter'+1;
};

gen countryNum = 0;
replace countryNum = 1 if countryLabel == "ALL"; * All countries;
replace countryNum = 2 if countryLabel == "AT"; * Austria;
replace countryNum = 3 if countryLabel == "BE"; * Belgium;
replace countryNum = 4 if countryLabel == "CY"; * Cyprus;
replace countryNum = 5 if countryLabel == "DE"; * Germany;
replace countryNum = 6 if countryLabel == "ES"; * Spain;
replace countryNum = 7 if countryLabel == "FI"; * Finland;
replace countryNum = 8 if countryLabel == "FR"; * France;
replace countryNum = 9 if countryLabel == "GR"; * Greece;
replace countryNum = 10 if countryLabel == "IT"; * Italy;
replace countryNum = 11 if countryLabel == "LU"; * Luxembourg;
replace countryNum = 12 if countryLabel == "MT"; * Malta;
replace countryNum = 13 if countryLabel == "NL"; * Netherlands;
replace countryNum = 14 if countryLabel == "PT"; * Portugal;
replace countryNum = 15 if countryLabel == "SI"; * Slovenia;
replace countryNum = 16 if countryLabel == "SK"; * Slovakia;

label defin countryLabelLong 1 "All Countries" 2 "Austria" 3 "Belgium" 4 "Cyprus" 5 "Germany" 6 "Spain" 7 "Finland" 8 "France" 9 "Greece" 10 "Italy" 11 "Luxembourg" 12 "Malta" 13 "Netherlands" 14 "Portugal" 15 "Slovenia" 16 "Slovakia";
label values countryNum countryLabelLong;


rename gini_networth gini_networth_2008;
keep countryNum gini_networth_2008;
gen number=_n;
drop if number >16;
save "`dataPath'\gini_networth_2008.dta", replace;




* 2013;
use "`dataPath'\D_compl_2013_0.dta";
keep  dn3001 hw0010 sa0100;
rename dn3001 networth;
rename hw0010 wgt;
rename sa0100 country;

local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
local allWealthVars "networth";
	
* Data transformations;
*************************************************************************************;
foreach var of local allWealthVars {;	
	foreach cntry of local allCountries {;	
		disp "Country: `cntry'";
		ainequal `var' [weight=wgt] if country=="`cntry'";
		mat tempMat = r(b);
		sca gini_`var'_`cntry' = tempMat[1,1];
	};

	disp "Country: All countries";
	ainequal `var' [weight=wgt];
	mat tempMat = r(b);
	sca gini_`var'_ALL = tempMat[1,1];
};

cd "`basePath'";
*************************************************************************************;
local allCountries "ALL AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
gen observation = _n;
gen gini_networth = .;
gen mpc_networth = .;
gen mpc_liquidAssets = .;
gen mpc_liquidAssets_bottomTop = .;
gen mpc_networth_bottomTop = .;
gen countryLabel = "L";
local counter = 1;

mat input mpcAll_networth =        (0.12\ 0.16\ 0.10\ 0.13\ 0.22\ 0.12\ 0.13\ 0.13\ 0.10\ 0.13\ 0.12\ 0.10\ 0.11\ 0.11\ 0.10\ 0.10);
mat input mpcAll_liquidAssets =    (0.26\ 0.24\ 0.27\ 0.25\ 0.26\ 0.38\ 0.28\ 0.30\ 0.35\ 0.31\ 0.23\ 0.18\ 0.19\ 0.32\ 0.29\ 0.23);
mat input mpcTop_networth =        (0.06\ 0.07\ 0.06\ 0.06\ 0.08\ 0.07\ 0.06\ 0.07\ 0.06\ 0.07\ 0.06\ 0.06\ 0.06\ 0.06\ 0.06\ 0.07);
mat input mpcBottom_networth =     (0.17\ 0.25\ 0.14\ 0.19\ 0.34\ 0.17\ 0.19\ 0.19\ 0.13\ 0.19\ 0.17\ 0.14\ 0.16\ 0.15\ 0.13\ 0.13);
mat input mpcTop_liquidAssets =    (0.14\ 0.14\ 0.14\ 0.14\ 0.14\ 0.18\ 0.15\ 0.15\ 0.17\ 0.16\ 0.14\ 0.13\ 0.13\ 0.16\ 0.15\ 0.14);
mat input mpcBottom_liquidAssets = (0.36\ 0.33\ 0.38\ 0.35\ 0.36\ 0.54\ 0.40\ 0.43\ 0.50\ 0.44\ 0.32\ 0.23\ 0.24\ 0.45\ 0.42\ 0.31);
mat input homeOwnership_all =      (60.1\ 47.7\ 69.6\ 76.7\ 44.2\ 82.7\ 67.8\ 55.3\ 72.4\ 68.7\ 67.1\ 77.7\ 57.1\ 71.5\ 81.8\ 89.9);

foreach cntry of local allCountries {;	
	replace gini_networth = gini_networth_`cntry' in `counter';
	replace mpc_networth = mpcAll_networth[`counter',1] in `counter';
	replace mpc_liquidAssets = mpcAll_liquidAssets[`counter',1] in `counter';
	replace mpc_networth_bottomTop = mpcBottom_networth[`counter',1]/mpcTop_networth[`counter',1] in `counter';
	replace mpc_liquidAssets_bottomTop = mpcBottom_liquidAssets[`counter',1]/mpcTop_liquidAssets[`counter',1] in `counter';
	replace countryLabel = "`cntry'" in `counter';
	local counter = `counter'+1;
};

gen countryNum = 0;
replace countryNum = 1 if countryLabel == "ALL"; * All countries;
replace countryNum = 2 if countryLabel == "AT"; * Austria;
replace countryNum = 3 if countryLabel == "BE"; * Belgium;
replace countryNum = 4 if countryLabel == "CY"; * Cyprus;
replace countryNum = 5 if countryLabel == "DE"; * Germany;
replace countryNum = 6 if countryLabel == "ES"; * Spain;
replace countryNum = 7 if countryLabel == "FI"; * Finland;
replace countryNum = 8 if countryLabel == "FR"; * France;
replace countryNum = 9 if countryLabel == "GR"; * Greece;
replace countryNum = 10 if countryLabel == "IT"; * Italy;
replace countryNum = 11 if countryLabel == "LU"; * Luxembourg;
replace countryNum = 12 if countryLabel == "MT"; * Malta;
replace countryNum = 13 if countryLabel == "NL"; * Netherlands;
replace countryNum = 14 if countryLabel == "PT"; * Portugal;
replace countryNum = 15 if countryLabel == "SI"; * Slovenia;
replace countryNum = 16 if countryLabel == "SK"; * Slovakia;

label defin countryLabelLong 1 "All Countries" 2 "Austria" 3 "Belgium" 4 "Cyprus" 5 "Germany" 6 "Spain" 7 "Finland" 8 "France" 9 "Greece" 10 "Italy" 11 "Luxembourg" 12 "Malta" 13 "Netherlands" 14 "Portugal" 15 "Slovenia" 16 "Slovakia";
label values countryNum countryLabelLong;


rename gini_networth gini_networth_2013;
keep countryNum gini_networth_2013;
gen number=_n;
drop if number >16;
save "`dataPath'\gini_networth_2013.dta", replace;


* merge two gini datasets;
use "`dataPath'\gini_networth_2008.dta";
merge m:m number using "`dataPath'\gini_networth_2013.dta";
drop _merge;
save "`dataPath'\gini_networth_2010_2013.dta", replace;


* bar graph;
graph bar gini_networth_2008 gini_networth_2013, over(countryNum, label(angle(45))) nofill legend(label(1 "2008Q1") label(2 "2013Q2"))
bar(1, color(blue*5)) bar(2, color(blue*1.2))
yscale(r(0.4 0.9)) ylabel(0 "0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8") 
graphregion(color(white)) ytitle("Gini Coefficients -- Net Wealth");
graph export "`dataPath'\fGiniNetworth_2008_2013.pdf", replace;





