* download wages, gdp, net wealth, debt, unemployment rate, consumption series ----- ea17

set more off 
clear
clear matrix

set mem 3000m
set matsize 155
program drop _all
discard
do setPath
local basePath "$basePath"
local stataPath "$stataPath"
local logPath "`stataPath'"
local dataPath "`basePath'\data"
global dataPath "`dataPath'"
adopath + "`stataPath'"
capture log close
cd "`stataPath'"

set more off
odbc query "sdw", user(pub) password(pub)

* reference year - wages, gdp, wealth and debt are set to 100
sca refYear = "2008Q1"
sca refYearNum = quarterly(refYear,"YQ") - 119

* download hicp
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ICP.M.I6.S.000000.3.INX',obs_value,null)) HICP_ea17 FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ICP_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('ICP.M.I6.S.000000.3.INX') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME

gen date_test = monthly(PERIOD_NAME, "YM")
format date_test %tm

sort date_test

gen temp_y= yofd(dofm(date_test))
format temp_y %ty
gen temp_q= qofd(dofm(date_test))
format temp_q %tq

sort temp_q date_test
by temp_q: gen t=_n
gen PERIOD_NAME2 = PERIOD_NAME if t==3

bysort temp_q: egen HICP_EA17_mean=mean(HICP_EA17)
drop HICP_EA17
rename HICP_EA17_mean HICP_EA17

keep if t==3
rename temp_q date
keep date HICP_EA17

save "`dataPath'\HICP_EA17.dta", replace


* download net wealth

import excel "`dataPath'\NetWealth.xls", sheet("Sheet1") firstrow clear
label variable NetWealth "Household Net Wealth, euro area 17"
gen date_test = quarterly(PERIOD_NAME, "YQ")
gen date= qofd(dofq(date_test))
format date %tq
keep date NetWealth
save "`dataPath'\NetWealth.dta", replace



* download wages
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ESA.Q.I6.Y.1000.D11000.0000.TTTT.V.U.A',obs_value,null)) val_ea17 FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ESA_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('ESA.Q.I6.Y.1000.D11000.0000.TTTT.V.U.A') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
gen date_test = quarterly(PERIOD_NAME, "YQ")
gen date= qofd(dofq(date_test))
format date %tq
gen WAGES_EA17=VAL_EA17
keep date WAGES_EA17
save "`dataPath'\Wages_EA17.dta", replace




* download gdp
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ESA.Q.I6.Y.0000.B1QG00.1000.TTTT.L.U.A',obs_value,null)) val_ea17 FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ESA_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('ESA.Q.I6.Y.0000.B1QG00.1000.TTTT.L.U.A') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 

sort PERIOD_NAME
gen date_test = quarterly(PERIOD_NAME, "YQ")
gen date= qofd(dofq(date_test))
format date %tq
gen GDP_EA17=VAL_EA17
keep date GDP_EA17
save "`dataPath'\GDP_EA17.dta", replace



* download debt
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'IEAQ.Q.I6.N.V.LE.F4.S1M.A1.S.2.X.E.Z',obs_value,null)) val_ea17 FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_IEAQ_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('IEAQ.Q.I6.N.V.LE.F4.S1M.A1.S.2.X.E.Z') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
gen date_test = quarterly(PERIOD_NAME, "YQ")
gen date= qofd(dofq(date_test))
format date %tq
rename VAL_EA17 Debt
keep date Debt
save "`dataPath'\Debt_EA17.dta", replace

* download unemployment rate as a percentage of labour force
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'STS.Q.I6.S.UNEH.RTT000.4.000',obs_value,null)) val_ea17 FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_STS_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('STS.Q.I6.S.UNEH.RTT000.4.000') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
gen date_test = quarterly(PERIOD_NAME, "YQ")
gen date= qofd(dofq(date_test))
format date %tq
rename VAL_EA17 Unempl
keep date Unempl
save "`dataPath'\Unemployment_EA17.dta", replace

* download consumption, real, refyear=2005, millions of EUR
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ESA.Q.I6.Y.1415.P31000.0000.TTTT.L.U.A',obs_value,null)) val_ea17 FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ESA_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('ESA.Q.I6.Y.1415.P31000.0000.TTTT.L.U.A') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
gen date_test = quarterly(PERIOD_NAME, "YQ")
gen date= qofd(dofq(date_test))
format date %tq
rename VAL_EA17 Cons
keep date Cons
save "`dataPath'\Cons_EA17.dta", replace


use "`dataPath'\HICP_EA17.dta"
merge 1:1 date using "`dataPath'\Wages_EA17.dta"
drop _merge
merge 1:1 date using "`dataPath'\GDP_EA17.dta"
drop _merge
merge 1:1 date using "`dataPath'\NetWealth.dta"
drop _merge
merge 1:1 date using "`dataPath'\Debt_EA17.dta"
drop _merge

merge 1:1 date using "`dataPath'\Unemployment_EA17.dta"
drop _merge
merge 1:1 date using "`dataPath'\Cons_EA17.dta"
drop _merge








* convert nominal wages into real & normalize 2005=100
gen WagesReal = 100*WAGES_EA17/HICP_EA17
gen WagesNorm = 100*WagesReal/WagesReal[refYearNum]
* GDP
gen GdpNorm = 100*GDP_EA17/GDP_EA17[refYearNum]
* net wealth
gen NetWealthReal = 100*NetWealth/HICP_EA17
gen NetWealthNorm = 100*NetWealthReal/NetWealthReal[refYearNum]
* debt
gen DebtReal = 100*Debt/HICP_EA17


save "`dataPath'\ea17macro.dta", replace




* drop periods we don't need - start in 2005
gen period = _n
keep if period >60
drop period


tsset date, quarterly
gen temp_y= yofd(dofq(date))
format temp_y %ty
rename temp_y year


* fGreatRecession;
#delimit ;
twoway
(line GdpNorm date, lcolor(black) lwidth(medthick) lpattern(shortdash))
(line NetWealthNorm date, lcolor(black) lwidth(medthick) lpattern(solid))
(line WagesNorm date, lcolor(blue*1.2) lwidth(medthick) lpattern(dash_dot)),
legend(on order(1 "GDP" 2 "Net Wealth" 3 "Wages") cols(3))
graphregion(color(white))
xtitle("") xlabel(180(4)212,format(%tqCY))
;
graph export "`dataPath'\fGreatRecession.pdf", replace;


* fUnemployment;
#delimit ;
twoway
(line Unempl date, lcolor(black) lwidth(medthick)),
graphregion(color(white)) 
ytitle("Percent")
xtitle("") xlabel(180(4)212,format(%tqCY))
;
graph export "`dataPath'\fUnemployment.pdf", replace;



* fNominalDebt;
#delimit ;
twoway
(line Debt date, lcolor(black) lwidth(medthick)),
graphregion(color(white)) 
ytitle("") ylabel(4000000(1000000)7000000, angle(horizontal))
xtitle("") xlabel(180(4)212,format(%tqCY))
;
graph export "`dataPath'\fNominalDebt.pdf", replace;
*note("in millions of EUR");

* fRealDebt;
#delimit ;
twoway
(line DebtReal date, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
graphregion(color(white)) 
ytitle("") ylabel(4000000(1000000)7000000, angle(horizontal))
xtitle("") xlabel(180(4)212,format(%tqCY))
;
graph export "`dataPath'\fRealDebt.pdf", replace;


* fRealvsNomDebt;
#delimit ;
twoway
(line Debt date, lcolor(pink) lwidth(medthick) lpattern(solid))
(line DebtReal date, lcolor(black) lwidth(medthick) lpattern(dash_dot)),
graphregion(color(white)) 
ytitle("") ylabel(4000000(1000000)7000000, angle(horizontal))
xtitle("") xlabel(180(4)212,format(%tqCY))
legend(on order(1 "Nominal debt" 2 "Real debt") cols(2))
;
graph export "`dataPath'\fRealvsNomDebt.pdf", replace;

*fRealConsumption;
#delimit ;
twoway
(line Cons date, lcolor(black) lwidth(medthick)),
graphregion(color(white)) 
ytitle("") ylabel( , angle(horizontal)) 
xtitle("") xlabel(180(4)212,format(%tqCY))
;
graph export "`dataPath'\fRealConsumption.pdf", replace;





















