
* draw change in house purchase and consumption interest rates

*cd "D:\akmaral\HFCS\HFCSupdate\programs"
set more off 
clear
clear matrix
set mem 3000m
set matsize 155
program drop _all
discard
do setPath
local basePath "$basePath"
local stataPath "$stataPath"
local logPath "`stataPath'"
local dataPath "`basePath'\data"
global dataPath "`dataPath'"
adopath + "`stataPath'"
capture log close
cd "`stataPath'"

#delimit;
global currentPeriod "2013Q2";
sca startOfRecession = "2008Q1";
sca startSmpl = quarterly(startOfRecession,"YQ")-159;
sca currentPeriod = "$currentPeriod";
sca endSmpl = quarterly(currentPeriod,"YQ")-159;


use "`dataPath'\allMacroData.dta";
replace IntRC_all_SK = IntRC_all_SK[37] if  _n==33;
replace IntRC_all_MT = IntRC_all_MT[36] if  _n==33;


local ctrylist = "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
local varlist = "IntRH_all IntRC_all";
foreach ii of local ctrylist {;
foreach var of local varlist{;
	sca index_`var'_`ii' = (`var'_`ii'[endSmpl] - `var'_`ii'[startSmpl]);
};
};
drop _all;

set obs 15;
gen numobs = _n;
gen countrynum = numobs;

gen IntRateHouse = .;
gen IntRateCons = .;


gen countrylabel = "";
replace countrylabel = "Austria" if numobs==1;
replace countrylabel = "Belgium" if numobs==2;
replace countrylabel = "Cyprus" if numobs==3;
replace countrylabel = "Germany" if numobs==4;
replace countrylabel = "Spain" if numobs==5;
replace countrylabel = "Finland" if numobs==6;
replace countrylabel = "France" if numobs==7;
replace countrylabel = "Greece" if numobs==8;
replace countrylabel = "Italy" if numobs ==9;
replace countrylabel = "Luxembourg" if numobs ==10;
replace countrylabel = "Malta" if numobs==11;
replace countrylabel = "Netherlands" if numobs==12;
replace countrylabel = "Portugal" if numobs==13;
replace countrylabel = "Slovenia" if numobs==14;
replace countrylabel = "Slovakia" if numobs==15;

local counter=1;
foreach ii of local ctrylist {;	
	replace IntRateHouse=index_IntRH_all_`ii' if numobs==`counter';
	local counter = `counter'+ 1;
};

local counter=1;
foreach ii of local ctrylist {;	
	replace IntRateCons=index_IntRC_all_`ii' if numobs==`counter';
	local counter = `counter'+ 1;
};


sort IntRateHouse;
gen countryOrder = _n;
global nobs =_N;

forvalues cntry = 1/$nobs {;
	global countryName = countrylabel[`cntry'];
	label define countryLabelSorted `cntry' "$countryName", modify;
};
label values countryOrder countryLabelSorted;

graph hbar (asis) IntRateHouse, over(countryOrder)
bar(1, color(blue*1.2))  
subtitle("Change in nominal interest rates on loans for house purchase")
ytitle("percentage points")
graphregion(color(white));
graph export "`dataPath'\fInterestRates_House.pdf", replace;
graph export "`dataPath'\fInterestRates_House.wmf", replace;



#delimit;
drop countryOrder;
sort IntRateCons;
gen countryOrder = _n;



forvalues cntry = 1/$nobs {;
	global countryName = countrylabel[`cntry'];
	label define countryLabelSorted `cntry' "$countryName", modify;
};
label values countryOrder countryLabelSorted;


graph hbar (asis) IntRateCons, over(countryOrder)
bar(1, color(blue*1.2))  
legend(label(1 "Weighted Consumption Interest Rates"))
graphregion(color(white));
graph export "`dataPath'\fInterestRates_Consumption.pdf", replace;



