
#delimit;
** This program...	;
clear; clear matrix; clear mata; program drop _all; discard;
set mem 3000m; set maxvar 30000; set matsize 155; set scheme s2color; set more off;

*local basePath "U:\Slacalek\Laptop_X230\20130627\Research\BSinKS\20130408\cstMPCEurope\Latest\Code\Stata\";
* Current directory needs to be changed depending on working environment;
do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
global dataPath "`dataPath'";
adopath + "`stataPath'";
global eolString "_char(92) _char(92)";		* string denoting new line in LaTeX tables \\;

capture log close;
cd "`stataPath'";
log using "`logPath'\DoAllHFCS_modelFit.log", replace;
cd "`dataPath'";
*************************************************************************************;

use "`dataPath'\D_compl.dta";

replace da2101 = 0 if da2101==.;
replace da2102 = 0 if da2102==.;
replace da2103 = 0 if da2103==.;
replace da2104 = 0 if da2104==.;
replace da2105 = 0 if da2105==.;
replace da2106 = 0 if da2106==.;
replace da2109 = 0 if da2109==.;

gen liquidAssets = da2101+da2102+da2103+da2104+da2105+da2106+da2109;
*** sum of deposits, mutual funds, bonds, non-SE business wealth, shares, managed accounts and voluntary pensions;

keep dhageh dn3001 dnnla di2000 hw0010 sa0100 liquidAssets;
rename dhageh age;
rename dn3001 networth;
rename dnnla netliquidassets;
rename di2000 income;
rename hw0010 wgt;
rename sa0100 country;

local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK ALL";
local allGraphFormats "wmf png eps pdf";
local wealthRatios "networth netliquidassets liquidAssets";
	
* Data transformations;
*************************************************************************************;
* Drop data, if age < 25 or >60;
drop if age < 25|age > 60;

* Cumulative distribution of wealth;
*************************************************************************************;
* normalize weights;
egen float wgt_norm = pc(wgt);
replace wgt_norm = wgt_norm/100;

foreach cntry of local allCountries {;
	preserve;
	if "`cntry'" ~= "ALL" {;
		keep if country == "`cntry'";
	};
	
	foreach var of local wealthRatios {;
		gsort -`var'; 

		* calculate cumulative distribution from the top; 
		gen `var'_temp = `var'*wgt_norm;
		egen float dist`var' = pc(`var'_temp);
		gen cum`var' = dist`var'[1];
		replace cum`var' = dist`var'[_n] + cum`var'[_n-1] if _n>1;

		* show wealth held by top x% (note that the order is reversed from RATIOS (above));
		sum cum`var' [weight=wgt_norm], det;
		sca `var'_top1_`cntry' = r(p1);
		sca `var'_top10_`cntry' = r(p10);
		
	};
	
	restore;
};
	
cd "`basePath'";
*************************************************************************************;

gen share_top1_networth_data = .;
gen share_top1_liquidAssets_data = .;
gen share_top1_networth_model = .;
gen share_top1_liquidAssets_model = .;

gen share_top10_networth_data = .;
gen share_top10_liquidAssets_data = .;
gen share_top10_networth_model = .;
gen share_top10_liquidAssets_model = .;


gen countryLabel = "L";
local counter = 1;

foreach cntry of local allCountries {;	
	replace share_top1_networth_data = networth_top1_`cntry' in `counter';
	replace share_top10_networth_data = networth_top10_`cntry' in `counter';
	replace share_top1_liquidAssets_data = networth_top1_`cntry' in `counter';
	replace share_top10_liquidAssets_data = networth_top10_`cntry' in `counter';
	
	replace countryLabel = "`cntry'" in `counter';
	local counter = `counter'+1;
};

replace share_top1_networth_model = 22.7 in 1; * Austria;
replace share_top1_networth_model = 12.9 in 2; * Belgium;
replace share_top1_networth_model = 17.5 in 3; * Cyprus;
replace share_top1_networth_model = 26.4 in 4; * Germany;
replace share_top1_networth_model = 12.2 in 5; * Spain;
replace share_top1_networth_model = 18.1 in 6; * Finland;
replace share_top1_networth_model = 17.0 in 7; * France;
replace share_top1_networth_model = 10.9 in 8; * Greece;
replace share_top1_networth_model = 13.7 in 9; * Italy;
replace share_top1_networth_model = 17.5 in 10; * Luxembourg;
replace share_top1_networth_model = 13.7 in 11; * Malta;
replace share_top1_networth_model = 15.5 in 12; * Netherlands;
replace share_top1_networth_model = 14.0 in 13; * Portugal;
replace share_top1_networth_model = 10.7 in 14; * Slovenia;
replace share_top1_networth_model = 9.5 in 15; * Slovakia;
replace share_top1_networth_model = 17.7 in 16; * All countries;

replace share_top10_networth_model = 63.0 in 1; * Austria;
replace share_top10_networth_model = 45.5 in 2; * Belgium;
replace share_top10_networth_model = 55.1 in 3; * Cyprus;
replace share_top10_networth_model = 67.1 in 4; * Germany;
replace share_top10_networth_model = 43.7 in 5; * Spain;
replace share_top10_networth_model = 55.4 in 6; * Finland;
replace share_top10_networth_model = 53.6 in 7; * France;
replace share_top10_networth_model = 40.8 in 8; * Greece;
replace share_top10_networth_model = 46.6 in 9; * Italy;
replace share_top10_networth_model = 53.4 in 10; * Luxembourg;
replace share_top10_networth_model = 46.0 in 11; * Malta;
replace share_top10_networth_model = 50.8 in 12; * Netherlands;
replace share_top10_networth_model = 48.2 in 13; * Portugal;
replace share_top10_networth_model = 40.7 in 14; * Slovenia;
replace share_top10_networth_model = 37.6 in 15; * Slovakia;
replace share_top10_networth_model = 53.4 in 16; * All countries;
	
replace share_top1_liquidAssets_model = 25.1 in 1; * Austria;
replace share_top1_liquidAssets_model = 27.7 in 2; * Belgium;
replace share_top1_liquidAssets_model = 25.0 in 3; * Cyprus;
replace share_top1_liquidAssets_model = 24.8 in 4; * Germany;
replace share_top1_liquidAssets_model = 34.7 in 5; * Spain;
replace share_top1_liquidAssets_model = 29.0 in 6; * Finland;
replace share_top1_liquidAssets_model = 30.6 in 7; * France;
replace share_top1_liquidAssets_model = 35.5 in 8; * Greece;
replace share_top1_liquidAssets_model = 26.1 in 9; * Italy;
replace share_top1_liquidAssets_model = 22.8 in 10; * Luxembourg;
replace share_top1_liquidAssets_model = 13.2 in 11; * Malta;
replace share_top1_liquidAssets_model = 14.1 in 12; * Netherlands;
replace share_top1_liquidAssets_model = 34.7 in 13; * Portugal;
replace share_top1_liquidAssets_model = 30.5 in 14; * Slovenia;
replace share_top1_liquidAssets_model = 20.9 in 15; * Slovakia;
replace share_top1_liquidAssets_model = 25.4 in 16; * All countries;

replace share_top10_liquidAssets_model = 62.0 in 1; * Austria;
replace share_top10_liquidAssets_model = 65.6 in 2; * Belgium;
replace share_top10_liquidAssets_model = 63.0 in 3; * Cyprus;
replace share_top10_liquidAssets_model = 59.4 in 4; * Germany;
replace share_top10_liquidAssets_model = 72.9 in 5; * Spain;
replace share_top10_liquidAssets_model = 67.8 in 6; * Finland;
replace share_top10_liquidAssets_model = 68.0 in 7; * France;
replace share_top10_liquidAssets_model = 74.8 in 8; * Greece;
replace share_top10_liquidAssets_model = 63.4 in 9; * Italy;
replace share_top10_liquidAssets_model = 60.2 in 10; * Luxembourg;
replace share_top10_liquidAssets_model = 44.8 in 11; * Malta;
replace share_top10_liquidAssets_model = 46.8 in 12; * Netherlands;
replace share_top10_liquidAssets_model = 72.4 in 13; * Portugal;
replace share_top10_liquidAssets_model = 69.2 in 14; * Slovenia;
replace share_top10_liquidAssets_model = 58.0 in 15; * Slovakia;
replace share_top10_liquidAssets_model = 63.9 in 16; * All countries;	

gen fit_share_top1_networth = share_top1_networth_model/share_top10_networth_data;
gen fit_share_top10_networth = share_top10_networth_model/share_top10_networth_data;
gen fit_share_top1_liquidAssets = share_top1_liquidAssets_model/share_top10_liquidAssets_data;
gen fit_share_top10_liquidAssets = share_top10_liquidAssets_model/share_top10_liquidAssets_data;

gen countryNum = 0;
replace countryNum = 1 if countryLabel == "ALL"; * All countries;
replace countryNum = 2 if countryLabel == "AT"; * Austria;
replace countryNum = 3 if countryLabel == "BE"; * Belgium;
replace countryNum = 4 if countryLabel == "CY"; * Cyprus;
replace countryNum = 5 if countryLabel == "DE"; * Germany;
replace countryNum = 6 if countryLabel == "ES"; * Spain;
replace countryNum = 7 if countryLabel == "FI"; * Finland;
replace countryNum = 8 if countryLabel == "FR"; * France;
replace countryNum = 9 if countryLabel == "GR"; * Greece;
replace countryNum = 10 if countryLabel == "IT"; * Italy;
replace countryNum = 11 if countryLabel == "LU"; * Luxembourg;
replace countryNum = 12 if countryLabel == "MT"; * Malta;
replace countryNum = 13 if countryLabel == "NL"; * Netherlands;
replace countryNum = 14 if countryLabel == "PT"; * Portugal;
replace countryNum = 15 if countryLabel == "SI"; * Slovenia;
replace countryNum = 16 if countryLabel == "SK"; * Slovakia;

label defin countryLabelLong 1 "All Countries" 2 "Austria" 3 "Belgium" 4 "Cyprus" 5 "Germany" 6 "Spain" 7 "Finland" 8 "France" 9 "Greece" 10 "Italy" 11 "Luxembourg" 12 "Malta" 13 "Netherlands" 14 "Portugal" 15 "Slovenia" 16 "Slovakia";
label values countryNum countryLabelLong;

*************************************************************************************;
graph bar share_top1_networth_data share_top1_networth_model, over(countryLabel) nofill legend(label(1 "Data") label(2 "Model")) 
bar(1, color(maroon)) bar(2, color(red)) graphregion(color(white))
ytitle("Top 1 Percent Shares, Net Wealth");
graph save "`dataPath'\share_top1_networth", asis replace;
foreach frmt of local allGraphFormats {;
	graph export "`dataPath'\share_top1_networth.`frmt'", replace;
};
	
graph bar share_top10_networth_data share_top10_networth_model, over(countryLabel) nofill legend(label(1 "Data") label(2 "Model")) 
bar(1, color(maroon)) bar(2, color(red)) graphregion(color(white))
ytitle("Top 10 Percent Shares, Net Wealth");
graph save "`dataPath'\share_top10_networth", asis replace;
foreach frmt of local allGraphFormats {;
	graph export "`dataPath'\share_top10_networth.`frmt'", replace;
};

graph bar share_top1_liquidAssets_data share_top1_liquidAssets_model, over(countryLabel) nofill legend(label(1 "Data") label(2 "Model")) 
bar(1, color(maroon)) bar(2, color(red)) graphregion(color(white))
ytitle("Top 1 Percent Shares, Liquid Assets");
graph save "`dataPath'\share_top1_liquidAssets", asis replace;
foreach frmt of local allGraphFormats {;
	graph export "`dataPath'\share_top1_liquidAssets.`frmt'", replace;
};
	
graph bar share_top10_liquidAssets_data share_top10_liquidAssets_model, over(countryLabel) nofill legend(label(1 "Data") label(2 "Model")) 
bar(1, color(maroon)) bar(2, color(red)) graphregion(color(white))
ytitle("Top 10 Percent Shares, Liquid Assets");
graph save "`dataPath'\share_top10_liquidAssets", asis replace;
foreach frmt of local allGraphFormats {;
	graph export "`dataPath'\share_top10_liquidAssets.`frmt'", replace;
};

*** Model vs Data;
graph bar fit_share_top1_networth fit_share_top1_liquidAssets, over(countryNum, label(angle(45))) nofill legend(label(1 "Net Wealth") label(2 "Liquid Assets")) 
bar(1, color(maroon)) bar(2, color(red)) graphregion(color(white))
ytitle("Top 1 Percent Shares: Model/Data");
graph save "`dataPath'\share_top1_fit", asis replace;
foreach frmt of local allGraphFormats {;
	graph export "`dataPath'\share_top1_fit.`frmt'", replace;
};

graph bar fit_share_top10_networth fit_share_top10_liquidAssets, over(countryNum, label(angle(45))) nofill legend(label(1 "Net Wealth") label(2 "Liquid Assets")) 
bar(1, color(red*5)) bar(2, color(maroon*.7)) yline(1, lcolor(black) lpattern(dot) lwidth(medthick))
ylabel(0 "0" 0.5 "0.5" 1 "1" 1.5 "1.5" 2 "2")
graphregion(color(white)) ytitle("Top 10 Percent Shares: Model/Data");
graph save "`dataPath'\share_top10_fit", asis replace;
foreach frmt of local allGraphFormats {;
	graph export "`dataPath'\share_top10_fit.`frmt'", replace;
};
	
*************************************************************************************;
log close;
