
* downloads unemployment rate by country and draws a figure
set more off 
clear
clear matrix

set mem 3000m
set matsize 155
program drop _all
discard
do setPath
local basePath "$basePath"
local stataPath "$stataPath"
local logPath "`stataPath'"
local dataPath "`basePath'\data"
global dataPath "`dataPath'"
adopath + "`stataPath'"
capture log close
cd "`stataPath'"

odbc query "sdw", user(pub) password(pub)

global ctrylist = "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK"
foreach ii of global ctrylist {
	clear
	odbc load/*
	*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'STS.M.`ii'.S.UNEH.RTT000.4.000',obs_value,null)) val_`ii' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_STS_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('STS.M.`ii'.S.UNEH.RTT000.4.000') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
	sort PERIOD_NAME
	compress
	rename VAL_`ii' Unempl_`ii'
	save "`dataPath'\Unempl_`ii'.dta", replace	
	display "`ii'   downloaded"

}

* Merge Data
use "`dataPath'\Unempl_AT.dta", clear
global ctrylist = "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK"
foreach ii of global ctrylist {
		merge PERIOD_NAME using "`dataPath'\Unempl_`ii'.dta"
		drop _merge
		sort PERIOD_NAME
		display "`ii' matched"
		label variable Unempl_`ii' "Unemployment rate T, TOTAL"
		erase "`dataPath'\Unempl_`ii'.dta"
}
* Pick only quarter-end values
gen date_test = monthly(PERIOD_NAME, "YM")
format date_test %tm

gen temp_y= yofd(dofm(date_test))
format temp_y %ty
gen temp_q= qofd(dofm(date_test))
format temp_q %tq

sort temp_q date_test
by temp_q: gen t=_n
keep if t==3

sort temp_y temp_q
list temp_y temp_q
drop t
by temp_y: gen t=_n
gen qind="Q1" if t==1
replace qind="Q2" if t==2
replace qind="Q3" if t==3
replace qind="Q4" if t==4

gen y_str = string(temp_y)

replace PERIOD_NAME = y_str + qind
rename PERIOD_NAME date

keep date Unempl*
compress
sort date
save "`dataPath'\UnemplByCountry.dta", replace

* drop periods we don't need
gen period = _n
keep if period >68
drop period

#delimit;
global currentPeriod "2013Q2";
sca startOfRecession = "2008Q1";
sca startSmpl = quarterly(startOfRecession,"YQ")-159;
sca currentPeriod = "$currentPeriod";
sca endSmpl = quarterly(currentPeriod,"YQ")-159;



local ctrylist = "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
foreach ii of local ctrylist {;

	sca index_Unempl_`ii' = (Unempl_`ii'[endSmpl] - Unempl_`ii'[startSmpl]);

};

drop _all;


set obs 15;
gen numobs = _n;
gen countrynum = numobs;

gen Unempl = .;

gen countrylabel = "";
replace countrylabel = "Austria" if numobs==1;
replace countrylabel = "Belgium" if numobs==2;
replace countrylabel = "Cyprus" if numobs==3;
replace countrylabel = "Germany" if numobs==4;
replace countrylabel = "Spain" if numobs==5;
replace countrylabel = "Finland" if numobs==6;
replace countrylabel = "France" if numobs==7;
replace countrylabel = "Greece" if numobs==8;
replace countrylabel = "Italy" if numobs ==9;
replace countrylabel = "Luxembourg" if numobs ==10;
replace countrylabel = "Malta" if numobs==11;
replace countrylabel = "Netherlands" if numobs==12;
replace countrylabel = "Portugal" if numobs==13;
replace countrylabel = "Slovenia" if numobs==14;
replace countrylabel = "Slovakia" if numobs==15;

local counter=1;
foreach ii of local ctrylist {;	
	replace Unempl=index_Unempl_`ii' if numobs==`counter';
	local counter = `counter'+ 1;
};

sort Unempl;
gen countryOrder = _n;
global nobs =_N;

forvalues cntry = 1/$nobs {;
	global countryName = countrylabel[`cntry'];
	label define countryLabelSorted `cntry' "$countryName", modify;
};
label values countryOrder countryLabelSorted;

#delimit;
graph hbar (asis) Unempl, over(countryOrder)
bar(1, color(blue*1.2)) 
subtitle("Change in unemployment rate") 
ytitle("percentage points")
graphregion(color(white));
graph export "`dataPath'\fUnemplByCountry.pdf", replace;
graph export "`dataPath'\fUnemplByCountry.wmf", replace;
















