drop if sa0100=="FI"

* Generate age dummies
gen agegrp=0
replace agegrp=1 if (dhageh1<35)
replace agegrp=2 if (dhageh1>=35 & dhageh1<54)
replace agegrp=3 if (dhageh1>=55)
drop if agegrp==0
tab agegrp, gen(age_d)
drop agegrp

* Rescale education
gen edu_1=(dheduh1==1 | dheduh1==0)
gen edu_2=(dheduh1==2)
gen edu_3=(dheduh1==3 | dheduh1==4)
gen edu_4=(dheduh1==5 | dheduh1==6)

* Dummies for HH-size
gen temp = dh0001
replace temp=4 if temp>=4
tab temp, gen(hhmemb_)
drop temp   

* Recode variables which will be updated in the course of simulations
* Income
gen hhgrossinc=log(di2000/1000)

* Redefine employment: employed, unemployed, retired
gen pens=(dhemph1==4)
gen unempl=(dhemph1==3)

* Net wealth
gen netwealth=log(dn3001/1000)

* Position in income & wealth distribution
tab dhnq01, gen(netwquint_)
tab dhiq01, gen(incquint_)


* Dummy for has debt
gen hasdebt = dl1000i

* Debt-service-ratio above 40%
gen dsr40p=dodstotal40p
replace dsr40p=0 if hasdebt==0

* Owner/renter status
gen owner=(dhhst==1 | dhhst==2)

* Generate country groups
gen ctry_group = " "
replace ctry_group="Cont" if (sa0100=="AT" | sa0100=="BE" | sa0100=="DE" | sa0100=="FR" | sa0100=="LU" | sa0100=="NL" | sa0100=="SI" | sa0100=="SK") 
replace ctry_group="Med" if (sa0100=="CY" | sa0100=="ES" | sa0100=="GR" | sa0100=="IT" | sa0100=="MT" | sa0100=="PT")

* Generate country (group) dummies
gen temp = sa0100
egen group = group(temp)


* ---------------------------------------------------------------------------------------
* Set definition for credit constr.
gen depvar = docreditc   				/* Credit constraint as defined in WP */
*gen depvar = dnnla2months   			/* Net liquid assets < 2 months income */
*gen depvar = (dnnla<(di2000/12)*6)  	/* Net liquid assets < 6 months income */
*gen depvar = dl1210i					/* Has credit line/overdraft facility */
*gen depvar = dl1220i					/* Has credit card debt */
* ---------------------------------------------------------------------------------------

* Drop useless variables
keep depvar group unempl pens age_d* edu_* netwealth hhgrossinc hhmemb_* owner hasdebt dsr40p hw0010  netwquint_* incquint_*
*keep depvar group unempl pens age_d* edu_* netwealth hhgrossinc hhmemb_* owner hasdebt dsr40p hw0010 dhidh netwquint_* incquint_*
