* use UN population to adjust hh weights;

set more off
clear
clear matrix
set mem 3000m
set matsize 155
program drop _all
discard
do setPath
local basePath "$basePath"
local stataPath "$stataPath"
local logPath "`stataPath'"
local dataPath "`basePath'\data"
adopath + "`stataPath'"

use "`dataPath'\WPP_HFCN.dta", clear


* TEST
*keep if sa0100=="AT"
*keep if sex=="Both"
*sort year age

* Additional step: sum all agents above 80 into
* one category: more reliable data as data 80+ is dodgy
gen age80p=(age>=80)
bysort sa0100 sex year age80p: egen temp=sum(pop)
replace pop=temp if age80p==1
replace pop=. if age>80
drop temp


*AK: 
gen age16p = (age>=16 & age<20)
bysort sa0100 sex year age16p: egen temp=sum(pop)
sort year age
replace pop=temp if age16p==1
replace pop=. if age>16 & age <20
drop temp

gen age20p = (age >=20 & age <25)
bysort sa0100 sex year age20p: egen temp=sum(pop)
sort year age
replace pop=temp if age20p==1
replace pop=. if age>20 & age <25
drop temp

gen age25p = (age >=25 & age <30)
bysort sa0100 sex year age25p: egen temp=sum(pop)
sort year age
replace pop=temp if age25p==1
replace pop=. if age>25 & age <30
drop temp

gen age30p = (age >=30 & age <35)
bysort sa0100 sex year age30p: egen temp=sum(pop)
sort year age
replace pop=temp if age30p==1
replace pop=. if age>30 & age <35
drop temp

gen age35p = (age >=35 & age <40)
bysort sa0100 sex year age35p: egen temp=sum(pop)
sort year age
replace pop=temp if age35p==1
replace pop=. if age>35 & age <40
drop temp

gen age40p = (age >=40 & age <45)
bysort sa0100 sex year age40p: egen temp=sum(pop)
sort year age
replace pop=temp if age40p==1
replace pop=. if age>40 & age <45
drop temp

gen age45p = (age >=45 & age <50)
bysort sa0100 sex year age45p: egen temp=sum(pop)
sort year age
replace pop=temp if age45p==1
replace pop=. if age>45 & age <50
drop temp

gen age50p = (age >=50 & age <55)
bysort sa0100 sex year age50p: egen temp=sum(pop)
sort year age
replace pop=temp if age50p==1
replace pop=. if age>50 & age <55
drop temp

gen age55p = (age >=55 & age <60)
bysort sa0100 sex year age55p: egen temp=sum(pop)
sort year age
replace pop=temp if age55p==1
replace pop=. if age>55 & age <60
drop temp

gen age60p = (age >=60 & age <65)
bysort sa0100 sex year age60p: egen temp=sum(pop)
sort year age
replace pop=temp if age60p==1
replace pop=. if age>60 & age <65
drop temp

gen age65p = (age >=65 & age <70)
bysort sa0100 sex year age65p: egen temp=sum(pop)
sort year age
replace pop=temp if age65p==1
replace pop=. if age>65 & age <70
drop temp

gen age70p = (age >=70 & age <75)
bysort sa0100 sex year age70p: egen temp=sum(pop)
sort year age
replace pop=temp if age70p==1
replace pop=. if age>70 & age <75
drop temp

gen age75p = (age >=75 & age <80)
bysort sa0100 sex year age75p: egen temp=sum(pop)
sort year age
replace pop=temp if age75p==1
replace pop=. if age>75 & age <80
drop temp





* Generate distribution
bysort sa0100 sex year: egen totpop=sum(pop)
gen popdist=pop/totpop

* Generate values for 80+ (fill data)
bysort sa0100 sex year age80p: egen temp=mean(popdist)
replace popdist=temp if age80p==1
drop age80p temp

local allVariables "age16p age20p age25p age30p age35p age40p age45p age50p age55p age60p age65p age70p age75p"
foreach var of local allVariables{
bysort sa0100 sex year `var': egen temp=mean(popdist)
replace popdist=temp if `var'==1
drop `var' temp
}






* assign fieldwork date for each country
gen temp = popdist if year==2010 & sa0100=="BE"
replace temp = popdist if year==2011 & sa0100=="AT"
replace temp = popdist if year==2011 & sa0100=="DE"
replace temp = popdist if year==2009 & sa0100=="GR"
replace temp = popdist if year==2009 & sa0100=="ES"
replace temp = popdist if year==2009 & sa0100=="FR"
replace temp = popdist if year==2011 & sa0100=="IT"
replace temp = popdist if year==2010 & sa0100=="CY"
replace temp = popdist if year==2010 & sa0100=="LU"
replace temp = popdist if year==2010 & sa0100=="MT"
replace temp = popdist if year==2010 & sa0100=="NL"
*replace temp = popdist if year==2011 & sa0100=="AT"
replace temp = popdist if year==2010 & sa0100=="PT"
replace temp = popdist if year==2010 & sa0100=="SI"
replace temp = popdist if year==2010 & sa0100=="SK"
replace temp = popdist if year==2010 & sa0100=="FI"




bysort sa0100 sex age: egen popdist_base=mean(temp)
gen popdist_rel=popdist/popdist_base
keep sa0100 age year sex popdist_rel popdist


* TEST
*drop sex sa0100
*reshape wide popdist_rel popdist, i(age) j(year)
*line popdist2008 popdist2009 popdist2010 popdist2020 age if age<80
*line popdist_rel2008 popdist_rel2009 popdist_rel2010 popdist_rel2015 age if age<80


* Some data handling to reshape (generate unique ID)
encode sa0100, gen(sa0100_num)
gen long tempID = (year*100+age)*100+sa0100_num
rename popdist_rel popdist_rel_
rename popdist popdist_
reshape wide popdist_rel_ popdist_, i(tempID) j(sex, string)
drop tempID sa0100_num
aorder
sort sa0100 year age



* keep only changes in the relative distribution for the target year;
gen updateYear = "${updateYear}"
destring updateYear, replace force

* keep only relative distribution for both sexes
drop if year~=updateYear
keep age popdist_rel_Both sa0100
rename popdist_rel_Both relPopDist
label variable relPopDist "Relative change in population distribution"
rename age dhageh1



/* some TESTING figures
#delimit ;
twoway
(line relPopDist dhageh1 if sa0100=="AT", lcolor(red))
(line relPopDist dhageh1 if sa0100=="DE", lcolor(blue))
(line relPopDist dhageh1 if sa0100=="CY", lcolor(black)),
legend(on order(1 "AT" 2 "DE" 3 "CY") cols(3))
graphregion(color(white))
xtitle("age") xlabel(16(10)100)
ytitle("Relative change in population distribution") ylabel(0.6(0.2)1.6)
;
graph export "`dataPath'\fRelPopDist_1.pdf", replace;

#delimit ;
twoway
(scatter relPopDist dhageh1 if sa0100=="AT", lcolor(red))
(scatter relPopDist dhageh1 if sa0100=="DE", lcolor(blue))
(scatter relPopDist dhageh1 if sa0100=="CY", lcolor(black)),
legend(on order(1 "AT" 2 "DE" 3 "CY") cols(3))
graphregion(color(white))
xtitle("age") xlabel(16(10)80)
ytitle("Relative change in population distribution") ylabel(0.6(0.2)1.6)
;
graph export "`dataPath'\fRelPopDist_1.pdf", replace;

#delimit ;
twoway
(scatter relPopDist dhageh1 if sa0100=="GR", lcolor(red))
(scatter relPopDist dhageh1 if sa0100=="FR", lcolor(blue))
(scatter relPopDist dhageh1 if sa0100=="FI", lcolor(black)),
legend(on order(1 "GR" 2 "FR" 3 "FI") cols(3))
graphregion(color(white))
xtitle("age") xlabel(16(10)80)
ytitle("Relative change in population distribution") ylabel(0.6(0.2)1.6)
;
graph export "`dataPath'\fRelPopDist_2.pdf", replace;

#delimit ;
twoway
(scatter relPopDist dhageh1 if sa0100=="IT", lcolor(red))
(scatter relPopDist dhageh1 if sa0100=="NL", lcolor(blue))
(scatter relPopDist dhageh1 if sa0100=="MT", lcolor(black)),
legend(on order(1 "IT" 2 "NL" 3 "MT") cols(3))
graphregion(color(white))
xtitle("age") xlabel(16(10)80)
ytitle("Relative change in population distribution") ylabel(0.6(0.2)1.6)
;
graph export "`dataPath'\fRelPopDist_3.pdf", replace;

#delimit ;
twoway
(scatter relPopDist dhageh1 if sa0100=="ES", lcolor(red))
(scatter relPopDist dhageh1 if sa0100=="PT", lcolor(blue))
(scatter relPopDist dhageh1 if sa0100=="SI", lcolor(black)),
legend(on order(1 "ES" 2 "PT" 3 "SI") cols(3))
graphregion(color(white))
xtitle("age") xlabel(16(10)80)
ytitle("Relative change in population distribution") ylabel(0.6(0.2)1.6)
;
graph export "`dataPath'\fRelPopDist_4.pdf", replace;

#delimit ;
twoway
(scatter relPopDist dhageh1 if sa0100=="SK", lcolor(red))
(scatter relPopDist dhageh1 if sa0100=="BE", lcolor(blue))
(scatter relPopDist dhageh1 if sa0100=="LU", lcolor(black)),
legend(on order(1 "SK" 2 "BE" 3 "LU") cols(3))
graphregion(color(white))
xtitle("age") xlabel(16(10)80)
ytitle("Relative change in population distribution") ylabel(0.6(0.2)1.6)
;
graph export "`dataPath'\fRelPopDist_5.pdf", replace;

*/




compress
save "`dataPath'\updatePopDist.dta", replace




* prepare D_compl for weight adjusting
use "`dataPath'\D_compl.dta", clear
keep sa0100 sa0010 im0100 hw0010 dhageh1

merge m:1 dhageh1 sa0100 using "`dataPath'\updatePopDist.dta"


* hh head in IT who is 102;
replace relPopDist=1 if sa0100=="IT" & dhageh1>100
drop if sa0010==.


drop _merge
sort sa0100 im0100 sa0010
gen hw0010_adjusted = hw0010*relPopDist
drop hw0010 relPopDist

save "`dataPath'\updatePopDist.dta", replace

* -------------------------------------------------------------------------------------
