cd "C:\Documents and Settings\vogeled\Desktop\test_HFCN\"
set more off

use "D_compl.dta", clear
*keep if im0100!=1
drop if sa0100=="FI" | sa0100=="IT"

* Generate age dummies
gen agegrp=0
replace agegrp=1 if (dhageh<35)
replace agegrp=2 if (dhageh>=35 & dhageh<54)
replace agegrp=3 if (dhageh>=55)
drop if agegrp==0
tab agegrp, gen(age_d)

gen age = dhageh

* Rescale education
gen edu_1=(dheduh==1 | dheduh==0)
gen edu_2=(dheduh==2)
gen edu_3=(dheduh==3 | dheduh==4)
gen edu_4=(dheduh==5 | dheduh==6)

* Rename some variables
rename dh0001 hhmemb
rename dh0004 hhmemb_work    

* Rescale employment status (DHEMPH)
gen emp_empl=(dhemph==1)
gen emp_self=(dhemph==2)
gen emp_unemp=(dhemph==3)
gen emp_ret=(dhemph==4)
gen emp_ot=(dhemph==5 | dhemph==.)

* Rescale employment, version 2: employed, unemployed, retired
gen pens=(dhemph==4)
gen unempl=(dhemph==3)

* Gender
gen female=(dhgenderh==2)
* Position in income & wealth distribution
tab dhnq01, gen(netwquint_)
tab dhiq01, gen(incquint_)
* Income
gen hhgrossinc=di2000/1000
* Debt / Asset ratio
gen debtassratio=dodaratio
* Debt / income ratio
gen debtincratio=dodiratio
* Dummy for has debt
gen hasdebt = dl1000i
* Net wealth
gen netwealth=dn3001/1000
* Debt service ratio
gen dsr = dodstotal
gen dsr_gen = dsr
replace dsr_gen = 0 if dsr==.
* Total debt
gen totdebt=dl1000/1000
* Owner status
gen owner_outr=(dhhst==1)
gen owner_mort=(dhhst==2)
gen owner_rent=(dhhst==3)

* Thes are agents who applied for credit or did not apply due to
* perceived credit constraint
gen validobs=(docreditappl==1 | docreditnotappl==1)
tab validobs, su(docreditc)
tab sa0100 if validobs, su(docreditc)

* Country dummies
tab sa0100, gen(ctrid_)

* Generate country groups
gen ctry_group="Cont" if (sa0100=="AT" | sa0100=="BE" | sa0100=="DE" | sa0100=="FR" | sa0100=="LU" | sa0100=="NL" | sa0100=="SI" | sa0100=="SK") 
replace ctry_group="Med" if (sa0100=="CY" | sa0100=="ES" | sa0100=="GR" | sa0100=="IT" | sa0100=="MT" | sa0100=="PT")
*replace group="Otr" if  sa0100=="SI" | sa0100=="SK" | sa0100=="FI"


* Set definition for credit constr.
gen depvar = docreditc   				/* Credit constraint as define in WP */
*gen depvar = dnnla2months   			/* Net liquid assets < 2 months income */
*gen depvar = (dnnla<(di2000/12)*6)  	/* Net liquid assets < 6 months income */
*gen depvar = dl1210i					/* Has credit line/overdraft facility */
*gen depvar = dl1220i					/* Has credit card debt */

* Summary of valid vs. invalid observations
bysort validobs: su pens unempl hhgrossinc owner_* age netwealth debtincratio debtassratio hasdebt   
bysort validobs: su pens unempl hhgrossinc owner_* age netwealth debtincratio debtassratio hasdebt if pens==0


* ---------------------------------------------------------------------------------------
* 									Some Models
* ---------------------------------------------------------------------------------------

gen group = ctry_group
*gen group = sa0100


* Including levels and dummies
*xi: probit depvar i.group unempl pens age_d* edu_* netwealth hhgrossinc netwquint_* incquint_* hhmemb owner_* hasdebt dsr_gen [pweight=dwhoho]
* Including levels and dummies + interacting unemployment
xi: probit depvar i.group*unempl pens age_d* edu_* netwealth hhgrossinc netwquint_* incquint_* hhmemb owner_* hasdebt dsr_gen [pweight=dwhoho]

margins, dydx(unempl owner_outr dsr_gen hasdebt) at(hasdebt=(0 1) )
* Income and wealth elasticities
*margins, dyex(hhgrossinc netwealth) at(hasdebt=(0 1) )
*margins, dyex(hhgrossinc netwealth) atmeans
margins, dyex(hhgrossinc netwealth)

* Marginal effects by country
predict double depvar_hat, xb
gen double me_hhgrossinc = normalden(depvar_hat)*_b[hhgrossinc]
gen double me_netwealth = normalden(depvar_hat)*_b[netwealth]
sum me_hhgrossinc me_netwealth if e(sample)
tab group if e(sample), sum(me_hhgrossinc) 
margins, dydx(hhgrossinc netwealth)
drop me_hhgrossinc me_netwealth



* ----------------------------------
* Individual Country/Group Models
* ----------------------------------

* Country/Groups
levelsof group, local(ctrylist)
foreach ii of local ctrylist {
	disp "Group `ii'"
	probit depvar unempl pens age_d* edu_* netwealth hhgrossinc                        hhmemb owner_* hasdebt dsr_gen if (group=="`ii'")  
	qui est store model_S_Gr_`ii'
	probit depvar unempl pens age_d* edu_* netwealth hhgrossinc netwquint_* incquint_* hhmemb owner_* hasdebt dsr_gen if (group=="`ii'")   
	qui est store model_L_Gr_`ii'
}


log using "D:\Edgar\BorrConstr.log", replace

* Results using model w/o income/wealth levels
est table model_S*, star(0.1 0.05 0.01)

* Results using income/wealth levels
est table model_L*, star(0.1 0.05 0.01)

* Results from pooled model with group dummy
est table pooled_S pooled_L, star(0.1 0.05 0.01)

log close



probit depvar hhgrossinc
predict depvar_hat, xb
gen double me_hhgrossinc = normalden(depvar_hat)*_b[hhgrossinc]
margins, dydx(hhgrossinc)
su me_hhgrossinc if e(sample)

* Elast
gen double mel_hhgrossinc = _b[hhgrossinc]*hhgrossinc
su mel_hhgrossinc if e(sample)
margins, eyex(hhgrossinc)
