*26/03/2014;
* calculates and writes the tex table Wealth Effects on Consumption;

set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;
do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
global dataPath "`dataPath'";
****************************************;
* ADJUST;

global getConsData "0";  *downloads data from SDW, last download: 17/02/2014 [default: No/0];
global unempSimulIncomeIndex "1";  * use income implied by unemployment simulation [default: No/0];
global currentPeriod "2013Q2";
****************************************;

global eolString "_char(92) _char(92)";		* string denoting new line in LaTeX tables \\;

sca mpc_homogeneous=0.05;
sca mpc_het_1 = 0.075;
sca mpc_het_2 = 0.070;
sca mpc_het_3 = 0.05;
sca mpc_het_4 = 0.03;
sca mpc_het_5 = 0.025;

sca mpc_homogeneous=0.025;
sca mpc_het_1 = 0.04;
sca mpc_het_2 = 0.035;
sca mpc_het_3 = 0.025;
sca mpc_het_4 = 0.015;
sca mpc_het_5 = 0.01;

****************************************;

local allYears "2008 2013";
foreach year of local allYears {;

	if "$unempSimulIncomeIndex"=="1" {;
	use "`dataPath'\D_compl_`year'_unempSimul_1.dta", replace;
	};
	else {;
	use "`dataPath'\D_compl_`year'_1.dta", replace;
	};
	
	local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
	foreach cntry of local allCountries {;

		sum hw0010 if sa0100=="`cntry'", det;
		sca numHH_`cntry' = r(sum)/5;  * 5 implicates;
	
	};
	
	sum hw0010, det;
	sca numHH_EA = r(sum)/5;  * 5 implicates;
	*************************************************************************************;
	* gen pop=1;	* whole sample;
	mvdecode _all, mv(-1=.a);	* -1 are missing values;
	mvdecode _all, mv(-2=.b);	* -2 are missing values;

	**Generate income and net wealth quintiles;
	gen dhiq01_cntry = .;
	gen dhiq01_ea = .;
	
	*Define a new label so the countries are ordered according to the official ECB order;
	label define country 1 "BE" 2 "DE" 3 "GR" 4 "ES" 5 "FR" 6 "IT" 7 "CY" 8 "LU" 9 "MT" 10 "NL" 11 "AT" 12 "PT" 13 "SI" 14 "SK" 15 "FI";
	generate aux = 1 if sa0100 == "BE";
	replace aux = 2 if sa0100 == "DE";
	replace aux = 3 if sa0100 == "GR";
	replace aux = 4 if sa0100 == "ES";
	replace aux = 5 if sa0100 == "FR";
	replace aux = 6 if sa0100 == "IT";
	replace aux = 7 if sa0100 == "CY";
	replace aux = 8 if sa0100 == "LU";
	replace aux = 9 if sa0100 == "MT";
	replace aux = 10 if sa0100 == "NL";
	replace aux = 11 if sa0100 == "AT";
	replace aux = 12 if sa0100 == "PT";
	replace aux = 13 if sa0100 == "SI";
	replace aux = 14 if sa0100 == "SK";
	replace aux = 15 if sa0100 == "FI";
	label values aux country;
	rename aux cntryid;

	* j is a country number;
	forvalues j = 1(1)15 {;
	forvalues i = 1(1)5 {;           
		*Income;
		_pctile di2000 [aweight=hw0010] if im0100 == `i' & cntryid ==`j',n(5);
		replace dhiq01_cntry = 1 if im0100 == `i' & cntryid ==`j' & di2000 <= r(r1);
		replace dhiq01_cntry = 2 if im0100 == `i' & cntryid ==`j'& di2000 > r(r1) & di2000 <= r(r2);
		replace dhiq01_cntry = 3 if im0100 == `i' & cntryid ==`j'& di2000 > r(r2) & di2000 <= r(r3);
		replace dhiq01_cntry = 4 if im0100 == `i' & cntryid ==`j'& di2000 > r(r3) & di2000 <= r(r4);
		replace dhiq01_cntry = 5 if im0100 == `i' & cntryid ==`j'& di2000 > r(r4);
	};
	};

	forvalues i = 1(1)5 {;           
		*Income;
		_pctile di2000 [aweight=hw0010] if im0100 == `i',n(5);
		replace dhiq01_ea = 1 if im0100 == `i' & di2000 <= r(r1);
		replace dhiq01_ea = 2 if im0100 == `i' & di2000 > r(r1) & di2000 <= r(r2);
		replace dhiq01_ea = 3 if im0100 == `i' & di2000 > r(r2) & di2000 <= r(r3);
		replace dhiq01_ea = 4 if im0100 == `i' & di2000 > r(r3) & di2000 <= r(r4);
		replace dhiq01_ea = 5 if im0100 == `i' & di2000 > r(r4);

	};

	******* Calculate stats;
	local allVars "dn3001";
	local allDistrVars "dhiq01_cntry";

	statsby dn3001_mean=r(mean) dn3001_median=r(p50), by(cntryid dhiq01_cntry im0100) saving("`basePath'\stats\allImplicates\ds_dn3001_dhiq01_cntry.dta", replace): summarize dn3001 [aweight = hw0010], det;
	statsby dn3001_mean=r(mean) dn3001_median=r(p50), by(dhiq01_ea im0100) saving("`basePath'\stats\allImplicates\ds_dn3001_dhiq01_ea.dta", replace): summarize dn3001 [aweight = hw0010], det;

	******* Average across implicates;
	*************************************************************************************;

	*** Means and medians;

	foreach var of local allVars {;
	foreach distrVar of local allDistrVars {;
		
		drop _all;
		use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta";
		by cntryid `distrVar', sort: egen `var'_mean_mean=mean(`var'_mean);
		by cntryid `distrVar', sort: egen `var'_median_mean=mean(`var'_median);
		*by `distrVar', sort: egen `var'_sum_mean=mean(`var'_sum);
		keep if im0100==1;
		drop im0100 `var'_mean `var'_median; *`var'_sum;
		rename `var'_mean_mean `var'_mean;
		rename `var'_median_mean `var'_median;
		*rename `var'_sum_mean `var'_sum;
		order `var'_median `var'_mean; *`var'_sum;	*** Make sure the median comes before the mean (as in the tables);
		save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta", replace;
		
	};
	};

	drop _all;
	use "`basePath'\stats\allImplicates\ds_dn3001_dhiq01_ea.dta";
	by dhiq01_ea, sort: egen dn3001_mean_mean=mean(dn3001_mean);
	by dhiq01_ea, sort: egen dn3001_median_mean=mean(dn3001_median);
	keep if im0100==1;
	drop im0100 dn3001_mean dn3001_median; 
	rename dn3001_mean_mean dn3001_mean;
	rename dn3001_median_mean dn3001_median;
	order dn3001_median dn3001_mean; *** Make sure the median comes before the mean (as in the tables);
	save "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_ea.dta", replace;
	save "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_ea_`year'.dta", replace;
	
	use "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_cntry.dta";
	
	gen dn3001_median_000 = dn3001_median/1000;
	gen dn3001_mean_000 = dn3001_mean/1000;
	
	gen mpc_hom = mpc_homogeneous;
	gen mpc_het=.;
	
	forvalues incquint = 1/5 {;
		replace mpc_het = mpc_het_`incquint' if dhiq01_cntry==`incquint';
		
		sca meanWealthIT_incQ`incquint'_`year' = dn3001_mean_000[`incquint'+25];
		sca medianWealthIT_incQ`incquint'_`year' = dn3001_median_000[`incquint'+25];

		sca meanWealthFI_incQ`incquint'_`year' = dn3001_mean_000[`incquint'+70];
		sca medianWealthFI_incQ`incquint'_`year' = dn3001_median_000[`incquint'+70];
	};
	
	gen cons_hom_median = mpc_hom*dn3001_median_000;
	gen cons_het_median = mpc_het*dn3001_median_000;
	gen cons_hom_mean = mpc_hom*dn3001_mean_000;
	gen cons_het_mean = mpc_het*dn3001_mean_000;

	forvalues cntry = 1/15 {;
	
		sum cons_hom_median if cntryid==`cntry';
		sca cons_hom_median_`year'_`cntry' = r(sum);

		sum cons_hom_mean if cntryid==`cntry';
		sca cons_hom_mean_`year'_`cntry' = r(sum);
	
		sum cons_het_median if cntryid==`cntry';
		sca cons_het_median_`year'_`cntry' = r(sum);

		sum cons_het_mean if cntryid==`cntry';
		sca cons_het_mean_`year'_`cntry' = r(sum);

	};
	
	drop _all;
	
	******************;	
	use "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_ea.dta";
	gen dn3001_median_000 = dn3001_median/1000;
	gen dn3001_mean_000 = dn3001_mean/1000;
	
	gen mpc_hom = mpc_homogeneous;
	gen mpc_het=.;
	
	forvalues incquint = 1/5 {;
		replace mpc_het = mpc_het_`incquint' if dhiq01_ea==`incquint';
		sca meanWealthEA_incQ`incquint'_`year' = dn3001_mean_000[`incquint'];
		sca medianWealthEA_incQ`incquint'_`year' = dn3001_median_000[`incquint'];
	};
	
	gen cons_hom_median = mpc_hom*dn3001_median_000;
	gen cons_het_median = mpc_het*dn3001_median_000;
	gen cons_hom_mean = mpc_hom*dn3001_mean_000;
	gen cons_het_mean = mpc_het*dn3001_mean_000;

	sum cons_hom_median;
	sca cons_hom_median_`year'_ea = r(sum);

	sum cons_hom_mean;
	sca cons_hom_mean_`year'_ea = r(sum);
	
	sum cons_het_median;
	sca cons_het_median_`year'_ea = r(sum);

	sum cons_het_mean;
	sca cons_het_mean_`year'_ea = r(sum);
	
	cd "`stataPath'";
	drop _all;
};

forvalues cntry = 1/15 {;

		sca dcons_hom_median_`cntry' = (cons_hom_median_2013_`cntry'-cons_hom_median_2008_`cntry');
		sca dcons_hom_mean_`cntry' = (cons_hom_mean_2013_`cntry'-cons_hom_mean_2008_`cntry');	
		sca dcons_het_median_`cntry' = (cons_het_median_2013_`cntry'-cons_het_median_2008_`cntry');
		sca dcons_het_mean_`cntry' = (cons_het_mean_2013_`cntry'-cons_het_mean_2008_`cntry');
		
};

		sca dcons_hom_median_ea1 = (cons_hom_median_2013_ea-cons_hom_median_2008_ea);
		sca dcons_hom_mean_ea1 = (cons_hom_mean_2013_ea-cons_hom_mean_2008_ea);	
		sca dcons_het_median_ea1 = (cons_het_median_2013_ea-cons_het_median_2008_ea);
		sca dcons_het_mean_ea1 = (cons_het_mean_2013_ea-cons_het_mean_2008_ea);


	
local allCountries "BE DE GR ES FR IT CY LU MT NL AT PT SI SK FI";
* Countries have to be in this order, rename the from "numbers" to 2-letter codes;
local i = 1;

foreach cntry of local allCountries {;

		sca dcons_hom_median_`cntry' = dcons_hom_median_`i'*numHH_`cntry'/(5*1e3);  * 5 quintiles;
		sca dcons_hom_mean_`cntry' = dcons_hom_mean_`i'*numHH_`cntry'/(5*1e3);	
		sca dcons_het_median_`cntry' = dcons_het_median_`i'*numHH_`cntry'/(5*1e3);
		sca dcons_het_mean_`cntry' = dcons_het_mean_`i'*numHH_`cntry'/(5*1e3);
		local i = `i'+1;
		
};

sca dcons_hom_median_EA = dcons_hom_median_ea1*numHH_EA/(5*1e3);  * 5 quintiles;
sca dcons_hom_mean_EA = dcons_hom_mean_ea1*numHH_EA/(5*1e3);	
sca dcons_het_median_EA = dcons_het_median_ea1*numHH_EA/(5*1e3);
sca dcons_het_mean_EA = dcons_het_mean_ea1*numHH_EA/(5*1e3);


if "$getConsData"=="1" {;
	do SDW_download_Consumption_02.do;
};

use "`dataPath'\consumption_all.dta";

sca startOfRecession = "2008Q1";
sca startSmpl = quarterly(startOfRecession,"YQ")-59;

sca currentPeriod = "$currentPeriod";
sca endSmpl = quarterly(currentPeriod,"YQ")-59;

local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";

foreach cntry of local allCountries {;

	sca aggrConsLevel_`cntry' = 
	(RealCons_`cntry'[endSmpl]+RealCons_`cntry'[endSmpl-1]+RealCons_`cntry'[endSmpl-2]+RealCons_`cntry'[endSmpl-3])*(HICP_`cntry'[endSmpl]/100);
	
};

gen RealCons_EA = RealCons_AT+RealCons_BE+RealCons_CY+RealCons_DE+RealCons_ES+RealCons_FI+RealCons_FR+RealCons_GR+RealCons_IT+RealCons_LU+RealCons_MT+RealCons_NL+RealCons_PT+RealCons_SI+RealCons_SK;

sca aggrConsLevel_EA = aggrConsLevel_AT+aggrConsLevel_BE+aggrConsLevel_CY+aggrConsLevel_DE+aggrConsLevel_ES+aggrConsLevel_FI+aggrConsLevel_FR+aggrConsLevel_GR+aggrConsLevel_IT+aggrConsLevel_LU+aggrConsLevel_MT+aggrConsLevel_NL+aggrConsLevel_PT+aggrConsLevel_SI+aggrConsLevel_SK;
local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK EA";

foreach cntry of local allCountries {;

	sca dconsPerc_hom_median_`cntry' = 100*dcons_hom_median_`cntry'/aggrConsLevel_`cntry';
	sca dconsPerc_hom_mean_`cntry' = 100*dcons_hom_mean_`cntry'/aggrConsLevel_`cntry';
	sca dconsPerc_het_median_`cntry' = 100*dcons_het_median_`cntry'/aggrConsLevel_`cntry';
	sca dconsPerc_het_mean_`cntry' = 100*dcons_het_mean_`cntry'/aggrConsLevel_`cntry';
	
	sca aggrConsPerHH_`cntry'=aggrConsLevel_`cntry'/(numHH_`cntry'/1e3);
	
	sca cGrowth_`cntry' = 100*((RealCons_`cntry'[endSmpl]+RealCons_`cntry'[endSmpl-1]+RealCons_`cntry'[endSmpl-2]+RealCons_`cntry'[endSmpl-3]) /
	(RealCons_`cntry'[startSmpl]+RealCons_`cntry'[startSmpl+1]+RealCons_`cntry'[startSmpl+2]+RealCons_`cntry'[startSmpl+3])-1);
};
	
do writeWealthTable03.do;	

**** Draw bar figure;

**** Euro Area;
**************************************************';
gen dmeanWealthEA_inc = .;
gen dmedianWealthEA_inc = .;
gen dmeanWealthGrowthEA_inc = .;
gen dmedianWealthGrowthEA_inc = .;

gen dmeanConsHetEA_inc = .;
gen dmedianConsHetEA_inc = .;
gen dmeanConsHomEA_inc = .;
gen dmedianConsHomEA_inc = .;
gen dConsEA_inc_all = .;

gen incQuint =.;
gen incQuint_all =.;
gen scenario = .;
replace scenario = _n in 1/4;

forvalues incquint = 1/5 {;
		
		gen incQuint`incquint'_all =.;
		sca dmeanWealthEA_incQ`incquint' = meanWealthEA_incQ`incquint'_2013 - meanWealthEA_incQ`incquint'_2008;
		sca dmedianWealthEA_incQ`incquint' = medianWealthEA_incQ`incquint'_2013 - medianWealthEA_incQ`incquint'_2008;		
		
		sca dmeanWealthGrowthEA_incQ`incquint' = 100*(meanWealthEA_incQ`incquint'_2013 - meanWealthEA_incQ`incquint'_2008)/meanWealthEA_incQ`incquint'_2008;
		sca dmedianWealthGrowthEA_incQ`incquint' = 100*(medianWealthEA_incQ`incquint'_2013 - medianWealthEA_incQ`incquint'_2008)/medianWealthEA_incQ`incquint'_2008;		

		replace dmeanWealthEA_inc = dmeanWealthEA_incQ`incquint' in `incquint';
		replace dmedianWealthEA_inc = dmedianWealthEA_incQ`incquint' in `incquint';
		replace dmeanWealthGrowthEA_inc = dmeanWealthGrowthEA_incQ`incquint' in `incquint';
		replace dmedianWealthGrowthEA_inc = dmedianWealthGrowthEA_incQ`incquint' in `incquint';
		
		sca dmeanConsHetEA_incQ`incquint' = 1000*mpc_het_`incquint'*dmeanWealthEA_incQ`incquint';
		sca dmedianConsHetEA_incQ`incquint' = 1000*mpc_het_`incquint'*dmedianWealthEA_incQ`incquint';
		sca dmeanConsHomEA_incQ`incquint' = 1000*mpc_homogeneous*dmeanWealthEA_incQ`incquint';
		sca dmedianConsHomEA_incQ`incquint' = 1000*mpc_homogeneous*dmedianWealthEA_incQ`incquint';
		
		replace dmeanConsHetEA_inc = dmeanConsHetEA_incQ`incquint' in `incquint';
		replace dmedianConsHetEA_inc = dmedianConsHetEA_incQ`incquint' in `incquint';
		replace dmeanConsHomEA_inc = dmeanConsHomEA_incQ`incquint' in `incquint';
		replace dmedianConsHomEA_inc = dmedianConsHomEA_incQ`incquint' in `incquint';
		
		replace incQuint`incquint'_all = dmedianConsHomEA_incQ`incquint' in 1;
		replace incQuint`incquint'_all = dmeanConsHomEA_incQ`incquint' in 2;
		replace incQuint`incquint'_all = dmedianConsHetEA_incQ`incquint' in 3;
		replace incQuint`incquint'_all = dmeanConsHetEA_incQ`incquint' in 4;
		
		replace incQuint =  `incquint' in `incquint';
};

label define incLabel 1 "Less than 20" 2 "20-40"  3 "40-60" 4 "60-80" 5 "80-100";
label values incQuint incLabel;

label define scenLabel 1 "Hom MPC/Median" 2 "Hom MPC/Mean"  3 "Het MPC/Median" 4 "Het MPC/Mean";
label values scenario scenLabel;

graph bar (asis) dmedianWealthEA_inc dmeanWealthEA_inc, over(incQuint)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) 
legend(pos(7) ring(0) label(1 "Median") label(2 "Mean"))
ytitle("EUR Thousands")
graphregion(color(white));
graph export "`dataPath'\fDwealthByIncome_unemp_EA.pdf", replace;


* version for slides;
graph bar (asis) dmedianWealthEA_inc dmeanWealthEA_inc, over(incQuint)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) 
legend(pos(7) ring(0) label(1 "Median") label(2 "Mean"))
ytitle("EUR Thousands")
title("Change in Net Wealth, 2008Q1-2013Q2")
graphregion(color(white));
graph export "`dataPath'\fDwealthByIncome_Slides.pdf", replace;





graph bar (asis) dmedianConsHetEA_inc dmeanConsHetEA_inc, over(incQuint)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) 
legend(pos(7) ring(0) label(1 "Median") label(2 "Mean"))
ytitle("EUR")
graphregion(color(white));
graph export "`dataPath'\fDconsByIncome.pdf", replace;


graph bar (sum) incQuint1_all incQuint2_all incQuint3_all incQuint4_all incQuint5_all, over(scenario) stack
legend(rows(1) label(1 "Q1") label(2 "Q2") label(3 "Q3") label(4 "Q4") label(5 "Q5"))
bar(5, color(blue*5)) bar(4, color(blue*1.2)) bar(3, color(blue*0.6)) bar(2, color(blue*0.3)) bar(1, color(blue*0.10))
ytitle("EUR")
graphregion(color(white));
graph export "`dataPath'\fDconsByScen_unemp_EA.pdf", replace;



* version for slides;
graph bar (sum) incQuint1_all incQuint2_all incQuint3_all incQuint4_all incQuint5_all, over(scenario) stack
legend(rows(1) label(1 "Q1") label(2 "Q2") label(3 "Q3") label(4 "Q4") label(5 "Q5"))
bar(5, color(blue*5)) bar(4, color(blue*1.2)) bar(3, color(blue*0.6)) bar(2, color(blue*0.3)) bar(1, color(blue*0.10))
ytitle("EUR")
title("Change in Consumption, 2008Q1-2013Q2")
graphregion(color(white));
graph export "`dataPath'\fDconsByScen_unemp_EA_Slides.pdf", replace;


graph bar (asis) dmedianWealthGrowthEA_inc dmeanWealthGrowthEA_inc, over(incQuint)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) 
legend(pos(7) ring(0) label(1 "Median") label(2 "Mean"))
ytitle("Percent") ylabel(-20(5)0)
graphregion(color(white));
graph export "`dataPath'\fDwealthGrowthByIncome.pdf", replace;


**** Finland;
**************************************************';
gen dmeanWealthFI_inc = .;
gen dmedianWealthFI_inc = .;

forvalues incquint = 1/5 {;

		sca dmeanWealthFI_incQ`incquint' = 100*(meanWealthFI_incQ`incquint'_2013 - meanWealthFI_incQ`incquint'_2008)/meanWealthFI_incQ`incquint'_2008;
		sca dmedianWealthFI_incQ`incquint' = 100*(medianWealthFI_incQ`incquint'_2013 - medianWealthFI_incQ`incquint'_2008)/medianWealthFI_incQ`incquint'_2008;		
		
		replace dmeanWealthFI_inc = dmeanWealthFI_incQ`incquint' in `incquint';
		replace dmedianWealthFI_inc = dmedianWealthFI_incQ`incquint' in `incquint';

};

graph bar (asis) dmedianWealthFI_inc dmeanWealthFI_inc, over(incQuint)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) 
legend(pos(5) ring(0) label(1 "Median") label(2 "Mean"))
ytitle("Percent") ylabel(-45(5)10)
graphregion(color(white));
graph export "`dataPath'\fDwealthByIncome_FI.pdf", replace;



**** Italy;
**************************************************';
gen dmeanWealthIT_inc = .;
gen dmedianWealthIT_inc = .;

forvalues incquint = 1/5 {;

		sca dmeanWealthIT_incQ`incquint' = 100*(meanWealthIT_incQ`incquint'_2013 - meanWealthIT_incQ`incquint'_2008)/meanWealthIT_incQ`incquint'_2008;
		sca dmedianWealthIT_incQ`incquint' = 100*(medianWealthIT_incQ`incquint'_2013 - medianWealthIT_incQ`incquint'_2008)/medianWealthIT_incQ`incquint'_2008;		
		
		replace dmeanWealthIT_inc = dmeanWealthIT_incQ`incquint' in `incquint';
		replace dmedianWealthIT_inc = dmedianWealthIT_incQ`incquint' in `incquint';

};

graph bar (asis) dmedianWealthIT_inc dmeanWealthIT_inc, over(incQuint)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) 
legend(pos(5) ring(0) label(1 "Median") label(2 "Mean"))
ytitle("Percent") ylabel(-45(5)10)
graphregion(color(white));
graph export "`dataPath'\fDwealthByIncome_IT.pdf", replace;

		
	
