*26/03/2014;

cd "D:\akmaral\HFCS\HFCSupdate\MASTER\programs"

set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
global dataPath "`dataPath'";


****************************************;
* ADJUST;

global getConsData "0";  *downloads data from SDW, last download: 17/02/2014 [default: No/0];
global unempSimulIncomeIndex "1";  * use income implied by unemployment simulation [default: No/0];
global currentPeriod "2013Q2";
****************************************;

global eolString "_char(92) _char(92)";		* string denoting new line in LaTeX tables \\;

sca mpc_homogeneous=0.05;
sca mpc_het_1 = 0.075;
sca mpc_het_2 = 0.070;
sca mpc_het_3 = 0.05;
sca mpc_het_4 = 0.03;
sca mpc_het_5 = 0.025;

sca mpc_homogeneous=0.025;
sca mpc_het_1 = 0.04;
sca mpc_het_2 = 0.035;
sca mpc_het_3 = 0.025;
sca mpc_het_4 = 0.015;
sca mpc_het_5 = 0.01;

****************************************;

local allYears "2008 2013";

foreach year of local allYears {;

	if "$unempSimulIncomeIndex"=="1" {;
	use "`dataPath'\D_compl_`year'_unempSimul_1.dta", replace;
	};
	else {;
	use "`dataPath'\D_compl_`year'_1.dta", replace;
	};

	local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
	foreach cntry of local allCountries {;

		sum hw0010 if sa0100=="`cntry'", det;
		sca numHH_`cntry' = r(sum)/5;  * 5 implicates;
	
	};
	
	sum hw0010, det;
	sca numHH_EA = r(sum)/5;  * 5 implicates;
	*************************************************************************************;
	* gen pop=1;	* whole sample;
	mvdecode _all, mv(-1=.a);	* -1 are missing values;
	mvdecode _all, mv(-2=.b);	* -2 are missing values;

	**Generate income and net wealth quintiles;
	gen dhiq01_cntry = .;
	gen dhiq01_ea = .;
	*gen dhnq01_cntry = .;


	*Define a new label so the countries are ordered according to the official ECB order;
	label define country 1 "BE" 2 "DE" 3 "GR" 4 "ES" 5 "FR" 6 "IT" 7 "CY" 8 "LU" 9 "MT" 10 "NL" 11 "AT" 12 "PT" 13 "SI" 14 "SK" 15 "FI";
	generate aux = 1 if sa0100 == "BE";
	replace aux = 2 if sa0100 == "DE";
	replace aux = 3 if sa0100 == "GR";
	replace aux = 4 if sa0100 == "ES";
	replace aux = 5 if sa0100 == "FR";
	replace aux = 6 if sa0100 == "IT";
	replace aux = 7 if sa0100 == "CY";
	replace aux = 8 if sa0100 == "LU";
	replace aux = 9 if sa0100 == "MT";
	replace aux = 10 if sa0100 == "NL";
	replace aux = 11 if sa0100 == "AT";
	replace aux = 12 if sa0100 == "PT";
	replace aux = 13 if sa0100 == "SI";
	replace aux = 14 if sa0100 == "SK";
	replace aux = 15 if sa0100 == "FI";
	label values aux country;
	rename aux cntryid;

	* j is a country number;
	forvalues j = 1(1)15 {;
	forvalues i = 1(1)5 {;           
		*Income;
		_pctile di2000 [aweight=hw0010] if im0100 == `i' & cntryid ==`j',n(5);
		replace dhiq01_cntry = 1 if im0100 == `i' & cntryid ==`j' & di2000 <= r(r1);
		replace dhiq01_cntry = 2 if im0100 == `i' & cntryid ==`j'& di2000 > r(r1) & di2000 <= r(r2);
		replace dhiq01_cntry = 3 if im0100 == `i' & cntryid ==`j'& di2000 > r(r2) & di2000 <= r(r3);
		replace dhiq01_cntry = 4 if im0100 == `i' & cntryid ==`j'& di2000 > r(r3) & di2000 <= r(r4);
		replace dhiq01_cntry = 5 if im0100 == `i' & cntryid ==`j'& di2000 > r(r4);
	};
	};

forvalues i = 1(1)5 {;           
		*Income;
		_pctile di2000 [aweight=hw0010] if im0100 == `i',n(5);
		replace dhiq01_ea = 1 if im0100 == `i' & di2000 <= r(r1);
		replace dhiq01_ea = 2 if im0100 == `i' & di2000 > r(r1) & di2000 <= r(r2);
		replace dhiq01_ea = 3 if im0100 == `i' & di2000 > r(r2) & di2000 <= r(r3);
		replace dhiq01_ea = 4 if im0100 == `i' & di2000 > r(r3) & di2000 <= r(r4);
		replace dhiq01_ea = 5 if im0100 == `i' & di2000 > r(r4);

	};

	******* Calculate stats;
	local allVars "dn3001";
	local allDistrVars "dhiq01_cntry";

	statsby dn3001_mean=r(mean) dn3001_median=r(p50), by(cntryid dhiq01_cntry im0100) saving("`basePath'\stats\allImplicates\ds_dn3001_dhiq01_cntry.dta", replace): summarize dn3001 [aweight = hw0010], det;
	statsby dn3001_mean=r(mean) dn3001_median=r(p50), by(dhiq01_ea im0100) saving("`basePath'\stats\allImplicates\ds_dn3001_dhiq01_ea.dta", replace): summarize dn3001 [aweight = hw0010], det;

	******* Average across implicates;
	*************************************************************************************;

	*** Means and medians;

	foreach var of local allVars {;
	foreach distrVar of local allDistrVars {;
		
		drop _all;
		use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta";
		by cntryid `distrVar', sort: egen `var'_mean_mean=mean(`var'_mean);
		by cntryid `distrVar', sort: egen `var'_median_mean=mean(`var'_median);
		*by `distrVar', sort: egen `var'_sum_mean=mean(`var'_sum);
		keep if im0100==1;
		drop im0100 `var'_mean `var'_median; *`var'_sum;
		rename `var'_mean_mean `var'_mean;
		rename `var'_median_mean `var'_median;
		*rename `var'_sum_mean `var'_sum;
		order `var'_median `var'_mean; *`var'_sum;	*** Make sure the median comes before the mean (as in the tables);
		save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta", replace;
		
	};
	};

	drop _all;
	use "`basePath'\stats\allImplicates\ds_dn3001_dhiq01_ea.dta";
	by dhiq01_ea, sort: egen dn3001_mean_mean=mean(dn3001_mean);
	by dhiq01_ea, sort: egen dn3001_median_mean=mean(dn3001_median);
	keep if im0100==1;
	drop im0100 dn3001_mean dn3001_median; 
	rename dn3001_mean_mean dn3001_mean;
	rename dn3001_median_mean dn3001_median;
	order dn3001_median dn3001_mean; *** Make sure the median comes before the mean (as in the tables);
	save "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_ea.dta", replace;
	save "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_ea_`year'.dta", replace;
	
	use "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_cntry.dta";
	
	gen dn3001_median_000 = dn3001_median/1000;
	gen dn3001_mean_000 = dn3001_mean/1000;
	
	gen mpc_hom = mpc_homogeneous;
	gen mpc_het=.;
	
	forvalues incquint = 1/5 {;
		replace mpc_het = mpc_het_`incquint' if dhiq01_cntry==`incquint';
	};
	
	sort cntryid dhiq01_cntry;
	save "`dataPath'\wealthByCntryInc_`year'.dta", replace;

	drop _all;
	cd "`stataPath'";
};

use "`dataPath'\wealthByCntryInc_2013.dta", replace;
drop mpc_hom mpc_het dn3001_mean dn3001_median ;
rename dn3001_median_000 dn3001_median_2013;
rename dn3001_mean_000 dn3001_mean_2013;

merge 1:1 cntryid dhiq01_cntry using "`dataPath'\wealthByCntryInc_2008.dta";

drop dn3001_mean dn3001_median _merge;
rename dn3001_median_000 dn3001_median_2008;
rename dn3001_mean_000 dn3001_mean_2008;

save "`dataPath'\wealthByCntryInc_all.dta", replace;


gen numHH = .;
replace numHH = numHH_BE if cntryid == 1;
replace numHH = numHH_DE if cntryid == 2;
replace numHH = numHH_GR if cntryid == 3;
replace numHH = numHH_ES if cntryid == 4;
replace numHH = numHH_FR if cntryid == 5;
replace numHH = numHH_IT if cntryid == 6;
replace numHH = numHH_CY if cntryid == 7;
replace numHH = numHH_LU if cntryid == 8;
replace numHH = numHH_MT if cntryid == 9;
replace numHH = numHH_NL if cntryid == 10;
replace numHH = numHH_AT if cntryid == 11;
replace numHH = numHH_PT if cntryid == 12;
replace numHH = numHH_SI if cntryid == 13;
replace numHH = numHH_SK if cntryid == 14;
replace numHH = numHH_FI if cntryid == 15;

gen numHH_rel = numHH/numHH_EA;

gen cons_medianHom = mpc_hom*(dn3001_median_2013-dn3001_median_2008);
gen cons_meanHom = mpc_hom*(dn3001_mean_2013-dn3001_mean_2008);
gen cons_medianHet = mpc_het*(dn3001_median_2013-dn3001_median_2008);
gen cons_meanHet = mpc_het*(dn3001_mean_2013-dn3001_mean_2008);

gen cons_medianHom_ea = 1000*numHH_rel*mpc_hom*(dn3001_median_2013-dn3001_median_2008);
gen cons_meanHom_ea = 1000*numHH_rel*mpc_hom*(dn3001_mean_2013-dn3001_mean_2008);
gen cons_medianHet_ea = 1000*numHH_rel*mpc_het*(dn3001_median_2013-dn3001_median_2008);
gen cons_meanHet_ea = 1000*numHH_rel*mpc_het*(dn3001_mean_2013-dn3001_mean_2008);

gen wealth_median_ea = numHH_rel*(dn3001_median_2013-dn3001_median_2008);
gen wealth_mean_ea = numHH_rel*(dn3001_mean_2013-dn3001_mean_2008);


forvalues incquint = 1/5 {;

	sum cons_medianHom_ea if dhiq01_cntry==`incquint';
	sca cons_medianHom_ea_q`incquint' = r(sum);

	sum cons_meanHom_ea if dhiq01_cntry==`incquint';
	sca cons_meanHom_ea_q`incquint' = r(sum);
		
	sum cons_medianHet_ea if dhiq01_cntry==`incquint';
	sca cons_medianHet_ea_q`incquint' = r(sum);

	sum cons_meanHet_ea if dhiq01_cntry==`incquint';
	sca cons_meanHet_ea_q`incquint' = r(sum);
		
		
	sum wealth_median_ea if dhiq01_cntry==`incquint';
	sca wealth_median_ea_q`incquint' = r(sum);

	sum wealth_mean_ea if dhiq01_cntry==`incquint';
	sca wealth_mean_ea_q`incquint' = r(sum);
			
};
	
gen incQuint =.;
gen incQuint_all =.;
gen dmedianWealthEA_inc = .;
gen dmeanWealthEA_inc = .;

gen scenario = .;
replace scenario = _n in 1/4;

forvalues incquint = 1/5 {;
		
		gen incQuint`incquint'_all =.;
		
		replace incQuint`incquint'_all = cons_medianHom_ea_q`incquint' in 1;
		replace incQuint`incquint'_all = cons_meanHom_ea_q`incquint' in 2;
		replace incQuint`incquint'_all = cons_medianHet_ea_q`incquint' in 3;
		replace incQuint`incquint'_all = cons_meanHet_ea_q`incquint' in 4;
		
		replace dmedianWealthEA_inc = wealth_median_ea_q`incquint' in `incquint';
		replace dmeanWealthEA_inc = wealth_mean_ea_q`incquint' in `incquint';
		
		replace incQuint =  `incquint' in `incquint';
};

label define incLabel 1 "Less than 20" 2 "20-40"  3 "40-60" 4 "60-80" 5 "80-100";
label values incQuint incLabel;

label define scenLabel 1 "Hom MPC/Median" 2 "Hom MPC/Mean"  3 "Het MPC/Median" 4 "Het MPC/Mean";
label values scenario scenLabel;


graph bar (sum) incQuint1_all incQuint2_all incQuint3_all incQuint4_all incQuint5_all, over(scenario) stack
legend(rows(1) label(1 "Q1") label(2 "Q2") label(3 "Q3") label(4 "Q4") label(5 "Q5"))
bar(5, color(blue*5)) bar(4, color(blue*1.2)) bar(3, color(blue*0.6)) bar(2, color(blue*0.3)) bar(1, color(blue*0.10))
ytitle("EUR")
graphregion(color(white));
graph export "`dataPath'\fDconsByScen.pdf", replace;

graph bar (asis) dmedianWealthEA_inc dmeanWealthEA_inc, over(incQuint)
bar(1, color(blue*5)) bar(2, color(blue*1.2)) 
legend(pos(7) ring(0) label(1 "Median") label(2 "Mean"))
ytitle("EUR Thousands")
graphregion(color(white));
graph export "`dataPath'\fDwealthByIncome.pdf", replace;


	
