******************************************************************************************************;
* 07/05/2014;
* This program updates HFCS using aggregate series from SDW;
* deflated liabilities;
* ma smoothing version;
* heterogeneous HICP deflator for net wealth and income;
******************************************************************************************************;
set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;
* ----------------------------------------------------------------------------------------------------;
do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
global dataPath "`dataPath'";
adopath + "`stataPath'";
* ----------------------------------------------------------------------------------------------------;
capture log close;
cd "`stataPath'";
log using "`logPath'\hfcsUpdate_unempSimul.log", replace;
* ----------------------------------------------------------------------------------------------------;

sca currentPeriod = "$currentPeriod";
sca endSmpl = quarterly(currentPeriod,"YQ")-159;
sca lastDataSca = "$lastData";
sca lastData = quarterly(lastDataSca, "YQ") - 159;

******************************************************************************************************;
global adj="Y"; *seasonal adjustment variables (for SDW); *general, N: no adjustment, Y: seasonally and working day adjustment;
global padj1="S"; *for Prices, Seasonally adjusted, not working day adjusted, European Central Bank;
global padj2=3;
global padju = "S"; *for unemployment, Seasonally adjusted, not working day adjusted: S;

******************************************************************************************************;
* Reference years - Assets and Liabilities;
* interview start dates, 2000Q1=1; * Asst = assets&liabilities, Inc = income;

sca stSmplAsst_AT = "2011Q1";
sca stSmplAsst_BE = "2010Q3";
sca stSmplAsst_CY = "2010Q3";
sca stSmplAsst_DE = "2011Q1";
sca stSmplAsst_ES = "2009Q1";
sca stSmplAsst_FI = "2009Q3";
sca stSmplAsst_FR = "2009Q4";
sca stSmplAsst_GR = "2009Q3";
sca stSmplAsst_IT = "2010Q4";
sca stSmplAsst_LU = "2010Q4";
sca stSmplAsst_MT = "2010Q4";
sca stSmplAsst_NL = "2009Q4";
sca stSmplAsst_PT = "2010Q2";
sca stSmplAsst_SI = "2010Q4";
sca stSmplAsst_SK = "2010Q3";
*-----------------------------------------------------------------------------------;
* Reference years- Income;
sca stSmplInc_AT = "2009Q3";
sca stSmplInc_BE = "2009Q3";
sca stSmplInc_CY = "2009Q3";
sca stSmplInc_DE = "2009Q3"; 
sca stSmplInc_ES = "2007Q3"; 
sca stSmplInc_FI = "2009Q3";
sca stSmplInc_FR = "2009Q3"; 
sca stSmplInc_GR = "2009Q1";
sca stSmplInc_IT = "2010Q3"; 
sca stSmplInc_LU = "2009Q3"; 
sca stSmplInc_MT = "2010Q3"; 
sca stSmplInc_NL = "2009Q3"; 
sca stSmplInc_PT = "2009Q3"; 
sca stSmplInc_SI = "2009Q3"; 
sca stSmplInc_SK = "2010Q2"; 


if "$getMacroData" == "1" {;
	* Download aggregate data from SDW;
	do ./sdw/SDW_download_RPP;
	do ./sdw/SDW_download_HICP;
	do ./sdw/SDW_download_Stock;
	do ./sdw/SDW_download_WagesPC;
	do ./sdw/SDW_download_BondYields;
	do ./sdw/SDW_download_USOE;
	do ./sdw/SDW_download_D75;
	do ./sdw/SDW_download_B2B3;
	do ./sdw/SDW_download_D41;
	do ./sdw/SDW_download_IntRates;
	do ./sdw/SDW_download_CurrencyDeposits;
	do ./sdw/SDW_download_F6;

	*-----------------------------------------------------------------------------------;
	* merge and save as allMacroData.dta;
	use "$dataPath\RPP_ALL.dta";
	merge 1:1 PERIOD_NAME using "$dataPath\HICP_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\Stock_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\WagesPC_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\Yield10_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\USOE_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\D75_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\B2B3_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\D41_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\IntRates_ALL.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\CurrencyDeposits.dta";
	drop _merge;
	merge 1:1 PERIOD_NAME using "$dataPath\InsuranceTechRes.dta";
	drop _merge;

	*-----------------------------------------------------------------------------------;
	* replacements USOE ;
	local allCountries "DE GR PT";
	foreach cntry of local allCountries{;
		replace USOE_D_`cntry'= Stock_`cntry';
	};
	save "`dataPath'\allMacroData.dta", replace;
};

******************************************************************************************************;

use "`dataPath'\allMacroData.dta";
* very rough adjustment for DE - Interests;
replace D41_DE = D41_DE[_n-1] if missing(D41_DE);

gen t=_n;
tsset t;

* ma smoothing for non seasonal var;
*(1/4)*[x(t-3) + x(t-2) + x(t-1) + 1*x(t)];
local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
*local allVariables "RPP BS_F2M BS_F6 D75_C WagesPC D41";

local allVariables "RPP D75_C WagesPC";
foreach var of local allVariables {;
foreach cntry of local allCountries {;	
	tssmooth ma `var'_`cntry'_ma31 = `var'_`cntry', window(3 1);
	replace  `var'_`cntry' = `var'_`cntry'_ma31 ;
	drop `var'_`cntry'_ma31;

};
};
save "`dataPath'\allMacroDataSmooth.dta", replace;
use "`dataPath'\allMacroDataSmooth.dta";

* get the cell number for the reference periods;
foreach cntry of local allCountries {;	
	sca stSmplAsst_n_`cntry'    = quarterly(stSmplAsst_`cntry', "YQ") -159;               
	sca stSmplInc_n_`cntry'     = quarterly(stSmplInc_`cntry',"YQ")-159;
}; 





*****************************************************************************************************************;

* compute growth rates: ASSETS;
local allVariables "Stock ZCB USOE_D RPP BS_F2M BS_F6";
foreach var of local allVariables {;
foreach cntry of local allCountries {;	 
	sca `var'_growth_`cntry' = `var'_`cntry'[endSmpl]/`var'_`cntry'[stSmplAsst_n_`cntry'];
};
};
*-----------------------------------------------------------------------------------;
* HICP for Asset variables (different ref. year);
foreach cntry of local allCountries {;
	sca HICPasst_growth_`cntry' = HICP_`cntry'[endSmpl]/HICP_`cntry'[stSmplAsst_n_`cntry'];

};
*-----------------------------------------------------------------------------------;
* compute growth rates: INCOME;
local allVariables "D75_C WagesPC D41 B2B3";

foreach var of local allVariables {;
foreach cntry of local allCountries {;	 
	sca `var'_growth_`cntry' = `var'_`cntry'[endSmpl]/`var'_`cntry'[stSmplInc_n_`cntry'];
};
};
*-----------------------------------------------------------------------------------;
* HICP for Income variables (different ref. year);
foreach cntry of local allCountries {;
	sca HICPinc_growth_`cntry' = HICP_`cntry'[endSmpl]/HICP_`cntry'[stSmplInc_n_`cntry'];

};


*-----------------------------------------------------------------------------------;
* compute a deflator: start with fixing 2013Q2 (54), next fix deflator[2013Q2]=1;
* for net wealth;

foreach cntry of local allCountries {;
sca HICPasstEnd_`cntry' = HICP_`cntry'[lastData] / HICP_`cntry'[stSmplAsst_n_`cntry'];
sca HICPasstDefl_`cntry' = HICPasst_growth_`cntry' / HICPasstEnd_`cntry';
};
*-----------------------------------------------------------------------------------;
* for income;
foreach cntry of local allCountries {;
sca HICPincEnd_`cntry' = HICP_`cntry'[lastData] / HICP_`cntry'[stSmplInc_n_`cntry'];
sca HICPincDefl_`cntry' = HICPinc_growth_`cntry' / HICPincEnd_`cntry';
};


*-----------------------------------------------------------------------------------;
* Interest rates change - to compute a new DL2000 and DL2100 ONLY;

* Adjustment for missing IntR;	
replace IntRC_all_SK = IntRC_all_SK[37] if  _n==33;
replace IntRC_all_MT = IntRC_all_MT[36] if  _n==33;


local allVariables "IntRH_all IntRC_all"; 
foreach var of local allVariables {;
foreach cntry of local allCountries {;	
	
	sca `var'_growth_`cntry' = (`var'_`cntry'[endSmpl] - `var'_`cntry'[stSmplAsst_n_`cntry'])/100;
};
};
*-----------------------------------------------------------------------------------;
* replacements for missing values of B2B3, D41, D75_C;

local allCountries "FR CY MT PT DE GR";
foreach cntry of local allCountries{;
	sca B2B3_growth_`cntry' = HICPinc_growth_`cntry';   * Gross operating surplus and mixed income;
};


local allCountries "AT CY LU MT PT SK BE";    
foreach cntry of local allCountries{;
	sca D41_growth_`cntry' = HICPinc_growth_`cntry';    * Interests;
};

local allCountries "AT IT CY LU MT PT SK BE DE";
foreach cntry of local allCountries{;
	sca D75_C_growth_`cntry' = HICPinc_growth_`cntry';  * miscellaneous current transfers;
};

* replacement insurance technical reserves // BS_F6 ;
local allCountries "LU MT SK";
foreach cntry of local allCountries{;
	sca BS_F6_growth_`cntry' = HICPasst_growth_`cntry';
};


drop _all;

******************************************************************************************************;
* Update HFCS data;
if "$unempSimulIncomeIndex"=="1" {;
	use "`dataPath'\D_compl_unempSimul.dta", replace;
};
else {;
	use "`dataPath'\D_compl.dta", replace;
};

if "$unempSimulIncomeIndex"=="1" {;
	drop di2000 di1100 di1200 di1610;
	rename di2000_unempSimul di2000;
	rename di1100_unempSimul di1100;
	rename di1200_unempSimul di1200;
	rename di1610_unempSimul di1610;
};

*-----------------------------------------------------------------------------------;
* Generate proportion of volume of adjustable rate mortgages by country;

cap encode sa0100, generate(sa0100NUM) ;   //transform countries into integers (1 to 15);
gen fractionAdjustableHMR = .;   //fraction of hmr mortgages having adjustable interest rates in the data;
gen fractionAdjustable = .;      //fraction of mortgages on other propery having adjustable interest rates in the data;

forvalues i=1/15 {;
     quietly sum dl1110a if sa0100NUM == `i' [aweight = hw0010], d;
     local adjustableHMR = r(mean) * r(N);    //amount of adjustable interest rate hmr mortgages (country by country);                                
     quietly sum dl1110b if sa0100NUM == `i' [aweight = hw0010], d;
     local fixedHMR = r(mean) * r(N);     //amount of fixed interest rate hmr mortgages (country by country);
     replace fractionAdjustableHMR = `adjustableHMR' / (`adjustableHMR' + `fixedHMR') if sa0100NUM == `i';  //fraction of adjustable interest rate hmr mortgages (country by country);
                
     quietly sum dl1120a if sa0100NUM == `i' [aweight = hw0010], d;
     local adjustable = r(mean) * r(N);  //amount of adjustable interest rate other mortgages (country by country);
     quietly sum dl1120b if sa0100NUM == `i' [aweight = hw0010], d;
     local fixed = r(mean) * r(N);      //amount of fixed interest rate other mortgages (country by country);
     replace fractionAdjustable = `adjustable' / (`adjustable' + `fixed') if sa0100NUM == `i';     //fraction of adjustable interest rate other mortgages (country by country);
};

gen unknownadjustableHMR = fractionAdjustableHMR * dl1110c;  //calculate fraction of unknown hmr mortgage assumed to be adjustable;
gen unknowandjustable = fractionAdjustable * dl1120c; //calculate fraction of unknown other mortgage assumed to be adjustable;


*-----------------------------------------------------------------------------------;
* update of DL2000 and DL2100 to recompute dodstotalp and dodsmortg below;
* generate auxiliary for debt payments;

local allVariables "dl2000 dl2100"  ;
foreach var of local allVariables {; 

	gen `var'_0 = `var' ;
	replace  `var'_0 = 0 if `var'==.; 

};

* hmr mortgage - outstanding, pick only variables with variable interest rate;
gen dl1110_out = dl1110 if dl1110ai ==1;
replace  dl1110_out = unknownadjustableHMR if dl1110ci ==1;
replace  dl1110_out = 0 if dl1110_out ==.;

*other morgages - outstanding, pick only variables with variable interest rate;
gen dl1120_out = dl1120 if dl1120ai ==1;
replace dl1120_out = unknowandjustable if dl1120ci ==1;
replace dl1120_out = 0 if  dl1120_out==.;

*non mortgages- outstanding;
gen dl1200_out = dl1200;
replace dl1200_out = 0 if dl1200_out ==.;

gen dl1110_0 = 0;
gen dl1120_0 = 0;
gen dl1200_0 = 0;

local allCountries "AT BE CY DE ES FI FR GR IT LU MT NL PT SI SK";
foreach cntry of local allCountries { ;

	replace dl1110_0 = (dl1110_out*IntRH_all_growth_`cntry')  if sa0100=="`cntry'";
	replace dl1120_0 = (dl1120_out*IntRH_all_growth_`cntry')  if sa0100=="`cntry'";
	* recompute non mortgage loans, ASSUMP: variable rate for all;
	replace dl1200_0 = (dl1200_out*IntRC_all_growth_`cntry')  if sa0100=="`cntry'";
};


gen dl2000_00 = dl2000_0 + (dl1110_0/12) + (dl1120_0/12) + (dl1200_0/12);
replace dl2000_00=0 if dl2000_00<0&dl2000_00~=.;		* Replace negative payments with zero;
replace dl2000 = dl2000_00 if dl2000~=.;

gen dl2100_00 = dl2100_0 + (dl1110_0/12) + (dl1120_0/12);
replace dl2100_00=0 if dl2100_00<0&dl2100_00~=.;
replace dl2100 = dl2100_00 if dl2100~=.;

drop dl2000_0 dl2000_00 dl2100_0 dl2100_00 dl1110_0 dl1120_0 dl1200_0 dl1110_out dl1120_out dl1200_out;
*-----------------------------------------------------------------------------------;
* ASSETS and INCOME;
* Rename growth rates to be compatible with variables;
foreach cntry of local allCountries {;

	* real assets;
	sca  da1110_growth_`cntry' = RPP_growth_`cntry';      * HMR; 
	sca  da1120_growth_`cntry' = RPP_growth_`cntry';      * Other Real Estate Property;
	sca  da1130_growth_`cntry' = HICPasst_growth_`cntry'; * vehicles; 
	sca  da1131_growth_`cntry' = HICPasst_growth_`cntry'; * valuables;
	sca  da1140_growth_`cntry' = USOE_D_growth_`cntry';	  * self employment businesses;

	* financial assets;
	sca  da2101_growth_`cntry' = BS_F2M_growth_`cntry';   * deposits;	
	sca  da2102_growth_`cntry' = Stock_growth_`cntry';    * mutual funds; 
	sca  da2103_growth_`cntry' = ZCB_growth_`cntry';	  * bonds;
	sca  da2104_growth_`cntry' = USOE_D_growth_`cntry';   * non-self-employment private business;
	sca  da2105_growth_`cntry' = Stock_growth_`cntry';    * shares;	
	sca  da2106_growth_`cntry' = HICPasst_growth_`cntry'; * managed accounts;
	sca  da2107_growth_`cntry' = HICPasst_growth_`cntry'; * money owed to households;
	sca  da2108_growth_`cntry' = HICPasst_growth_`cntry'; * other assets;
	sca  da2109_growth_`cntry' = BS_F6_growth_`cntry';    * voluntary pension, whole life insurance - updated with insurance technical reserves(BS_F6);
	
	* income;
	sca  di1100_growth_`cntry' = WagesPC_growth_`cntry';  * employee income;
	sca  di1200_growth_`cntry' = B2B3_growth_`cntry'; 	  * self employment income;
	sca  di1300_growth_`cntry' = B2B3_growth_`cntry';     * rental income from real estate property;
	sca  di1400_growth_`cntry' = D41_growth_`cntry';      * income from financial investments;
	sca  di1510_growth_`cntry' = HICPinc_growth_`cntry';  * income - public pensions;
	sca  di1520_growth_`cntry' = HICPinc_growth_`cntry';  * occupational and private pension plans;
	sca  di1610_growth_`cntry' = HICPinc_growth_`cntry';  * unemployment benefits;
	sca  di1620_growth_`cntry' = HICPinc_growth_`cntry';  * income from regular social transfers;
	sca  di1700_growth_`cntry' = D75_C_growth_`cntry'; 	  * income from private transfers;
	sca  di1800_growth_`cntry' = HICPinc_growth_`cntry';  * other income;
	
	* liabilities;
	sca  dl1110_growth_`cntry' = HICPasst_growth_`cntry';    * HMR mortgages;
	sca  dl1120_growth_`cntry' = HICPasst_growth_`cntry';    * other properties mortgages;
	sca  dl1200_growth_`cntry' = HICPasst_growth_`cntry';    * non-mortgages;
	
};

local allVariables "da1110 da1120 da1130 da1131 da1140 da2101 da2102 da2103 da2104 da2105 da2106 da2107 da2108 da2109 di1100 di1200 di1300 di1400 di1510 di1520 di1610 di1620 di1700 di1800 dl1110 dl1120 dl1200"; 
foreach var of local allVariables {;	
foreach cntry of local allCountries {;
	
	replace  `var' = `var'*`var'_growth_`cntry' if sa0100=="`cntry'";

};
};

******************************************************************************************************;
* recalculate NET WEALTH, INCOME, DEBT BURDEN;
do recalculateNetWealth_07;
do recalculateIncome_05;
do recalculateDebtBurden;
do recalculateLiabilities; * only for scenario B, updated 06/03/2014;

local updateYear "$updateYear";
local RealIndex  "$RealIndex";

if "$unempSimulIncomeIndex"~="1" {;
	gen job_aftershock=.;
};

keep di2000 dn3001 dnnla dl1000 da1000 da2100 da3001 dodstotalp dodsmortg dodaratio dodiratio dnnlaratio doltvratio 
dh0001 dhhst dhageh1b dhageh1 dhhtype dheduh1 dhemph1 ditop10 dntop10 
sa0010 sa0100 hw0010 im0100 job_aftershock id
da1110 da1120 da1130 da1131 da1140 da2101 da2102 da2103 da2104 da2105 da2106 da2107 da2108 da2109
dodstotal40p dl1000i dhhst docreditc;

sort sa0100 im0100 sa0010;
 
 
 
if "$unempSimulIncomeIndex"=="1" {;
	save "`dataPath'\D_compl_`updateYear'_unempSimul_`RealIndex'.dta", replace;
	erase "`dataPath'\D_compl_unempSimul.dta";
};
else {;
	save "`dataPath'\D_compl_`updateYear'_`RealIndex'.dta", replace;
};

log close;
******************************************************************************************************;
