*24/10/2013;
*This program creates new variables and saves extended data files;

set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
*************************************************************************************;
capture log close;
cd "`stataPath'";
log using "`logPath'\newvariables.log", replace;
local updateYear "$updateYear";
local RealIndex  "$RealIndex";

*----------------------------------------------------------------------;
* update population weights;
if "$adjustPopWeights" == "1" {;
	do adjustPopWeights.do;
};
*----------------------------------------------------------------------;
if "$unempSimulIncomeIndex"=="1" {;
	use "`dataPath'\D_compl_`updateYear'_unempSimul_`RealIndex'.dta";
};
else {;
	use "`dataPath'\D_compl_`updateYear'_`RealIndex'.dta";
};

*----------------------------------------------------------------------;
* merge with updated weights;
if "$adjustPopWeights" == "1" {;
	
	merge 1:1 sa0100 im0100 sa0010 dhageh1 using "`dataPath'\updatePopDist.dta";
	drop hw0010 _merge;
	rename hw0010_adjusted hw0010;
	*erase "`dataPath'\updatePopDist.dta";
	
};

*----------------------------------------------------------------------;
******* Generate additional (rougher) classification variables;
*************************************************************************************;
gen pop=1;	* whole sample;
mvdecode _all, mv(-1=.a);	* -1 are missing values;
mvdecode _all, mv(-2=.b);	* -2 are missing values;

*Household size;
gen dmdh0001 = dh0001;
replace dmdh0001 = 5 if dh0001 > 5;

*New categories for housing status;
gen dmdhhst = dhhst;

*Age brackets;
gen dmdhageh=16;
*replace dmdhageh=25 if dhageh1b == 6 | dhageh1b == 7;
replace dmdhageh=35 if dhageh1b == 8 | dhageh1b == 9;
replace dmdhageh=45 if dhageh1b == 10 | dhageh1b == 11;
replace dmdhageh=55 if dhageh1b == 12 | dhageh1b == 13;
replace dmdhageh=65 if dhageh1b == 14 | dhageh1b == 15;
replace dmdhageh=75 if dhageh1b == 16 | dhageh1b == 17 | dhageh1b == 18;

gen dmdhhtype=dhhtype;
replace dmdhhtype=6 if dhhtype==7;
replace dmdhhtype=10 if dhhtype==11|dhhtype==12;

*** Redefine dmdhhtype so that stats in the table show up in the order I want;
gen dmdhhtype_j=0;
replace dmdhhtype_j=1 if dmdhhtype==9;
replace dmdhhtype_j=2 if dmdhhtype==51;
replace dmdhhtype_j=3 if dmdhhtype==52;
replace dmdhhtype_j=4 if dmdhhtype==10;
replace dmdhhtype_j=5 if dmdhhtype==6;

*New categories for education level;

gen dmdheduh_j=dheduh1;
replace dmdheduh_j=1 if dheduh1==0|dheduh1==2;
replace dmdheduh_j=2 if dheduh1==3|dheduh1==4;
replace dmdheduh_j=3 if dheduh1==5|dheduh1==6;

*Work status;
gen dmdhemph1 = dhemph1;
replace dmdhemph1 = 5 if dhemph1 == 3;
replace dmdhemph1 = 3 if dmdhemph1 == 4;
replace dmdhemph1 = 4 if dmdhemph1 == 5;

******* Generate 'income composition' variables for tables 2 and 3;
*************************************************************************************;
/*
gen di1100_j = di1100;
replace di1100_j = 0 if di1100_j == .;
gen di1200_j = di1200;
replace di1200_j = 0 if di1200_j == .;
gen di1500_j = di1500;
replace di1500_j = 0 if di1500_j == .;
gen di1600_j = di1600;
replace di1600_j = 0 if di1600_j == .;
gen di1610_j = di1610;
replace di1610_j = 0 if di1610_j == .;
gen di1620_j = di1620;
replace di1620_j = 0 if di1620_j == .;
gen di1700_j = di1700;
replace di1700_j = 0 if di1700_j == .;
gen di1420_j = di1420;
replace di1420_j = 0 if di1420_j == .;
gen dirents_j = di1300;
replace dirents_j = 0 if dirents_j == .;
gen ditfgross_j = di1400;
replace ditfgross_j = 0 if ditfgross_j == .;

gen icomp1 = di1100_j + di1200_j + di1500_j + di1610_j;
replace icomp1 = 0 if icomp1 == .;
gen icomp2 = di1620_j;
replace icomp2 = 0 if icomp2 == .;
gen icomp3 = dirents_j;
replace icomp3 = 0 if icomp3 == .;
gen icomp4 = ditfgross_j;
replace icomp4 = 0 if icomp4 == .;
gen otherincome = di2000-di1100_j-di1200_j-di1500_j-di1420_j-di1600_j-di1700_j-dirents_j-ditfgross_j;
gen icomp5 = di1700_j + di1420_j + otherincome;
replace icomp5 = 0 if icomp5 == .;

gen icomp1s = icomp1/di2000;
gen icomp2s = icomp2/di2000;
gen icomp3s = icomp3/di2000;
gen icomp4s = icomp4/di2000;
gen icomp5s = icomp5/di2000;

gen icomp1i = 1 if icomp1 > 0;
replace icomp1i = 0 if icomp1i == .;
gen icomp2i = 1 if icomp2 > 0;
replace icomp2i = 0 if icomp2i == .;
gen icomp3i = 1 if icomp3 > 0;
replace icomp3i = 0 if icomp3i == .;
gen icomp4i = 1 if icomp4 > 0;
replace icomp4i = 0 if icomp4i == .;
gen icomp5i = 1 if icomp5 > 0;
replace icomp5i = 0 if icomp5i == .;

**Generate participation variables for those holding the asset;

gen direntsi = di1300/di2000 if di1300 != .;
gen ditfgrossi = di1400/di2000 if di1400 != .;
*/

**Generate income and net wealth quintiles;
gen dhiq01_ea = .;
gen dhnq01_ea = .;

forvalues i = 1(1)5 {;
            
*Income;
_pctile di2000 [aweight=hw0010] if im0100 == `i',n(5);
replace dhiq01_ea = 1 if im0100 == `i' & di2000 <= r(r1);
replace dhiq01_ea = 2 if im0100 == `i' & di2000 > r(r1) & di2000 <= r(r2);
replace dhiq01_ea = 3 if im0100 == `i' & di2000 > r(r2) & di2000 <= r(r3);
replace dhiq01_ea = 4 if im0100 == `i' & di2000 > r(r3) & di2000 <= r(r4);
replace dhiq01_ea = 5 if im0100 == `i' & di2000 > r(r4);

*Net wealth;
_pctile dn3001 [aweight=hw0010] if im0100 == `i',n(5);
replace dhnq01_ea = 1 if im0100 == `i' & dn3001 <= r(r1);
replace dhnq01_ea = 2 if im0100 == `i' & dn3001 > r(r1) & dn3001 <= r(r2);
replace dhnq01_ea = 3 if im0100 == `i' & dn3001 > r(r2) & dn3001 <= r(r3);
replace dhnq01_ea = 4 if im0100 == `i' & dn3001 > r(r3) & dn3001 <= r(r4);
replace dhnq01_ea = 5 if im0100 == `i' & dn3001 > r(r4);
};

*** Redefine top ditop10 and dntop10 (create indicators of top 10/5/1 percent of income/wealth);
gen ditop10_j=0;
replace ditop10_j=1 if ditop10>=90;
gen ditop5_j=0;
replace ditop5_j=1 if ditop10>=95;
gen ditop1_j=0;
replace ditop1_j=1 if ditop10==99;

gen dntop10_j=0;
replace dntop10_j=1 if dntop10>=90;
gen dntop5_j=0;
replace dntop5_j=1 if dntop10>=95;
gen dntop1_j=0;
replace dntop1_j=1 if dntop10==99;

*Define a new label so the countries are ordered according to the official ECB order;
label define country 1 "BE" 2 "DE" 3 "GR" 4 "ES" 5 "FR" 6 "IT" 7 "CY" 8 "LU" 9 "MT" 10 "NL" 11 "AT" 12 "PT" 13 "SI" 14 "SK" 15 "FI";
generate aux = 1 if sa0100 == "BE";
replace aux = 2 if sa0100 == "DE";
replace aux = 3 if sa0100 == "GR";
replace aux = 4 if sa0100 == "ES";
replace aux = 5 if sa0100 == "FR";
replace aux = 6 if sa0100 == "IT";
replace aux = 7 if sa0100 == "CY";
replace aux = 8 if sa0100 == "LU";
replace aux = 9 if sa0100 == "MT";
replace aux = 10 if sa0100 == "NL";
replace aux = 11 if sa0100 == "AT";
replace aux = 12 if sa0100 == "PT";
replace aux = 13 if sa0100 == "SI";
replace aux = 14 if sa0100 == "SK";
replace aux = 15 if sa0100 == "FI";
label values aux country;
drop sa0100;
rename aux sa0100; 

if "$unempSimulIncomeIndex"=="1" {;
	save "`dataPath'\D_compl_`updateYear'_unempSimul_`RealIndex'_extended.dta", replace;	
};
else {;
	save "`dataPath'\D_compl_`updateYear'_`RealIndex'_extended.dta", replace;
};


