******************************************************************************************************;
* This file uses SDW codes to download B2B3 - Gross operating surplus and mixed income

******************************************************************************************************;

local dataPath "$dataPath"
clear
set more off
* Set source
odbc query "sdw", user(pub) password(pub)

* if adjustment "Y", seasonally and working day adjusted
* if adjustment "N", no adjustment

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ESA.Q.`ii'.$adj.0000.B2_3G0.1000.TTTT.V.N.A',obs_value,null)) VAL_`ii' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ESA_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('ESA.Q.`ii'.$adj.0000.B2_3G0.1000.TTTT.V.N.A') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
compress
save "`dataPath'\B2B3_`ii'.dta", replace	
}



* ---------------------------------------------------------------------------------------------------------------------------;
* Merge Data
use "`dataPath'\B2B3_AT.dta", clear

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
		merge PERIOD_NAME using "`dataPath'\B2B3_`ii'.dta"
		drop _merge
		sort PERIOD_NAME
		display "`ii' matched"
		rename VAL_`ii' B2B3_`ii'
        label variable B2B3_`ii' "B2+B3: Gross Opeating Surplus and Mixed Income"
		erase "`dataPath'\B2B3_`ii'.dta"
}
* ---------------------------------------------------------------------------------------------------------------------------;
* drop countries we don't need
drop B2B3_EE B2B3_IE

* drop periods we don't need
gen period = _n
keep if period >100
drop period 

* missing values for FR, CY, MT, PT, DE
local allVariables "B2B3_FR B2B3_CY B2B3_MT B2B3_PT B2B3_DE" 
foreach var of local allVariables {	

	replace  `var' = 1 if `var'==.
}
* partially available for GR, replace
replace B2B3_GR = 1


save "`dataPath'\B2B3_ALL.dta", replace
clear
* ---------------------------------------------------------------------------------------------------------------------------;







 
