******************************************************************************************************;
* Download Long-term interest rate for convergence purposes // Bond Yields 
******************************************************************************************************;

local dataPath "$dataPath"
clear
set more off
* Set source
odbc query "sdw", user(pub) password(pub)

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
clear
odbc load/*
*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'IRS.Q.`ii'.L.L40.CI.0000.EUR.N.Z',obs_value,null)) val_`ii' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_IRS_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('IRS.Q.`ii'.L.L40.CI.0000.EUR.N.Z') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
compress
save "`dataPath'\Yield10_`ii'.dta", replace	
}
* ---------------------------------------------------------------------------------------------------------------------------;
* Non euro area countries to construct world stock performance

* US
clear
odbc load/*
*/ , exec("SELECT max(period_name) period_name ,max(decode(series_key, 'FM.Q.US.USD.BL.BB.USGG10YR.HSTA',obs_value,null)) VAL_US FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_FM_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('FM.Q.US.USD.BL.BB.USGG10YR.HSTA') ) group by obs_date order by obs_date ") user(pub) password(pub) 
sort PERIOD_NAME
compress
save "`dataPath'\Yield10_US.dta", replace
clear


* UK
clear	
odbc load/*
*/ , exec("SELECT max(period_name) period_name ,max(decode(series_key, 'FM.Q.GB.GBP.RT.BB.GB10YT_RR.YLDA',obs_value,null)) VAL_UK FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_FM_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('FM.Q.GB.GBP.RT.BB.GB10YT_RR.YLDA') ) group by obs_date order by obs_date ") user(pub) password(pub) 
sort PERIOD_NAME
compress
save "`dataPath'\Yield10_UK.dta", replace
clear

* JP
clear	
odbc load/*
*/ , exec("SELECT max(period_name) period_name ,max(decode(series_key, 'FM.Q.JP.JPY.RT.BB.JP10YT_RR.YLDA',obs_value,null)) VAL_JP FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_FM_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('FM.Q.JP.JPY.RT.BB.JP10YT_RR.YLDA') ) group by obs_date order by obs_date ") user(pub) password(pub) 
sort PERIOD_NAME
compress
save "`dataPath'\Yield10_JP.dta", replace
clear


* ---------------------------------------------------------------------------------------------------------------------------;
* Merge Data
use "`dataPath'\Yield10_AT.dta", clear
global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE US UK JP"
foreach ii of global ctrylist {
		merge PERIOD_NAME using "`dataPath'\Yield10_`ii'.dta"
		drop _merge
		sort PERIOD_NAME
		display "`ii' matched"
		rename VAL_`ii' Yield10_`ii'
		label variable Yield10_`ii' "Long-term interest rate for convergence purposes"
		
		* Compute zero coupon bond
		gen ZCB_`ii' = 100/((1+Yield10_`ii'/100)^10)
		label variable ZCB_`ii' "Zero coupon bond, face value=100"
		drop Yield10_`ii'
		erase "`dataPath'\Yield10_`ii'.dta"
}
* ---------------------------------------------------------------------------------------------------------------------------;

* drop countries we don't need
drop ZCB_EE ZCB_IE

* drop periods we don't need
gen period = _n
keep if period >80
drop period

save "`dataPath'\Yield10_ALL.dta", replace
clear
* ---------------------------------------------------------------------------------------------------------------------------;










