******************************************************************************************************;
* This file downloads employees per sector;

******************************************************************************************************;

* Clear Memory
capture log close
clear
set more off

* Set source
odbc query "sdw", user(pub) password(pub)


* --------------------------------------------------
* Import Country by Country Property Prices
* Step 1: download series
* Step 2: rename OBS_VAL to country specific value
* Step 3: sort by date (to merge) and save
* --------------------------------------------------

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
clear
	local nacelist ="2A_A 2B_E 2C_C 2F_F 2G_I 2J_J 2K_K 2L_L 2M_N 2O_Q 2R_U TTTT"
	foreach ij of local nacelist {
	clear
	odbc load, /*
	*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ESA.Q.`ii'.$adj.1000.EMPLOY.0000.`ij'.N.P.A',obs_value,null)) val_`ii'_`ij' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ESA_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id AND SERIES_KEY IN ('ESA.Q.`ii'.$adj.1000.EMPLOY.0000.`ij'.N.P.A') ) group by obs_date order by obs_date ") user(pub) password(pub) 
	sort PERIOD_NAME
	compress
	save Employment_`ii'_`ij'.dta, replace	
		
	display "`ii' `ij' downloaded"
	}
}
* --------------------------------------------------
* Merge Data
* Outer loop: country
* Inner loop: industry
global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
		use Employment_`ii'_2A_A.dta, clear
		rename VAL_`ii'_2A_A EMPL_2A_A
	    local nacelist ="2B_E 2C_C 2F_F 2G_I 2J_J 2K_K 2L_L 2M_N 2O_Q 2R_U TTTT"
		foreach ij of local nacelist {
			merge PERIOD_NAME using Employment_`ii'_`ij'.dta
			rename VAL_`ii'_`ij' EMPL_`ij'
			drop _merge
			sort PERIOD_NAME
			display "`ii' `ij' matched"
		}
		gen ctryid = "`ii'"
		save Employment_Sect_`ii'.dta, replace
}
* --------------------------------------------------
* Rename variables, reshape into "Long" and save
use Employment_Sect_AT.dta, clear
global ctrylist = "NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE" /* use country AT as a starting data set*/
foreach ii of global ctrylist {
	append using Employment_Sect_`ii'.dta	
}
rename PERIOD_NAME date

label variable EMPL_2A_A "Employees NACE Sector A"
label variable EMPL_2B_E "Employees NACE Sector B_E"
label variable EMPL_2C_C "Employees NACE Sector C"
label variable EMPL_2F_F "Employees NACE Sector F"
label variable EMPL_2G_I "Employees NACE Sector G-I"
label variable EMPL_2J_J "Employees NACE Sector J"
label variable EMPL_2K_K "Employees NACE Sector K"
label variable EMPL_2L_L "Employees NACE Sector L"
label variable EMPL_2M_N "Employees NACE Sector M-N"
label variable EMPL_2O_Q "Employees NACE Sector Q"
label variable EMPL_2R_U "Employees NACE Sector R-U"
label variable EMPL_TTTT "Employees, All sectors"

* Rename variables 
global nacelist ="A_A B_E C_C F_F G_I J_J K_K L_L M_N O_Q R_U"
foreach ii of global nacelist {
	rename EMPL_2`ii' EMPL_`ii'
}
rename EMPL_TTT EMPL_ALL


compress
sort ctryid date
save Employees_Sect_ALL.dta, replace
clear
* --------------------------------------------------



* "2A_A 2B_E 2C_C 2F_F 2G_I 2J_J 2K_K 2L_L 2M_N 2O_Q 2R_U"



 
