******************************************************************************************************;
* This file downloads HICP data - seasonally adjusted - monthly converted to quarterly;

******************************************************************************************************;

local dataPath "$dataPath"
clear
set more off
odbc query "sdw", user(pub) password(pub)

global ctrylist = "AT NL FR GR IT CY ES LU MT PT SI SK FI BE DE"
foreach ii of global ctrylist {
clear
odbc load,/*
*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ICP.M.`ii'.$padj1.000000.$padj2.INX',obs_value,null)) val_`ii' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ICP_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('ICP.M.`ii'.$padj1.000000.$padj2.INX') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
compress
save "`dataPath'\HICP_`ii'.dta", replace	
}

* ---------------------------------------------------------------------------------------------------------------------------;
* Merge Data
use "`dataPath'\HICP_AT.dta", clear
global ctrylist = "AT NL FR GR IT CY ES LU MT PT SI SK FI BE DE"
foreach ii of global ctrylist {
		merge PERIOD_NAME using "`dataPath'\HICP_`ii'.dta"
		drop _merge
		sort PERIOD_NAME
		display "`ii' matched"
		rename VAL_`ii' HICP_`ii'
		label variable HICP_`ii' "End of quarter level of HICP"
		erase "`dataPath'\HICP_`ii'.dta"
}
* ---------------------------------------------------------------------------------------------------------------------------;
* Pick only quarter-end values
gen date_test = monthly(PERIOD_NAME, "YM")
format date_test %tm

gen temp_y= yofd(dofm(date_test))
format temp_y %ty
gen temp_q= qofd(dofm(date_test))
format temp_q %tq

sort temp_q date_test
by temp_q: gen t=_n
keep if t==3

sort temp_y temp_q
list temp_y temp_q
drop t
by temp_y: gen t=_n
gen qind="Q1" if t==1
replace qind="Q2" if t==2
replace qind="Q3" if t==3
replace qind="Q4" if t==4

gen y_str = string(temp_y)
replace PERIOD_NAME = y_str + qind
* ---------------------------------------------------------------------------------------------------------------------------;
* drop periods we don't need
gen period = _n
keep if period >60
drop period
drop date_test temp_y temp_q t qind y_str

save "`dataPath'\HICP_ALL.dta", replace
clear
* ---------------------------------------------------------------------------------------------------------------------------;







