******************************************************************************************************;
* This file downloads Interest rates, long, medium, short and weighted for consumption and house purchase;

******************************************************************************************************;

local dataPath "$dataPath"
clear
set more off
odbc query "sdw", user(pub) password(pub)
* ---------------------------------------------------------------------------------------------------------------------------;
global ctrylist = "AT NL FR GR IT CY ES LU MT PT SI SK FI BE DE"
foreach ii of global ctrylist {
clear
	local matlist ="I F A"
	foreach ij of local matlist {
	clear
	odbc load/*
	*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'MIR.M.`ii'.B.A2B.`ij'.R.A.2250.EUR.N',obs_value,null)) val_`ii'_`ij' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_MIR_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('MIR.M.`ii'.B.A2B.`ij'.R.A.2250.EUR.N') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
	sort PERIOD_NAME
	compress
	
	save "`dataPath'\IntRates_`ii'_`ij'.dta", replace
	}
	
	* Download long term HH-interest Rate
	local matlist ="AM P"
	foreach ij of local matlist {
	clear
	odbc load/*
	*/, exec("SELECT max(period_name) period_name ,max(decode(series_key, 'MIR.M.`ii'.B.A2C.`ij'.R.A.2250.EUR.N',obs_value,null)) val_`ii'_`ij' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_MIR_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('MIR.M.`ii'.B.A2C.`ij'.R.A.2250.EUR.N') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
	sort PERIOD_NAME
	compress
	save "`dataPath'\IntRates_`ii'_`ij'.dta", replace	
	}
}
* ---------------------------------------------------------------------------------------------------------------------------;
* Merge Data
* Outer loop: country
* Inner loop: industry
global ctrylist = "AT NL FR GR IT CY ES LU MT PT SI SK FI BE DE"
foreach ii of global ctrylist {
		use "`dataPath'\IntRates_`ii'_P.dta", clear
		rm "`dataPath'\IntRates_`ii'_P.dta"
			
		rename VAL_`ii'_P IntR_P
	    local matlist ="I F AM A"
		foreach ij of local matlist {
			merge PERIOD_NAME using "`dataPath'\IntRates_`ii'_`ij'.dta"
			rm "`dataPath'\IntRates_`ii'_`ij'.dta"	
			rename VAL_`ii'_`ij' IntR_`ij'
			drop _merge
			sort PERIOD_NAME
			display "`ii' `ij' matched"
		}
		gen ctryid = "`ii'"
		sort PERIOD_NAME
		* Introduce MA process
		gen t=_n
		tsset t
		local matlist ="P I F AM A"
		foreach ij of local matlist {
			tssmooth ma IntR_`ij'=IntR_`ij', window(2 1 0) replace
		}
		drop t
		save "`dataPath'\IntRates_`ii'.dta", replace
}
* ---------------------------------------------------------------------------------------------------------------------------;
* Rename variables, reshape into "Long" and save
use "`dataPath'\IntRates_AT.dta", clear
rm "`dataPath'\IntRates_AT.dta"
global ctrylist = "NL FR GR IT CY ES LU MT PT SI SK FI BE DE" /* use country AT as a starting data set*/
foreach ii of global ctrylist {
	append using "`dataPath'\IntRates_`ii'.dta"
	rm "`dataPath'\IntRates_`ii'.dta"
}
* ---------------------------------------------------------------------------------------------------------------------------;
* Pick only quarter-end values
gen date_test = monthly(PERIOD_NAME, "YM")
format date_test %tm

gen temp_y= yofd(dofm(date_test))
format temp_y %ty
gen temp_q= qofd(dofm(date_test))
format temp_q %tq

sort ctryid temp_q date_test
by ctryid temp_q: gen t=_n
keep if t==3

sort ctryid temp_y temp_q
*list temp_y temp_q
drop t
by ctryid temp_y: gen t=_n
gen qind="Q1" if t==1
replace qind="Q2" if t==2
replace qind="Q3" if t==3
replace qind="Q4" if t==4

gen y_str = string(temp_y)

replace PERIOD_NAME = y_str + qind
* ---------------------------------------------------------------------------------------------------------------------------;
* Rename variables 
rename IntR_P IntR_L_ 
rename IntR_I IntR_M_
rename IntR_F IntR_S_
rename IntR_AM IntRH_all_
rename IntR_A  IntRC_all_
label variable IntR_L_ "Rate for Loans > 10 years"
label variable IntR_M_ "Rate for Loans 1><5 years"
label variable IntR_S_ "Rate for Loans <1 year"
label variable IntRH_all_ "Rate for all Housing loans (weighted)"
label variable IntRC_all_ "Rate for all Consump loans (weighted)"
* ---------------------------------------------------------------------------------------------------------------------------;
* Select only relevant time series and save
keep PERIOD_NAME IntR*  ctryid
compress
sort ctryid PERIOD_NAME
reshape wide IntR_L_  IntR_M_ IntR_S_ IntRH_all_ IntRC_all_, i(PERIOD_NAME) j(ctryid) string
* drop periods we don't need
gen period = _n
keep if period >80
drop period

* Imputation for NL
* Data before 2009Q4 missing for consumption loans
encode PERIOD_NAME, gen(time)
sort time
gen ind=(IntRC_all_NL[_n-1]==. & _n>1)
replace ind=0 if IntRC_all_NL==.
gen temp=IntRC_all_NL/IntRH_all_NL if ind==1
egen C_H_ratio=mean(temp)
replace IntRC_all_NL=C_H_ratio*IntRH_all_NL if  IntRC_all_NL==.
drop time ind C_H_ratio temp

* Imputation for LU
* data for 2013Q3 missing: mean of Q2-Q4
gen tempQ2=IntRC_all_LU if PERIOD_NAME=="2012Q2"
gen tempQ4=IntRC_all_LU if PERIOD_NAME=="2012Q4"
egen tempmeanQ2=mean(tempQ2)
egen tempmeanQ4=mean(tempQ4)
gen temp_imputed=(tempmeanQ2+tempmeanQ4)/2
replace IntRC_all_LU=temp_imputed if IntRC_all_LU==. &  PERIOD_NAME=="2012Q3"
drop temp*

* Imputation for MT
* data for 2013Q1 missing: mean of Q4-Q2
gen tempQ4=IntRC_all_MT if PERIOD_NAME=="2012Q4"
gen tempQ2=IntRC_all_MT if PERIOD_NAME=="2013Q2"
egen tempmeanQ4=mean(tempQ4)
egen tempmeanQ2=mean(tempQ2)
gen temp_imputed=(tempmeanQ4+tempmeanQ2)/2
replace IntRC_all_MT=temp_imputed if IntRC_all_MT==. &  PERIOD_NAME=="2013Q1"
drop temp*

* data for 2010Q13missing: mean of Q2-Q4
gen tempQ2=IntRC_all_MT if PERIOD_NAME=="2012Q2"
gen tempQ4=IntRC_all_MT if PERIOD_NAME=="2012Q4"
egen tempmeanQ2=mean(tempQ2)
egen tempmeanQ4=mean(tempQ4)
gen temp_imputed=(tempmeanQ2+tempmeanQ4)/2
replace IntRC_all_MT=temp_imputed if IntRC_all_MT==. &  PERIOD_NAME=="2010Q3"
drop temp*

* data for 2009Q1-2010Q1 missing
gen temp=IntRC_all_CY/IntR_S_CY if PERIOD_NAME=="2010Q1"
egen C_S_ratio=mean(temp)
replace IntRC_all_CY=C_S_ratio*IntR_S_CY if IntRC_all_CY==.
drop C_S_ratio temp


save "`dataPath'\IntRates_ALL.dta", replace
clear
* ---------------------------------------------------------------------------------------------------------------------------;




 
