******************************************************************************************************;
* This file downloads wages, employment (aggregates) and computes the per capita values;

******************************************************************************************************;

local dataPath "$dataPath"
clear
set more off
odbc query "sdw", user(pub) password(pub)
* ---------------------------------------------------------------------------------------------------------------------------;
* wages (aggregate)

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
clear
odbc load, /*
*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ESA.Q.`ii'.N.1000.D11000.0000.TTTT.V.N.A',obs_value,null)) val_`ii' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ESA_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id AND SERIES_KEY IN ('ESA.Q.`ii'.N.1000.D11000.0000.TTTT.V.N.A') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
sort PERIOD_NAME
compress

save "`dataPath'\Wages_`ii'.dta", replace	
}
* Merge Data
use "`dataPath'\Wages_AT.dta", clear

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
		merge PERIOD_NAME using "`dataPath'\Wages_`ii'.dta"
		drop _merge
		sort PERIOD_NAME
		display "`ii' matched"
		erase "`dataPath'\Wages_`ii'.dta"
		rename VAL_`ii' Wages_`ii'
}
save "`dataPath'\Wages_ALL.dta", replace
clear
* ---------------------------------------------------------------------------------------------------------------------------;
* employment (aggregate)
* ---------------------------------------------------------------------------------------------------------------------------;

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
clear
odbc load, /*
*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'ESA.Q.`ii'.N.1000.EMPLOY.0000.TTTT.N.P.A',obs_value,null)) val_`ii' FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_ESA_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id AND SERIES_KEY IN ('ESA.Q.`ii'.N.1000.EMPLOY.0000.TTTT.N.P.A') ) group by obs_date order by obs_date ") user(pub) password(pub) 
sort PERIOD_NAME
compress
save "`dataPath'\Employees_`ii'.dta", replace	
}

* Merge Data
use "`dataPath'\Employees_AT.dta", clear

global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
		merge PERIOD_NAME using "`dataPath'\Employees_`ii'.dta"
		drop _merge
		sort PERIOD_NAME
		display "`ii' matched"
		erase "`dataPath'\Employees_`ii'.dta"
		rename VAL_`ii' Employees_`ii'
}
save "`dataPath'\Employees_ALL.dta", replace
* ---------------------------------------------------------------------------------------------------------------------------;
* merge & per capita obs
* ---------------------------------------------------------------------------------------------------------------------------;

merge 1:1 PERIOD_NAME using "$dataPath\Wages_ALL.dta"
drop _merge
* drop countries we don't use
drop Wages_EE Employees_EE Wages_IE Employees_IE

local allCountries "AT NL FR GR IT CY ES LU MT PT SI SK FI BE DE"
foreach cntry of local allCountries {
	generate WagesPC_`cntry'= Wages_`cntry'/Employees_`cntry'
	drop Wages_`cntry' Employees_`cntry'
}
* drop periods we don't need
gen period = _n
keep if period >80
drop period

save "`dataPath'\WagesPC_ALL.dta", replace
clear
* ---------------------------------------------------------------------------------------------------------------------------;


