
* 28/01/2014;
set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
*************************************************************************************;

* Minimum number of obervations needed in order to calculate a statistic;
local cutoff = 25;

*************************************************************************************;
capture log close;
cd "`stataPath'";
log using "`logPath'\tDebtBurden.log", replace;

local updateYear "$updateYear";
local RealIndex  "$RealIndex";
local unempSimulIncomeIndex  "$unempSimulIncomeIndex";

if "$unempSimulIncomeIndex"=="1" {;
	use "`dataPath'\D_compl_`updateYear'_unempSimul_`RealIndex'_extended.dta";
};
else {;
	use "`dataPath'\D_compl_`updateYear'_`RealIndex'_extended.dta";
};

******* Calculate stats;
*************************************************************************************;
*Medians;

local allDistrVars "pop dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100";
local allVars "dodaratio dodiratio dodstotalp dodsmortg doltvratio dnnlaratio";

foreach var of local allVars {;
foreach distrVar of local allDistrVars{;

	statsby `var'_median=r(p50), by(`distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta", replace): summarize `var' [aweight = hw0010], det;
	statsby `var'_median_nobs=r(N), by(`distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'_nobs.dta", replace): summarize `var' [aweight = hw0010], det;
	
};
};

******* Average across implicates;
*************************************************************************************;

local allVars "dodaratio dodiratio dodstotalp dodsmortg doltvratio dnnlaratio";

foreach var of local allVars {;
foreach distrVar of local allDistrVars {;
	
	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta";
	by `distrVar', sort: egen `var'_median_mean=mean(`var'_median);
	keep if im0100==1;
	drop im0100 `var'_median;
	rename `var'_median_mean `var'_median;
	order `var'_median;
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta", replace;

	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'_nobs.dta";
	by `distrVar', sort: egen `var'_median_mean_nobs=mean(`var'_median_nobs);
	keep if im0100==1;
	drop im0100 `var'_median_nob;
	rename `var'_median_mean_nobs `var'_median_nobs;
	order `var'_median_nobs;
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_nobs.dta", replace;

};
};



******* Format data files into CSV tables;
*************************************************************************************;

* Note that we do not include 'pop' in the distribution variables because of the structure of the program (see below); 
local allDistrVars "dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100";
local allVars "dodaratio dodiratio dodstotalp dodsmortg doltvratio dnnlaratio";

**** Put together all lines/all classification variables;
foreach var of local allVars {;
	
	drop _all;
	cd "`basePath'\stats\averagedImplicates";
	use "`basePath'\stats\averagedImplicates\ds_`var'_pop.dta";
	foreach distrVar of local allDistrVars {;	
		append using "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta";
	};
	gen lineVar=_n;
	save "`basePath'\stats\averagedImplicates\ds_`var'.dta", replace;
	
	drop _all;
	cd "`basePath'\stats\averagedImplicates";
	use "`basePath'\stats\averagedImplicates\ds_`var'_pop_nobs.dta";
	foreach distrVar of local allDistrVars {;	
		append using "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_nobs.dta";
	};
	gen lineVar=_n;
	save "`basePath'\stats\averagedImplicates\ds_`var'_nobs.dta", replace;

};

cd "`stataPath'";



***********Creating tables;
*************************************************************************;

local allDistrVars "pop dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100";

local tableName "tDebtBurden";


use "`basePath'\stats\averagedImplicates\ds_dodaratio.dta";

local t_vars "dodiratio dodstotalp dodsmortg doltvratio dnnlaratio";

foreach var of local t_vars {;
	merge 1:1 lineVar using "`basePath'\stats\averagedImplicates\ds_`var'.dta";
	drop _merge;
};

save "`basePath'\stats\fullTables\_`tableName'_allC.dta", replace;



local t_vars "dodiratio dodaratio dodstotalp dodsmortg doltvratio dnnlaratio";
foreach var of local t_vars {;
	merge 1:1 lineVar using "`basePath'\stats\averagedImplicates\ds_`var'_nobs.dta";
	drop _merge;
};


drop `allDistrVars'; 
drop lineVar; 
*order classVar;
save "`basePath'\stats\fullTables\_`tableName'_allC_clean.dta", replace;

foreach var of local t_vars {;
replace `var'_median = 100*`var'_median;
};

foreach var of local t_vars {;
replace `var'_median = .b if `var'_median_nobs < `cutoff' & `var'_median_nobs > 0;
};

local N = _N;
set obs 94;
drop if dodiratio_median ==. ;
****************************************************************************;

mkmat dodaratio_median dodiratio_median dodstotalp_median dodsmortg_median doltvratio_median dnnlaratio_median, mat(X);

xml_tab X, format((S21b0 S21b0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1)) 
rblanks(r1 "Household size" S21b0, r6 "Housing status" S21b0 , r9 "Percentile of Income" S21b0, r14 "Percentile of Net Wealth" S21b0, r19 "Age of Reference Person" S21b0, r25 "Work Status of Reference Person" S21b0, r29 "Education of Reference Person" S21b0, r32 "Country" S21b0) 
rnames("All Households" 1 2 3 4 "5 and More" "Owner-Outright" "Owner-with Mortgage" "Renter or Other" "Less than 20" 20-39 40-59 60-79 80-100 "Less than 20" 20-39 40-59 60-79 80-100 16-34 35-44 45-54 55-64 65-74 75+ Employee Self-Employed Retired "Other Not Working" "Primary or No Education" Secondary Tertiary "Belgium" "Germany" "Greece" "Spain" "France" "Italy" "Cyprus" "Luxembourg" "Malta" "Netherlands" "Austria" "Portugal " "Slovenia" "Slovakia" "Finland")
cnames("Debt-Asset Ratio" "Debt-Income Ratio" "Debt Service-Income Ratio" "Mortgage Debt Service-Income Ratio" "Loan-Value Ratio of HMR" "Net Liquid Assets-Income Ratio")
cwidth(0 150, 1 80, 2 80, 3 80, 4 80, 5 80, 6 80)
mv(.="M" \ .b="N" \ .c="")
font("Times New Roman" 10)
title(Debt Burden (all % values)) 
save("`basePath'\stats\fullTables\_`tableName'_`updateYear'_r`RealIndex'_u`unempSimulIncomeIndex'") replace;

log close;
