
* 28/01/2014;

set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
*************************************************************************************;
* Minimum number of obervations needed in order to calculate a statistic;
local cutoff = 25;

*************************************************************************************;
capture log close;
cd "`stataPath'";
log using "`logPath'\table_income.log", replace;

local updateYear "$updateYear";
local RealIndex  "$RealIndex";
local unempSimulIncomeIndex  "$unempSimulIncomeIndex";

if "$unempSimulIncomeIndex"=="1" {;
	use "`dataPath'\D_compl_`updateYear'_unempSimul_`RealIndex'_extended.dta";
};
else {;
	use "`dataPath'\D_compl_`updateYear'_`RealIndex'_extended.dta";
};

******* Calculate stats;
*************************************************************************************;
******* Continuous variables, BOTH means AND medians;
local allVars "di2000";
local allDistrVars "pop dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100";

foreach var of local allVars {;
foreach distrVar of local allDistrVars{;

	statsby `var'_mean=r(mean) `var'_median=r(p50) `var'_sum=r(sum), by(`distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta", replace): summarize `var' [aweight = hw0010], det;
	statsby `var'_mean_nobs=r(N) `var'_median_nobs=r(N) `var'_sum_nobs=r(N), by(`distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'_nobs.dta", replace): summarize `var' [aweight = hw0010], det;
	
};
};


******* Average across implicates;
*************************************************************************************;


foreach var of local allVars {;
foreach distrVar of local allDistrVars {;
	
	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta";
	by `distrVar', sort: egen `var'_mean_mean=mean(`var'_mean);
	by `distrVar', sort: egen `var'_median_mean=mean(`var'_median);
	by `distrVar', sort: egen `var'_sum_mean=mean(`var'_sum);
	keep if im0100==1;
	drop im0100 `var'_mean `var'_median `var'_sum;
	rename `var'_mean_mean `var'_mean;
	rename `var'_median_mean `var'_median;
	rename `var'_sum_mean `var'_sum;
	order `var'_median `var'_mean;	*** Make sure the median comes before the mean (as in the tables);
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta", replace;

	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'_nobs.dta";
	by `distrVar', sort: egen `var'_mean_mean_nobs=mean(`var'_mean_nobs);
	by `distrVar', sort: egen `var'_median_mean_nobs=mean(`var'_median_nobs);
	by `distrVar', sort: egen `var'_sum_mean_nobs=mean(`var'_sum_nobs);
	keep if im0100==1;
	drop im0100 `var'_mean_nobs `var'_median_nobs `var'_sum_nobs;
	rename `var'_mean_mean_nobs `var'_mean_nobs;
	rename `var'_median_mean_nobs `var'_median_nobs;
	rename `var'_sum_mean_nobs `var'_sum_nobs;
	order `var'_median_nobs `var'_mean_nobs;	*** Make sure the median comes before the mean (as in the tables);
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_nobs.dta", replace;

};
};

******* Format data files into CSV tables;
*************************************************************************************;

* Note that we do not include 'pop' in the distribution variables because of the structure of the program (see below); 
local allDistrVars "dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100";

**** Put together all lines/all classification variables;
foreach var of local allVars {;
	
	drop _all;
	cd "`basePath'\stats\averagedImplicates";
	use "`basePath'\stats\averagedImplicates\ds_`var'_pop.dta";
	foreach distrVar of local allDistrVars {;	
		append using "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta";
	};
	gen lineVar=_n;
	save "`basePath'\stats\averagedImplicates\ds_`var'.dta", replace;
	
	drop _all;
	cd "`basePath'\stats\averagedImplicates";
	use "`basePath'\stats\averagedImplicates\ds_`var'_pop_nobs.dta";
	foreach distrVar of local allDistrVars {;	
		append using "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_nobs.dta";
	};
	gen lineVar=_n;
	save "`basePath'\stats\averagedImplicates\ds_`var'_nobs.dta", replace;

};

cd "`stataPath'";



***********Creating tables;
*************************************************************************;

local allDistrVars "pop dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100";

local tableName "tIncome";


use "`basePath'\stats\averagedImplicates\ds_di2000.dta";


save "`basePath'\stats\fullTables\_`tableName'_allC.dta", replace;


drop `allDistrVars'; 
*drop lineVar; 

local totI=di2000_sum[1];
replace di2000_sum = 100*di2000_sum/`totI';

save "`basePath'\stats\fullTables\_`tableName'_allC_clean.dta", replace;

merge 1:1 lineVar using "`basePath'\stats\averagedImplicates\ds_di2000_nobs.dta";
drop _merge;

replace di2000_median = .b if di2000_median_nobs < `cutoff' & di2000_median_nobs > 0;
replace di2000_mean = .b if di2000_mean_nobs < `cutoff' & di2000_mean_nobs > 0;
replace di2000_sum = .b if di2000_sum_nobs < `cutoff' & di2000_sum_nobs > 0;

gen di2000_median_000 = di2000_median/1000;
gen di2000_mean_000 = di2000_mean/1000;


local N = _N;
set obs 94;
drop if di2000_median_000 ==. ;
****************************************************************************;

mkmat di2000_median_000 di2000_mean_000 di2000_sum, mat(X);

xml_tab X, format((S21b0 S21b0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1)) 
rblanks(r1 "Household size" S21b0, r6 "Housing status" S21b0 , r9 "Percentile of Income" S21b0, r14 "Percentile of Net Wealth" S21b0, r19 "Age of Reference Person" S21b0, r25 "Work Status of Reference Person" S21b0, r29 "Education of Reference Person" S21b0, r32 "Country" S21b0) 
rnames("All Households" 1 2 3 4 "5 and More" "Owner-Outright" "Owner-with Mortgage" "Renter or Other" "Less than 20" 20-39 40-59 60-79 80-100 "Less than 20" 20-39 40-59 60-79 80-100 16-34 35-44 45-54 55-64 65-74 75+ Employee Self-Employed Retired "Other Not Working" "Primary or No Education" Secondary Tertiary "Belgium" "Germany" "Greece" "Spain" "France" "Italy" "Cyprus" "Luxembourg" "Malta" "Netherlands" "Austria" "Portugal " "Slovenia" "Slovakia" "Finland")
cnames("Median (1,000)" "Mean (1,000)" "Share of Total Income (%)")
cwidth(0 150, 1 80, 2 80, 3 80)
mv(.="M" \ .b="N" \ .c="")
font("Times New Roman" 10)
title(Total Household Gross Income [DI2000] (euros)) 
save("`basePath'\stats\fullTables\_`tableName'_`updateYear'_r`RealIndex'_u`unempSimulIncomeIndex'") replace;

log close;
