* 28/01/2014;
* estension of the real NetWealth table with real assets (da1000), financial assets (da2100) and total debt(dl1000);
* standard errors dropped;

set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
*************************************************************************************;

* Minimum number of obervations needed in order to calculate a statistic;
local cutoff = 25;
capture log close;
cd "`stataPath'";
log using "`logPath'\table_netwealth.log", replace;
local updateYear "$updateYear";
local RealIndex  "$RealIndex";
local unempSimulIncomeIndex  "$unempSimulIncomeIndex";


if "$unempSimulIncomeIndex"=="1" {;
	use "`dataPath'\D_compl_`updateYear'_unempSimul_`RealIndex'_extended.dta";
};
else {;
	use "`dataPath'\D_compl_`updateYear'_`RealIndex'_extended.dta";
};
	

* We want to calculate means for all hh's not only for those who participate;
replace dl1000 = 0 if dl1000 == .;
replace da1000 = 0 if da1000 == .;    
replace da2100 = 0 if da2100 == .;

******* Calculate stats;
*************************************************************************************;
******* Continuous variables, BOTH means AND medians;
local allVars "dn3001 da1000 da2100 dl1000";  
local allDistrVars "pop dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100"; * whole sample, hh size, housing status, percentile ea income, perc. ea net wealth, age, work status, education, country;

foreach var of local allVars {;
foreach distrVar of local allDistrVars{;

	statsby `var'_mean=r(mean) `var'_median=r(p50) `var'_sum=r(sum), by(`distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta", replace): summarize `var' [aweight = hw0010], det;
	statsby `var'_mean_nobs=r(N) `var'_median_nobs=r(N) `var'_sum_nobs=r(N), by(`distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'_nobs.dta", replace): summarize `var' [aweight = hw0010], det;
	statsby `var'_share_nobs=r(sum_w), by(`distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'_share_nobs.dta", replace): summarize `var' [aweight = hw0010], det;
	
};
};



******* Average across implicates;
*************************************************************************************;

*** Means and medians;

foreach var of local allVars {;
foreach distrVar of local allDistrVars {;
	
	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta";
	by `distrVar', sort: egen `var'_mean_mean=mean(`var'_mean);
	by `distrVar', sort: egen `var'_median_mean=mean(`var'_median);
	by `distrVar', sort: egen `var'_sum_mean=mean(`var'_sum);
	keep if im0100==1;
	drop im0100 `var'_mean `var'_median `var'_sum;
	rename `var'_mean_mean `var'_mean;
	rename `var'_median_mean `var'_median;
	rename `var'_sum_mean `var'_sum;
	order `var'_median `var'_mean `var'_sum;	*** Make sure the median comes before the mean (as in the tables);
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta", replace;

	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'_nobs.dta";
	by `distrVar', sort: egen `var'_mean_mean_nobs=mean(`var'_mean_nobs);
	by `distrVar', sort: egen `var'_median_mean_nobs=mean(`var'_median_nobs);
	by `distrVar', sort: egen `var'_sum_mean_nobs=mean(`var'_sum_nobs);
	keep if im0100==1;
	drop im0100 `var'_mean_nobs `var'_median_nobs `var'_sum_nobs;
	rename `var'_mean_mean_nobs `var'_mean_nobs;
	rename `var'_median_mean_nobs `var'_median_nobs;
	rename `var'_sum_mean_nobs `var'_sum_nobs;
	order `var'_median_nobs `var'_mean_nobs;	*** Make sure the median comes before the mean (as in the tables);
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_nobs.dta", replace;

	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'_share_nobs.dta";
	by `distrVar', sort: egen `var'_mean_share_nobs=mean(`var'_share_nobs);
	keep if im0100==1;
	drop im0100 `var'_share_nobs;
	rename `var'_mean_share_nobs `var'_share_nobs;
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_share_nobs.dta", replace;
	
};
};



******* Format data files into CSV tables;
*************************************************************************************;

* Note that we do not include 'pop' in the distribution variables because of the structure of the program (see below); 
local allDistrVars "dmdh0001 dmdhhst dhiq01_ea dhnq01_ea dmdhageh dmdhemph1 dmdheduh_j sa0100";
local allVars "dn3001 da1000 da2100 dl1000";  


**** Put together all lines/all classification variables;
foreach var of local allVars {;
	
	drop _all;
	cd "`basePath'\stats\averagedImplicates";
	use "`basePath'\stats\averagedImplicates\ds_`var'_pop.dta";
	foreach distrVar of local allDistrVars {;	
		append using "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta";
	};
	gen lineVar=_n;
	save "`basePath'\stats\averagedImplicates\ds_`var'.dta", replace;
	
	drop _all;
	cd "`basePath'\stats\averagedImplicates";
	use "`basePath'\stats\averagedImplicates\ds_`var'_pop_nobs.dta";
	foreach distrVar of local allDistrVars {;	
		append using "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_nobs.dta";
	};
	gen lineVar=_n;
	save "`basePath'\stats\averagedImplicates\ds_`var'_nobs.dta", replace;
	
	drop _all;
	cd "`basePath'\stats\averagedImplicates";
	use "`basePath'\stats\averagedImplicates\ds_`var'_pop_share_nobs.dta";
	foreach distrVar of local allDistrVars {;	
		append using "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'_share_nobs.dta";
	};
	gen lineVar=_n;
	save "`basePath'\stats\averagedImplicates\ds_`var'_share_nobs.dta", replace;


};

cd "`stataPath'";

***********Creating tables;
*************************************************************************;

local tableName "tNetWealthExtended";

use "`basePath'\stats\averagedImplicates\ds_dn3001.dta";

local t_vars "da1000 da2100 dl1000"; 

foreach var of local t_vars {;
	merge 1:1 lineVar using "`basePath'\stats\averagedImplicates\ds_`var'.dta";
	drop _merge;
};

local t_vars "dn3001 da1000 da2100 dl1000";
foreach var of local t_vars {;
	merge 1:1 lineVar using "`basePath'\stats\averagedImplicates\ds_`var'_nobs.dta";
	drop _merge;
};

save "`basePath'\stats\fullTables\_`tableName'_allC.dta", replace;

drop `allDistrVars'; 
drop lineVar; 
*order classVar;
local totNW=dn3001_sum[1];
replace dn3001_sum = 100*dn3001_sum/`totNW';



merge using "`basePath'\stats\averagedImplicates\ds_dn3001_share_nobs.dta";
drop _merge;

local totOBS=dn3001_share_nobs[1];
replace dn3001_share_nobs = 100*dn3001_share_nobs/`totOBS';

replace dn3001_median = .b if dn3001_median_nobs < `cutoff' & dn3001_median_nobs > 0;
replace dn3001_mean = .b if dn3001_mean_nobs < `cutoff' & dn3001_mean_nobs > 0;

replace da1000_mean = .b if da1000_mean_nobs < `cutoff' & da1000_mean_nobs > 0;
replace da1000_median = .b if da1000_median_nobs < `cutoff' & da1000_median_nobs > 0;

replace da2100_mean = .b if da2100_mean_nobs < `cutoff' & da2100_mean_nobs > 0;
replace da2100_median = .b if da2100_median_nobs < `cutoff' & da2100_median_nobs > 0;

replace dl1000_mean = .b if dl1000_mean_nobs < `cutoff' & dl1000_mean_nobs > 0;
replace dl1000_median = .b if dl1000_median_nobs < `cutoff' & dl1000_median_nobs > 0;


save "`basePath'\stats\fullTables\_`tableName'_allC_clean.dta", replace;

gen dn3001_median_000 = dn3001_median/1000;
gen dn3001_mean_000 = dn3001_mean/1000;

gen da1000_mean_000 = da1000_mean/1000;
gen da1000_median_000 = da1000_median/1000;

gen da2100_mean_000 = da2100_mean/1000;
gen da2100_median_000 = da2100_median/1000;

gen dl1000_mean_000 = dl1000_mean/1000;
gen dl1000_median_000 = dl1000_median/1000;

local N = _N;
set obs 94;     
drop if dn3001_median_000 ==. ;
****************************************************************************;

mkmat dn3001_median_000 dn3001_mean_000 da1000_median_000 da1000_mean_000 da2100_median_000 da2100_mean_000 dl1000_median_000 dl1000_mean_000, mat(X);

xml_tab X, format((S21b0 S21b0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0 S21r0) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1) (S22b0 N23r1)) 
rblanks(r1 "Household size" S21b0, r6 "Housing status" S21b0 , r9 "Percentile of Income" S21b0, r14 "Percentile of Net Wealth" S21b0, r19 "Age of Reference Person" S21b0, r25 "Work Status of Reference Person" S21b0, r29 "Education of Reference Person" S21b0, r32 "Country" S21b0) 

rnames("All Households" 1 2 3 4 "5 and More" "Owner-Outright" "Owner-with Mortgage" "Renter or Other" "Less than 20" 20-39 40-59 60-79 80-100 "Less than 20" 20-39 40-59 60-79 80-100 16-34 35-44 45-54 55-64 65-74 75+ Employee Self-Employed Retired "Other Not Working" "Primary or No Education" Secondary Tertiary "Belgium" "Germany" "Greece" "Spain" "France" "Italy" "Cyprus" "Luxembourg" "Malta" "Netherlands" "Austria" "Portugal" "Slovenia" "Slovakia" "Finland")

cnames("Median Net Wealth" "Mean Net Wealth" "Median Real Assets" "Mean Real Assets"  "Median Financial Assets" "Mean Financial Assets" "Median Liabilities" "Mean Liabilities")
cwidth(0 150, 1 80, 2 80, 3 80, 4 80, 5 80, 6 80, 7 80, 8 80)
mv(.="M" \ .b="N" \ .c="")
font("Times New Roman" 10)
title(Household Net Wealth - extended) 
save("`basePath'\stats\fullTables\_`tableName'_`updateYear'_r`RealIndex'_u`unempSimulIncomeIndex'") replace;

