****************************************;
*06/02/2014;
****************************************;
cd "D:\akmaral\HFCS\HFCSupdate\MASTER\programs"

set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
****************************************;
global calculate2013index "1";  * calculate wealth breakdowns based on updated dataset [default: No/0];

if "$calculate2013index"=="1" {;
	use "`dataPath'\D_compl_2013_0.dta", replace;
	global byWealthFileToSave "NetWealthQuintilePerCountryByWealth_2013";
	global byIncomeFileToSave "NetWealthQuintilePerCountryByIncome_2013";
};
else {;
	use "`dataPath'\D_compl_2008_1.dta", replace;
	global byWealthFileToSave "NetWealthQuintilePerCountryByWealth_2008";
	global byIncomeFileToSave "NetWealthQuintilePerCountryByIncome_2008";
};

*************************************************************************************;
gen pop=1;	* whole sample;
mvdecode _all, mv(-1=.a);	* -1 are missing values;
mvdecode _all, mv(-2=.b);	* -2 are missing values;

**Generate income and net wealth quintiles;
gen dhiq01_cntry = .;
gen dhnq01_cntry = .;


*Define a new label so the countries are ordered according to the official ECB order;
label define country 1 "BE" 2 "DE" 3 "GR" 4 "ES" 5 "FR" 6 "IT" 7 "CY" 8 "LU" 9 "MT" 10 "NL" 11 "AT" 12 "PT" 13 "SI" 14 "SK" 15 "FI";
generate aux = 1 if sa0100 == "BE";
replace aux = 2 if sa0100 == "DE";
replace aux = 3 if sa0100 == "GR";
replace aux = 4 if sa0100 == "ES";
replace aux = 5 if sa0100 == "FR";
replace aux = 6 if sa0100 == "IT";
replace aux = 7 if sa0100 == "CY";
replace aux = 8 if sa0100 == "LU";
replace aux = 9 if sa0100 == "MT";
replace aux = 10 if sa0100 == "NL";
replace aux = 11 if sa0100 == "AT";
replace aux = 12 if sa0100 == "PT";
replace aux = 13 if sa0100 == "SI";
replace aux = 14 if sa0100 == "SK";
replace aux = 15 if sa0100 == "FI";
label values aux country;
rename aux cntryid;

* j is a country number;
forvalues j = 1(1)15 {;
forvalues i = 1(1)5 {;           
	*Income;
	_pctile di2000 [aweight=hw0010] if im0100 == `i' & cntryid ==`j',n(5);
	replace dhiq01_cntry = 1 if im0100 == `i' & cntryid ==`j' & di2000 <= r(r1);
	replace dhiq01_cntry = 2 if im0100 == `i' & cntryid ==`j'& di2000 > r(r1) & di2000 <= r(r2);
	replace dhiq01_cntry = 3 if im0100 == `i' & cntryid ==`j'& di2000 > r(r2) & di2000 <= r(r3);
	replace dhiq01_cntry = 4 if im0100 == `i' & cntryid ==`j'& di2000 > r(r3) & di2000 <= r(r4);
	replace dhiq01_cntry = 5 if im0100 == `i' & cntryid ==`j'& di2000 > r(r4);

	*Net wealth;
	_pctile dn3001 [aweight=hw0010] if im0100 == `i'& cntryid ==`j',n(5);
	replace dhnq01_cntry = 1 if im0100 == `i' & cntryid ==`j'& dn3001 <= r(r1);
	replace dhnq01_cntry = 2 if im0100 == `i' & cntryid ==`j'& dn3001 > r(r1) & dn3001 <= r(r2);
	replace dhnq01_cntry = 3 if im0100 == `i' & cntryid ==`j'& dn3001 > r(r2) & dn3001 <= r(r3);
	replace dhnq01_cntry = 4 if im0100 == `i' & cntryid ==`j'& dn3001 > r(r3) & dn3001 <= r(r4);
	replace dhnq01_cntry = 5 if im0100 == `i' & cntryid ==`j'& dn3001 > r(r4);
};
};

******* Calculate stats;
local allVars "dn3001";
local allDistrVars "dhiq01_cntry dhnq01_cntry";

foreach var of local allVars {;
foreach distrVar of local allDistrVars{;
  
	statsby `var'_mean=r(mean) `var'_median=r(p50), by(cntryid `distrVar' im0100) saving("`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta", replace): summarize `var' [aweight = hw0010], det;
	
};
};

******* Average across implicates;
*************************************************************************************;

*** Means and medians;

foreach var of local allVars {;
foreach distrVar of local allDistrVars {;
	
	drop _all;
	use "`basePath'\stats\allImplicates\ds_`var'_`distrVar'.dta";
	by cntryid `distrVar', sort: egen `var'_mean_mean=mean(`var'_mean);
	by cntryid `distrVar', sort: egen `var'_median_mean=mean(`var'_median);
	*by `distrVar', sort: egen `var'_sum_mean=mean(`var'_sum);
	keep if im0100==1;
	drop im0100 `var'_mean `var'_median; *`var'_sum;
	rename `var'_mean_mean `var'_mean;
	rename `var'_median_mean `var'_median;
	*rename `var'_sum_mean `var'_sum;
	order `var'_median `var'_mean; *`var'_sum;	*** Make sure the median comes before the mean (as in the tables);
	save "`basePath'\stats\averagedImplicates\ds_`var'_`distrVar'.dta", replace;
	
};
};

gen dn3001_median_000 = dn3001_median/1000;
gen dn3001_mean_000 = dn3001_mean/1000;

cd "`stataPath'";

***********Creating tables;
*************************************************************************;

mkmat dn3001_median_000 dn3001_mean_000, mat(X);

xml_tab X, 
rnames("Belgium 1" 2 3 4 5 "Germany 1" 2 3 4 5 "Greece 1" 2 3 4 5 "Spain 1" 2 3 4 5 "France 1" 2 3 4 5 "Italy 1" 2 3 4 5 "Cyprus 1" 2 3 4 5 "Luxembourg 1" 2 3 4 5 "Malta 1" 2 3 4 5 "The Netherlands 1" 2 3 4 5 "Austria 1" 2 3 4 5 "Portugal 1" 2 3 4 5 "Slovenia 1" 2 3 4 5 "Slovakia 1" 2 3 4 5 "Finland 1" 2 3 4 5)
cnames("Median (1,000)" "Mean (1,000)")
font("Times New Roman" 10)
title(Household Net Wealth [DN3001] (thousand EUR)) 
save("`basePath'\stats\fullTables\_t$byWealthFileToSave") replace;

drop _all;
use "`basePath'\stats\averagedImplicates\ds_dn3001_dhiq01_cntry.dta";

gen dn3001_median_000 = dn3001_median/1000;
gen dn3001_mean_000 = dn3001_mean/1000;

mkmat dn3001_median_000 dn3001_mean_000, mat(X);

xml_tab X, 
rnames("Belgium 1" 2 3 4 5 "Germany 1" 2 3 4 5 "Greece 1" 2 3 4 5 "Spain 1" 2 3 4 5 "France 1" 2 3 4 5 "Italy 1" 2 3 4 5 "Cyprus 1" 2 3 4 5 "Luxembourg 1" 2 3 4 5 "Malta 1" 2 3 4 5 "The Netherlands 1" 2 3 4 5 "Austria 1" 2 3 4 5 "Portugal 1" 2 3 4 5 "Slovenia 1" 2 3 4 5 "Slovakia 1" 2 3 4 5 "Finland 1" 2 3 4 5)
cnames("Median (1,000)" "Mean (1,000)")
font("Times New Roman" 10)
title(Household Net Wealth [DN3001] (thousand EUR)) 
save("`basePath'\stats\fullTables\_t$byIncomeFileToSave") replace;
