
* -----------------------------------------------------------------
* This file generates the sector specific unemployment probabilities
* i.e. the distribution of the unemployment shock
do SDW_download_Employees_Sect_N.do
use "$SDWdataPath\Employees_Sect_ALL_N.dta", clear
set more off
* -----------------------------------------------------------------


* -----------------------------------------------------------------
* TEST TEST TEST TEST TEST TEST
* Test whether total employees = sum of sectors
* For most countries error rather small, so we use the pre-generated
* total instead of total
gen EMPL_ALL2 = EMPL_A_A + EMPL_B_E +  EMPL_F_F + EMPL_G_I +  EMPL_J_J  + EMPL_K_K + EMPL_L_L + EMPL_M_N + EMPL_O_Q + EMPL_R_U
gen diff = (EMPL_ALL/EMPL_ALL2-1)*100
*su diff
*bysort ctryid: su diff
*replace EMPL_ALL=EMPL_ALL2
drop diff EMPL_ALL2
* -----------------------------------------------------------------


* -----------------------------------------------------------------
* Step 0: Set the starting time of the sample and the current cate
* relevant points in time
gen datayear = datayear_employment
gen base_ind = .
do SetBaseYear.do
gen temp1 = quarterly(date, "YQ")
gen temp2 = quarterly(hfcnyear, "YQ")
gen temp3 = quarterly(datayear, "YQ")
drop date hfcnyear datayear
rename temp1 date
rename temp2 hfcnyear
rename temp3 datayear
format date hfcnyear datayear %tq
compress

* Generate indicator functions for the two potential base years
gen delta_t1 = datayear - 4*floor((datayear - hfcnyear)/4)
gen delta_t2 = delta_t1-4
gen w_delta_t2 = (delta_t1 - hfcnyear)/4
gen w_delta_t1 = 1 - w_delta_t2

* Replace non-necessary values by missings
global gen_varlist= "A_A B_E C_C F_F G_I J_J K_K L_L M_N O_Q R_U ALL"
global ctrylist="AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
	foreach ij of global gen_varlist {
	replace EMPL_`ij'=. if ctryid=="`ii'" & (date!= delta_t1 & date!=delta_t2 & date!=datayear)
	replace base_ind=1 if ctryid=="`ii'" & date==delta_t1
	replace base_ind=2 if ctryid=="`ii'" & date==delta_t2
	replace base_ind=3 if ctryid=="`ii'" & date==datayear
	}
}
replace w_delta_t1 = 0 if base_ind!=1
replace w_delta_t2 = 0 if base_ind!=2
gen w = w_delta_t1 + w_delta_t2
drop w_delta_t1 w_delta_t2
replace w = 1 if base_ind==3

* Compute weighted contributions (confex combination)
foreach ij of global gen_varlist {
	replace EMPL_`ij'=EMPL_`ij'*w 
}
replace base_ind = 2 if base_ind==1

* Drop all non-base/data-year observations
collapse (sum) EMPL_* , by(base_ind ctryid)
drop if base_ind==.
sort ctryid base_ind

* Set timers to use L-operator
encode ctryid, gen(ctryid_num)
tsset ctryid_num base_ind
rename base_ind date
compress
* -----------------------------------------------------------------


* -----------------------------------------------------------------
* Step 1: generate time specific weights for sector/country
* -----------------------------------------------------------------
local nacelist ="A_A B_E C_C F_F G_I J_J K_K L_L M_N O_Q R_U ALL"
foreach ii of local nacelist {
	gen W_`ii'=EMPL_`ii'/EMPL_ALL
}
* -----------------------------------------------------------------


* -----------------------------------------------------------------
* Step 2: Generate growth rates of employment per sector  
* -----------------------------------------------------------------
* : generate time specific weights for sector/country
local nacelist ="A_A B_E C_C F_F G_I J_J K_K L_L M_N O_Q R_U ALL"
foreach ii of local nacelist {
	gen G_`ii'=EMPL_`ii'/L.EMPL_`ii'-1
}
* -----------------------------------------------------------------


* -----------------------------------------------------------------
* Step 3: Transform growth rates to "zero sum" (idiosyncratic)
* -----------------------------------------------------------------
local nacelist ="A_A B_E C_C F_F G_I J_J K_K L_L M_N O_Q R_U ALL"
foreach ii of local nacelist {
	gen Gtransf_`ii' = G_`ii'-G_ALL
}
* Drop unnecessary variables
keep ctryid Gtransf_* 
drop if Gtransf_A_A==.
* Sector C for BE missing: replace with B_E as a higher category
replace Gtransf_C_C = Gtransf_B_E if ctryid=="BE"
* -----------------------------------------------------------------


* -----------------------------------------------------------------
* Reshape and Save data
reshape long Gtransf_  , i(ctryid) j(sect, string)
drop if sect=="ALL"
rename Gtransf ushock   
compress

* Rename ctryid for Miguel
rename ctryid sa0100

save Ushock_sect.dta, replace
*bysort ctryid: list
clear
* -----------------------------------------------------------------

