* --------------------------------------------------
* This file uses SDW codes to download male unemployment by age
* --------------------------------------------------

* Clear Memory
capture log close
clear
set more off

* Set source
odbc query "sdw", user(pub) password(pub)


* --------------------------------------------------
* Import Country by Country Property Prices
* Step 1: download series
* Step 2: rename OBS_VAL to country specific value
* Step 3: sort by date (to merge) and save
* --------------------------------------------------


global ctrylist = "AT NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE"
foreach ii of global ctrylist {
clear
		
*	odbc load, /*
*	*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'STS.M.`ii'.$padju.UNEH.RTF000.4.000',obs_value,null)) UT ,max(decode(series_key, 'STS.M.`ii'.$padju.UNEH.RTM000.4.000',obs_value,null)) UM ,max(decode(series_key, 'STS.M.`ii'.$padju.UNEH.RTT000.4.000',obs_value,null)) UF FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_STS_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('STS.M.`ii'.$padju.UNEH.RTF000.4.000','STS.M.`ii'.$padju.UNEH.RTM000.4.000','STS.M.`ii'.$padju.UNEH.RTT000.4.000') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub) 
odbc load, /*
*/ exec("SELECT max(period_name) period_name ,max(decode(series_key, 'STS.M.`ii'.S.UNEH.RTF000.4.000',obs_value,null)) UF ,max(decode(series_key, 'STS.M.`ii'.S.UNEH.RTM000.4.000',obs_value,null)) UM ,max(decode(series_key, 'STS.M.`ii'.S.UNEH.RTT000.4.000',obs_value,null)) UT FROM ( SELECT FIRST_DATE OBS_DATE,period_name, a.SERIES_KEY, a.OBS_VALUE FROM ESDB_PUB.V_STS_OBS_PLAIN a,common.period_dim b    WHERE  a.period_id=b.period_id  AND SERIES_KEY IN ('STS.M.`ii'.S.UNEH.RTF000.4.000','STS.M.`ii'.S.UNEH.RTM000.4.000','STS.M.`ii'.S.UNEH.RTT000.4.000') ) group by obs_date order by obs_date ") dsn("sdw") user(pub) password(pub)

	gen ctryid = "`ii'"
	sort PERIOD_NAME
	compress

	save UnemplT_`ii'.dta, replace		
	display "`ii'   downloaded"

}
* --------------------------------------------------



* --------------------------------------------------
* Rename variables, reshape into "Long" and save
use UnemplT_AT.dta, clear
rm UnemplT_AT.dta
global ctrylist = "NL FR IE GR IT CY ES LU MT PT SI SK FI BE EE DE" /* use country AT as a starting data set*/
foreach ii of global ctrylist {
	append using UnemplT_`ii'.dta
	rm UnemplT_`ii'.dta
}


* --------------------------------------------------
* Pick only quarter-end values
gen date_test = monthly(PERIOD_NAME, "YM")
format date_test %tm

gen temp_y= yofd(dofm(date_test))
format temp_y %ty
gen temp_q= qofd(dofm(date_test))
format temp_q %tq

sort ctryid temp_q date_test
by ctryid temp_q: gen t=_n
keep if t==3

sort ctryid temp_y temp_q
*list temp_y temp_q
drop t
by ctryid temp_y: gen t=_n
gen qind="Q1" if t==1
replace qind="Q2" if t==2
replace qind="Q3" if t==3
replace qind="Q4" if t==4

gen y_str = string(temp_y)

replace PERIOD_NAME = y_str + qind
rename PERIOD_NAME date
* --------------------------------------------------


* --------------------------------------------------
* Rename/Label variables 
label variable UF "Unemployment rate F, TOTAL"
label variable UM "Unemployment rate M, TOTAL"
label variable UT "Unemployment rate T, TOTAL"
* --------------------------------------------------
 

* --------------------------------------------------
* Select only relevant time series and save
keep date U* ctryid
compress
sort ctryid date
save "$SDWdataPath\UnemplT_ALL.dta", replace
clear
* --------------------------------------------------

