

# delimit ;

* This do file generates a data base that will be used for the unemployment simulation.;
* It makes use of the following data files:;
* D_compl.dta : the D file;
* P1.dta - P5.dta: the files containing the individual level data from the HFCS (the 5 implicates);
* Ushock_sect.dta: a file containing the sector specific unemployment shocks;
* OECD_ReplRate_ALL.dta: a file containing the income replacement rates taken from the OECD;
* UnemplT_Target.dta: a file containing the target unemployment rates that we want to match after the simulation;


*cd "U:\Slacalek\research\HFCS\HFCSupdate\programs\unemploymentSimulation";

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
global dataPath "`dataPath'";
adopath + "`stataPath'";
cd "`basePath'\programs\unemploymentSimulation";

*********************************************************;
use "`basePath'\programs\unemploymentSimulation\OECD_ReplRate_ALL.dta", clear;
drop if date == 2011;
*rename ctryid sa0100;
save "`basePath'\programs\unemploymentSimulation\OECD_ReplRate_ALL.dta", replace;
*********************************************************;

* Merge the 5 implicates of the P files;
use "`dataPath'\P1.dta", clear;
append using "`dataPath'\P2.dta";
append using "`dataPath'\P3.dta";
append using "`dataPath'\P4.dta";
append using "`dataPath'\P5.dta";
keep if ra0100 == 1;

keep hid sa0100 pe0400 pa0100 pg0110 pg0210 pg0510 im0100;
rename hid id;
sort id;

save "`dataPath'\data_unemp_simulation.dta", replace;

* Merge with D_compl file;
use "`dataPath'\D_compl.dta", clear;
sort id;

merge id using "`dataPath'\data_unemp_simulation.dta";

keep id sa0100 im0100 hw0010 dhemph dheduh dhgenderh dhageh1b pe0400 pa0100 pg0110 pg0210 pg0510 dhchildrendependent dh0004 di2000;

save "`dataPath'\data_unemp_simulation.dta", replace;


* Generate a variable containing the sector of work according to the level of dissagregation of the macro data;
gen sect = "";
replace sect = "A_A" if pe0400 == "A";
replace sect = "B_E" if pe0400 == "B" | pe0400 == "D" | pe0400 == "DE" | pe0400 == "E" | pe0400 == "B-E";
replace sect = "C_C" if pe0400 == "C";
replace sect = "F_F" if pe0400 == "F";
replace sect = "G_I" if pe0400 == "G" | pe0400 == "H" | pe0400 == "I" | pe0400 == "HJ";
replace sect = "J_J" if pe0400 == "J";
replace sect = "K_K" if pe0400 == "K";
replace sect = "L_L" if pe0400 == "L";
replace sect = "M_N" if pe0400 == "M" | pe0400 == "N" | pe0400 == "I" | pe0400 == "L-N";
replace sect = "O_Q" if pe0400 == "O" | pe0400 == "P" | pe0400 == "Q";
replace sect = "R_U" if pe0400 == "R" | pe0400 == "S" | pe0400 == "T" | pe0400 == "U" | pe0400 == "R-U";


* Merge with the file containing the sector specific unemployment shocks;
merge m:1 sa0100 sect using Ushock_sect.dta;

tab _merge;

* Drop cases for which there is info on the macro data but there is no single hh employed in that sector in the micro data;

drop if _merge == 2;
drop _merge;

* Generate variable indicating employed/unemployed;
gen job = 1 if dhemph == 1 | dhemph == 2;
replace job = 0 if dhemph == 3;


* Generate variable single/ no single;
gen single = 1 if pa0100 == 1 | pa0100 == 4 | pa0100 == 5;
replace single = 0 if pa0100 == 2 | pa0100 == 3;
* There are seven households in CY for which we have no marital status, for the sake of completeness I set them to single.;
replace single = 1 if single == .;


* Generate variable children/no children;
gen children = 1 if dhchildrendependent > 0 & dhchildrendependent != .;
replace children = 0 if dhchildrendependent == 0;

* Generate variable classifying hhs according to their income respect to average income;
* NOTE THAT THIS IS NOT RIGHT. I AM USING HOUSEHOLD INCOME TO DO THIS CLASSIFICATION, BUT IT SHOULD BE DONE AT THE INDIVIDUAL LEVEL;
* THE MOST APPROPIATE THING WILL BE TO GET THE NUMBERS FROM MACRO DATA SINCE WE DONT HAVE WEIGHTS FOR THE INDIVIDUALS HERE ;

sum di2000 [aweight=hw0010];
scalar inc67 = r(mean)*0.67;
scalar inc100 = r(mean);
scalar inc150 = r(mean)*1.5;

gen inc = .;
replace inc = 67 if di2000 <= inc67;
replace inc = 100 if di2000 > inc67 & di2000 <= inc150;
replace inc = 150 if di2000 > inc150;


* Merge with file containing the income replacement rates taken from the OECD;
* I am only keeping the numbers from 2010 from the original file OECD_ReplRate_ALL.dta;
merge m:1 sa0100 inc single children using OECD_ReplRate_ALL.dta;

drop _merge;


* Generate a variable for the labor income of the household head (adding employee and self-employed income together);
gen wages = pg0110;
replace wages = 0 if wages == .;
gen selfemployedincome = pg0210;
replace selfemployedincome = 0 if selfemployedincome == .;
gen laborincome = wages + selfemployedincome;


* Generate a variable for the unemployment benefits of the household head;
gen unemp_benefits = pg0510;
replace unemp_benefits = 0 if unemp_benefits == .;


* Merge with file containing ratios of unemployment change;
* I am only keeping the values for total unemployment, not for the sex categories;
sort sa0100;
merge sa0100 using UnemplT_Target.dta, keep(ScaleF_UT);

* I get rid of Estonia and Ireland;
drop if _merge == 2;


* Generate the variables that will be used in the probit (mainly dummies for education and age brackets);

* Education;
gen college = 1 if (dheduh == 5|dheduh == 6);
replace college = 0 if college == .;
replace college = . if dheduh == .;
gen highschool = 1 if (dheduh == 3 | dheduh == 4);
replace highschool = 0 if highschool == .;
replace highschool = . if dheduh == .;



*Age brackets;
gen agebracket=16;
replace agebracket=35 if dhageh1b == 8 | dhageh1b == 9;
replace agebracket=45 if dhageh1b == 10 | dhageh1b == 11;
replace agebracket=55 if dhageh1b == 12 | dhageh1b == 13;
replace agebracket=65 if dhageh1b == 14 | dhageh1b == 15;
replace agebracket=75 if dhageh1b == 16 | dhageh1b == 17 | dhageh1b == 18;


gen age1 = 1 if agebracket == 16;
replace age1 = 0 if age1 == .;
gen age2 = 1 if agebracket == 35;
replace age2 = 0 if age2 == .;
gen age3 = 1 if agebracket == 45;
replace age3 = 0 if age3 == .;
gen age4 = 1 if agebracket == 55;
replace age4 = 0 if age4 == .;
gen age5 = 1 if agebracket == 65;
replace age5 = 0 if age5 == .;
gen age6 = 1 if agebracket == 75;
replace age6 = 0 if age6 == .;


drop if sa0100 == "IE";
drop if sa0100 == "EE";


save "`dataPath'\data_unemp_simulation.dta", replace;




