

# delimit ;

* This do file generates a data base that will be used for the unemployment simulation.;
* It makes use of the following data files:;
* D_compl.dta : the D file;
* P1.dta - P5.dta: the files containing the individual level data from the HFCS (the 5 implicates);
* Ushock_sect.dta: a file containing the sector specific unemployment shocks;
* OECD_ReplRate_ALL.dta: a file containing the income replacement rates taken from the OECD;
* UnemplT_Target.dta: a file containing the target unemployment rates that we want to match after the simulation;


*cd "U:\Slacalek\research\HFCS\HFCSupdate\programs\unemploymentSimulation";

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
global dataPath "`dataPath'";
adopath + "`stataPath'";
cd "`basePath'\programs\unemploymentSimulation";

*********************************************************;

if "$unempLTreplRatiosIndex"=="1" {;
	use "`basePath'\programs\unemploymentSimulation\OECD_LT_ReplRate_ALL.dta", clear;
	drop if date == 2011;
	save "`basePath'\programs\unemploymentSimulation\OECD_LT_ReplRate_ALL.dta", replace;
};
else {;
	use "`basePath'\programs\unemploymentSimulation\OECD_ReplRate_ALL.dta", clear;
	drop if date == 2011;
	save "`basePath'\programs\unemploymentSimulation\OECD_ReplRate_ALL.dta", replace;
};


*********************************************************;

* Merge the 5 implicates of the P files;
use "`dataPath'\P1.dta", clear;
append using "`dataPath'\P2.dta";
append using "`dataPath'\P3.dta";
append using "`dataPath'\P4.dta";
append using "`dataPath'\P5.dta";

keep hid sa0010 sa0100 im0100 ra0010 pa0100 pa0200 pe0100a pe0100b pe0100c pe0100d pe0100e pe0100f pe0100g pe0100h pe0100i pe0200 pe0400 pg0110 pg0210 pg0510 ra0100 ra0200 ra0300 ra0300_b;
rename hid id;
sort id;

save "`dataPath'\data_unemp_simulation.dta", replace;

* Merge with D_compl file;
use "`dataPath'\D_compl.dta", clear;
keep id dhchildrendependent hw0010;
sort id;

merge 1:m id using "`dataPath'\data_unemp_simulation.dta";
drop _merge;


* Generate a variable containing the sector of work according to the level of dissagregation of the macro data;
gen sect = "";
replace sect = "A_A" if pe0400 == "A";
replace sect = "B_E" if pe0400 == "B" | pe0400 == "D" | pe0400 == "DE" | pe0400 == "E" | pe0400 == "B-E";
replace sect = "C_C" if pe0400 == "C";
replace sect = "F_F" if pe0400 == "F";
replace sect = "G_I" if pe0400 == "G" | pe0400 == "H" | pe0400 == "I" | pe0400 == "HJ";
replace sect = "J_J" if pe0400 == "J";
replace sect = "K_K" if pe0400 == "K";
replace sect = "L_L" if pe0400 == "L";
replace sect = "M_N" if pe0400 == "M" | pe0400 == "N" | pe0400 == "I" | pe0400 == "L-N";
replace sect = "O_Q" if pe0400 == "O" | pe0400 == "P" | pe0400 == "Q";
replace sect = "R_U" if pe0400 == "R" | pe0400 == "S" | pe0400 == "T" | pe0400 == "U" | pe0400 == "R-U";


* Merge with the file containing the sector specific unemployment shocks;
merge m:1 sa0100 sect using Ushock_sect.dta;

tab _merge;

* Drop cases for which there is info on the macro data but there is no single hh employed in that sector in the micro data;

drop if _merge == 2;
drop _merge;

* Generate variable indicating employed/unemployed;
gen job = 1 if pe0100a == 1 | pe0100a == 2;
replace job = 0 if pe0100a == 3;


* Generate variable single/ no single;
gen single = 1 if pa0100 == 1 | pa0100 == 4 | pa0100 == 5;
replace single = 0 if pa0100 == 2 | pa0100 == 3;
* There are seven households in CY for which we have no marital status, for the sake of completeness I set them to single.;
replace single = 1 if single == .;


* Generate variable children/no children;
gen children = 1 if dhchildrendependent > 0 & dhchildrendependent != . & ra0100 == 1;
replace children = 1 if dhchildrendependent > 0 & dhchildrendependent != . & ra0100 == 2;
replace children = 0 if dhchildrendependent == 0;
replace children = 0 if children == .;


* Generate a variable for labor income (adding employee and self-employed income together);
* Those who have a negative income (coming from self-employment) are set to missing;
gen wages = pg0110;
replace wages = 0 if wages == .;
gen selfemployedincome = pg0210;
replace selfemployedincome = 0 if selfemployedincome == .;
gen laborincome = wages + selfemployedincome;
replace laborincome = . if laborincome <= 0;

* Generate a variable for the unemployment benefits;
gen unemp_benefits = pg0510;
replace unemp_benefits = 0 if unemp_benefits == .;

* Generate variable classifying individuals according to their income respect to average income;
sum laborincome [aweight=hw0010];
scalar inc67 = r(mean)*0.67;
scalar inc100 = r(mean);
scalar inc150 = r(mean)*1.5;

gen inc = .;
replace inc = 67 if laborincome <= inc67;
replace inc = 100 if laborincome > inc67 & laborincome <= inc150;
replace inc = 150 if laborincome > inc150;


* Merge with file containing the income replacement rates taken from the OECD;
* I am only keeping the numbers from 2010 from the original file OECD_ReplRate_ALL.dta;

if "$unempLTreplRatiosIndex"=="1" {;
	merge m:1 sa0100 inc single children using OECD_LT_ReplRate_ALL.dta;
};
else {;
	merge m:1 sa0100 inc single children using OECD_ReplRate_ALL.dta;
};

drop _merge;


* Merge with file containing ratios of unemployment change;
* I am only keeping the values for total unemployment, not for the sex categories;
sort sa0100;
merge sa0100 using UnemplT_Target.dta, keep(ScaleF_UT);

* I get rid of Estonia and Ireland;
drop if _merge == 2;
drop _merge;

* Generate the variables that will be used in the probit (mainly dummies for education, gender and age brackets);

* Education;
gen college = 1 if pa0200 == 5;
replace college = 0 if college == .;
replace college = . if pa0200 == .;
gen highschool = 1 if pa0200 == 3;
replace highschool = 0 if highschool == .;
replace highschool = . if pa0200 == .;

* Gender;
gen gender = 1 if ra0200 == 1;
replace gender = 0 if ra0200 == 2;

*Age brackets;
gen agebracket=16;
replace agebracket=35 if ra0300_b == 8 | ra0300_b == 9;
replace agebracket=45 if ra0300_b == 10 | ra0300_b == 11;
replace agebracket=55 if ra0300_b == 12 | ra0300_b == 13;
replace agebracket=65 if ra0300_b == 14 | ra0300_b == 15;
replace agebracket=75 if ra0300_b == 16 | ra0300_b == 17 | ra0300_b == 18;

gen age1 = 1 if agebracket == 16;
replace age1 = 0 if age1 == .;
gen age2 = 1 if agebracket == 35;
replace age2 = 0 if age2 == .;
gen age3 = 1 if agebracket == 45;
replace age3 = 0 if age3 == .;
gen age4 = 1 if agebracket == 55;
replace age4 = 0 if age4 == .;
gen age5 = 1 if agebracket == 65;
replace age5 = 0 if age5 == .;
gen age6 = 1 if agebracket == 75;
replace age6 = 0 if age6 == .;

* I am going to create a category comprising the last 3 age brackets. This is because when runnng the probits there were brackets that were predicting the outcome of the regression perfectly and thus they were drop off;
gen age456 = 1 if age4 == 1 | age5 == 1 | age6 == 1;
replace age456 = 0 if age456 == .;

drop if sa0100 == "IE";
drop if sa0100 == "EE";

* There is 1 individual without id (neither population weight). I am going to drop it.;
drop if id == "";
sort id ra0010;
save "`dataPath'\data_unemp_simulation_ind.dta", replace;

