

set more off
clear
clear matrix
#delimit;
set mem 3000m;
set matsize 155;
program drop _all;
discard;

do setPath;
local basePath "$basePath";
local stataPath "$stataPath";
local logPath "`stataPath'";
local dataPath "`basePath'\data";
adopath + "`stataPath'";
*************************************************************************************;
set scheme ecbochre;
graph set window fontface "Gill Sans MT";
graph set window fontfacesans "Gill Sans MT";

capture log close;
cd "`stataPath'";
log using "`logPath'\wealthIncomeByAge.log", replace;

use "`dataPath'\D_compl_2013_extended_unempSimul.dta";
*drop if sa0100=="I1";	* drop "old Italy";

******* Generate additional (rougher) classification variables;
*************************************************************************************;
*gen pop=1;	* whole sample;
mvdecode _all, mv(-1=.a);	* -1 are missing values;
mvdecode _all, mv(-2=.b);	* -2 are missing values;

replace dmdhageh=25;
replace dmdhageh=35 if dhageh1b>=8&dhageh1b<10;
replace dmdhageh=45 if dhageh1b>=10&dhageh1b<12;
replace dmdhageh=55 if dhageh1b>=12&dhageh1b<14;
replace dmdhageh=65 if dhageh1b>=14&dhageh1b<16;
replace dmdhageh=75 if dhageh1b>=16;

replace dmdhhtype=dhhtype;
replace dmdhhtype=6 if dhhtype==7;
replace dmdhhtype=10 if dhhtype==11|dhhtype==12;

*** Redefine dmdhhtype so that stats in the table show up in the order I want;
replace dmdhhtype_j=0;
replace dmdhhtype_j=1 if dmdhhtype==9;
replace dmdhhtype_j=2 if dmdhhtype==51;
replace dmdhhtype_j=3 if dmdhhtype==52;
replace dmdhhtype_j=4 if dmdhhtype==10;
replace dmdhhtype_j=5 if dmdhhtype==6;

replace dmdheduh=dheduh1;
replace dmdheduh=0 if dheduh1==1|dheduh1==2;
replace dmdheduh=3 if dheduh1==4;
replace dmdheduh=5 if dheduh1==6;

replace dmdheduh_j=dheduh;
replace dmdheduh_j=1 if dmdheduh==0;
replace dmdheduh_j=2 if dmdheduh==3;
replace dmdheduh_j=3 if dmdheduh==5;

*** Redefine top ditop10 and dntop10 (create indicators of top 10/5/1 percent of income/wealth);
replace ditop10_j=0;
replace ditop10_j=1 if ditop10>=90;
replace ditop5_j=0;
replace ditop5_j=1 if ditop10>=95;
replace ditop1_j=0;
replace ditop1_j=1 if ditop10==99;

replace dntop10_j=0;
replace dntop10_j=1 if dntop10>=90;
replace dntop5_j=0;
replace dntop5_j=1 if dntop10>=95;
replace dntop1_j=0;
replace dntop1_j=1 if dntop10==99;

gen tes = da2100 + da1000 - dl1000;

**** Net Wealth;
*************************************************************************************;
local allClassVarsToPlot "dmdhageh";
local allVariables "dn3001 da2100 da1000 dl1000 tes di2000 di2000eq";
local tableName "tWealth";

gen dn3001_1000=dn3001/1000;
gen da2100_1000=da2100/1000;
gen da1000_1000=da1000/1000;
gen dl1000_1000= -(dl1000/1000);
gen di2000_1000=di2000/1000;
gen di2000eq_1000=di2000eq/1000;

replace da2100_1000=0 if da2100==.&dn3001~=.;
replace da1000_1000=0 if da1000==.&dn3001~=.;
replace dl1000_1000=0 if dl1000==.&dn3001~=.;

gen tes_1000 = da2100_1000 + da1000_1000 + dl1000_1000;

disp "Mean Housing Fin Assets & Liabilities";
summarize da2100_1000 da1000_1000 dl1000_1000 [aweight = hw0010];

sort dmdhageh;

foreach var of local allVariables {;

	statsby `var'_mean=r(mean), by(dmdhageh)
	saving("`basePath'\stats\ds_mean_`var'_dmdhageh.dta", replace): summarize `var'_1000 [aweight = hw0010];

};

foreach var of local allVariables {;

	drop _all;
	use "`basePath'\stats\ds_mean_`var'_dmdhageh.dta";
	gen lineVar=_n;
	save "`basePath'\stats\ds_mean_`var'_dmdhageh.dta", replace;

};

local t_vars "da2100 da1000 dl1000 tes di2000 di2000eq";
use "`basePath'\stats\ds_mean_dn3001_dmdhageh.dta";

foreach var of local t_vars {;
	merge 1:1 lineVar using "`basePath'\stats\ds_mean_`var'_dmdhageh.dta";
	drop _merge;
};
save "`basePath'\stats\ds_mean__dn3001_dmdhageh.dta", replace;

foreach byVar2plot of local allClassVarsToPlot {;
	
	preserve;
	keep if `byVar2plot'~=.;	
	graph twoway
		(connected dn3001_mean `byVar2plot', lwidth(medthick))
		(connected da2100_mean `byVar2plot')
		(connected da1000_mean `byVar2plot')
		(connected dl1000_mean `byVar2plot',
		xtitle(`" "' "Age of Household Reference Person") ytitle("Mean (EUR Thousands)" `" "')
		yline(0, lcolor(black))
		xlabel(25 "16-34" 35 "35-44" 45 "45-54" 55 "55-64" 65 "65-74" 75 "75+") 
		legend(lab(1 "Net Wealth") lab(2 "Gross Financial Assets") lab(3 "Gross Real Assets") 
		lab(4 "Gross Liabilities"))
		);
		
	graph save "`basePath'\graphs\wealthByAge", asis replace;
	graph export "`basePath'\graphs\wealthByAge.wmf", replace;	

	graph twoway
		(connected di2000_mean `byVar2plot', /* lcolor(black) mcolor(black) */ msymbol(O))
		(connected di2000eq_mean `byVar2plot', /* lcolor(black) mcolor(black) */   lpattern(dash) msymbol(D) msize(small)
		xtitle(`" "' "Age of Household Reference Person") ytitle("Mean (EUR Thousands)" `" "')
		yline(0, lcolor(black))
		xlabel(25 "16-34" 35 "35-44" 45 "45-54" 55 "55-64" 65 "65-74" 75 "75+") 
		ylabel(0(5)50) 
		legend(lab(1 "Income") lab(2 "Equivalised Income"))
			);
		
	graph save "`basePath'\graphs\incomeByAge_eq", asis replace;
	graph export "`basePath'\graphs\incomeByAge_eq.wmf", replace;	
	
	
	restore;
	
};


*************************************************************************************;
log close;
